@@ -1,55 +1,63 @@
 define(
 //begin v1.x content
 {
-	"field-second-relative+0": "الآن",
-	"field-quarter-relative+-1": "الربع الأخير",
-	"field-weekday": "اليوم",
-	"field-mon-narrow-relative+0": "الإثنين الحالي",
-	"field-mon-narrow-relative+1": "الإثنين القادم",
+	"field-quarter-short-relative+0": "هذا الربع",
+	"field-quarter-short-relative+1": "الربع القادم",
+	"field-tue-relative+-1": "الثلاثاء الماضي",
+	"field-year": "السنة",
 	"field-wed-relative+0": "الأربعاء الحالي",
 	"field-wed-relative+1": "الأربعاء القادم",
-	"field-week-short": "الأسبوع",
-	"field-tue-relative+-1": "الثلاثاء الماضي",
-	"field-year-short": "السنة",
-	"field-thu-narrow-relative+-1": "الخميس الماضي",
-	"field-hour-relative+0": "الساعة الحالية",
-	"field-quarter-narrow": "ربع السنة",
-	"field-fri-relative+-1": "الجمعة الماضي",
-	"field-hour-short": "الساعات",
-	"field-wed-relative+-1": "الأربعاء الماضي",
-	"field-mon-short-relative+-1": "الاثنين الماضي",
-	"field-thu-relative+-1": "الخميس الماضي",
-	"field-era": "العصر",
-	"field-sat-narrow-relative+0": "السبت الحالي",
-	"field-sat-narrow-relative+1": "السبت القادم",
-	"field-year": "السنة",
-	"field-hour": "الساعات",
-	"field-sat-relative+0": "السبت الحالي",
-	"field-sat-relative+1": "السبت القادم",
-	"field-sat-short-relative+-1": "السبت الماضي",
-	"field-minute-narrow": "الدقائق",
+	"field-minute": "الدقائق",
+	"field-tue-narrow-relative+0": "الثلاثاء الحالي",
+	"field-tue-narrow-relative+1": "الثلاثاء القادم",
+	"field-thu-short-relative+0": "الخميس الحالي",
+	"field-day-short-relative+-1": "أمس",
+	"field-thu-short-relative+1": "الخميس القادم",
 	"field-day-relative+0": "اليوم",
+	"field-day-short-relative+-2": "أول أمس",
 	"field-day-relative+1": "غدًا",
-	"field-thu-relative+0": "الخميس الحالي",
-	"field-mon-narrow-relative+-1": "الإثنين الماضي",
 	"field-day-relative+2": "بعد الغد",
-	"field-wed-narrow-relative+0": "الأربعاء الحالي",
-	"field-thu-relative+1": "الخميس القادم",
-	"field-wed-narrow-relative+1": "الأربعاء القادم",
-	"field-mon-short-relative+0": "الاثنين الحالي",
-	"field-mon-short-relative+1": "الإثنين القادم",
-	"field-wed-short-relative+-1": "الأربعاء الماضي",
-	"field-fri-narrow-relative+-1": "الجمعة الماضي",
-	"field-hour-narrow": "الساعات",
-	"field-tue-short-relative+0": "الثلاثاء الحالي",
+	"field-wed-narrow-relative+-1": "الأربعاء الماضي",
 	"field-year-narrow": "السنة",
+	"field-era-short": "العصر",
+	"field-tue-relative+0": "الثلاثاء الحالي",
+	"field-tue-relative+1": "الثلاثاء القادم",
+	"field-weekdayOfMonth": "يوم عمل من الشهر",
+	"field-second-short": "الثواني",
+	"field-weekdayOfMonth-narrow": "يوم عمل/شهر",
+	"field-week-relative+0": "هذا الأسبوع",
+	"field-month-relative+0": "هذا الشهر",
+	"field-week-relative+1": "الأسبوع القادم",
+	"field-month-relative+1": "الشهر القادم",
+	"field-sun-narrow-relative+0": "الأحد الحالي",
+	"field-mon-short-relative+0": "الإثنين الحالي",
+	"field-sun-narrow-relative+1": "الأحد القادم",
+	"field-mon-short-relative+1": "الإثنين القادم",
+	"field-second-relative+0": "الآن",
+	"field-weekOfMonth": "الأسبوع من الشهر",
+	"field-month-short": "الشهر",
+	"field-day": "يوم",
+	"field-dayOfYear-short": "يوم من سنة",
+	"field-year-relative+-1": "السنة الماضية",
+	"field-sat-short-relative+-1": "السبت الماضي",
+	"field-hour-relative+0": "الساعة الحالية",
+	"field-wed-relative+-1": "الأربعاء الماضي",
+	"field-sat-narrow-relative+-1": "السبت الماضي",
+	"field-second": "الثواني",
+	"field-quarter": "ربع السنة",
+	"field-week-short": "الأسبوع",
+	"field-day-narrow-relative+0": "اليوم",
+	"field-day-narrow-relative+1": "غدًا",
+	"field-day-narrow-relative+2": "بعد الغد",
+	"field-tue-short-relative+0": "الثلاثاء الحالي",
 	"field-tue-short-relative+1": "الثلاثاء القادم",
-	"field-minute-short": "الدقائق",
+	"field-mon-relative+-1": "الإثنين الماضي",
+	"field-month": "الشهر",
 	"field-day-narrow": "يوم",
-	"field-wed-short-relative+0": "الأربعاء الحالي",
-	"field-wed-short-relative+1": "الأربعاء القادم",
-	"field-sun-relative+0": "الأحد الحالي",
-	"field-sun-relative+1": "الأحد القادم",
+	"field-minute-short": "الدقائق",
+	"field-dayperiod": "ص/م",
+	"field-sat-short-relative+0": "السبت الحالي",
+	"field-sat-short-relative+1": "السبت القادم",
 	"eraAbbr": [
 		"تيكا",
 		"هاكتشي",
@@ -286,76 +294,96 @@ define(
 		"ميجي",
 		"تيشو",
 		"شووا",
-		"هيسي"
+		"هيسي",
+		"ريوا"
 	],
-	"field-minute": "الدقائق",
-	"field-month-short": "الشهر",
-	"field-dayperiod": "ص/م",
+	"field-second-narrow": "الثواني",
+	"field-mon-relative+0": "الإثنين الحالي",
+	"field-mon-relative+1": "الإثنين القادم",
+	"field-day-narrow-relative+-1": "أمس",
+	"field-year-short": "السنة",
+	"field-day-narrow-relative+-2": "أول أمس",
+	"field-quarter-relative+-1": "الربع الأخير",
+	"field-dayperiod-narrow": "ص/م",
+	"field-dayOfYear": "يوم من السنة",
+	"field-sat-relative+-1": "السبت الماضي",
+	"field-hour": "الساعات",
+	"field-month-relative+-1": "الشهر الماضي",
+	"field-quarter-short": "ربع السنة",
+	"field-sat-narrow-relative+0": "السبت الحالي",
+	"field-fri-relative+0": "الجمعة الحالي",
+	"field-sat-narrow-relative+1": "السبت القادم",
+	"field-fri-relative+1": "الجمعة القادم",
+	"field-sun-short-relative+0": "الأحد الحالي",
+	"field-sun-short-relative+1": "الأحد القادم",
+	"field-week-relative+-1": "الأسبوع الماضي",
+	"field-quarter-short-relative+-1": "الربع الأخير",
+	"field-quarter-relative+0": "هذا الربع",
+	"field-minute-relative+0": "هذه الدقيقة",
+	"field-quarter-relative+1": "الربع القادم",
+	"field-wed-short-relative+-1": "الأربعاء الماضي",
+	"field-thu-short-relative+-1": "الخميس الماضي",
+	"field-mon-narrow-relative+-1": "الإثنين الماضي",
+	"field-thu-narrow-relative+-1": "الخميس الماضي",
+	"field-tue-narrow-relative+-1": "الثلاثاء الماضي",
+	"field-weekOfMonth-short": "أسبوع من شهر",
+	"field-wed-short-relative+0": "الأربعاء الحالي",
+	"field-wed-short-relative+1": "الأربعاء القادم",
+	"field-sun-relative+-1": "الأحد الماضي",
+	"field-weekday": "اليوم",
+	"field-day-short-relative+0": "اليوم",
+	"field-quarter-narrow-relative+0": "هذا الربع",
+	"field-sat-relative+0": "السبت الحالي",
+	"field-day-short-relative+1": "غدًا",
+	"field-quarter-narrow-relative+1": "الربع القادم",
+	"field-sat-relative+1": "السبت القادم",
+	"field-day-short-relative+2": "بعد الغد",
+	"field-dayOfYear-narrow": "يوم/سنة",
+	"field-weekdayOfMonth-short": "يوم عمل من شهر",
+	"field-zone-narrow": "توقيت",
+	"field-thu-narrow-relative+0": "الخميس الحالي",
+	"field-thu-narrow-relative+1": "الخميس القادم",
+	"field-sun-narrow-relative+-1": "الأحد الماضي",
+	"field-mon-short-relative+-1": "الإثنين الماضي",
+	"field-thu-relative+0": "الخميس الحالي",
+	"field-thu-relative+1": "الخميس القادم",
+	"field-fri-short-relative+-1": "الجمعة الماضي",
+	"field-thu-relative+-1": "الخميس الماضي",
+	"field-week": "الأسبوع",
+	"field-wed-narrow-relative+0": "الأربعاء الحالي",
+	"field-wed-narrow-relative+1": "الأربعاء القادم",
+	"field-quarter-narrow-relative+-1": "الربع الأخير",
+	"field-dayperiod-short": "ص/م",
+	"field-fri-short-relative+0": "الجمعة الحالي",
+	"field-fri-short-relative+1": "الجمعة القادم",
+	"field-hour-short": "الساعات",
+	"field-zone-short": "توقيت",
+	"field-month-narrow": "الشهر",
+	"field-hour-narrow": "الساعات",
+	"field-fri-narrow-relative+-1": "الجمعة الماضي",
+	"field-year-relative+0": "السنة الحالية",
+	"field-year-relative+1": "السنة القادمة",
+	"field-era-narrow": "العصر",
+	"field-fri-relative+-1": "الجمعة الماضي",
+	"field-tue-short-relative+-1": "الثلاثاء الماضي",
+	"field-minute-narrow": "الدقائق",
+	"field-mon-narrow-relative+0": "الإثنين الحالي",
+	"field-mon-narrow-relative+1": "الإثنين القادم",
+	"field-zone": "التوقيت",
+	"field-weekOfMonth-narrow": "أسبوع/شهر",
+	"field-weekday-narrow": "اليوم",
+	"field-quarter-narrow": "ربع السنة",
+	"field-sun-short-relative+-1": "الأحد الماضي",
 	"field-day-relative+-1": "أمس",
 	"field-day-relative+-2": "أول أمس",
-	"field-minute-relative+0": "هذه الدقيقة",
-	"field-week-narrow": "الأسبوع",
-	"field-wed-narrow-relative+-1": "الأربعاء الماضي",
+	"field-weekday-short": "اليوم",
+	"field-sun-relative+0": "الأحد الحالي",
+	"field-sun-relative+1": "الأحد القادم",
 	"field-day-short": "يوم",
-	"field-quarter-relative+0": "هذا الربع",
-	"field-quarter-relative+1": "الربع القادم",
-	"field-fri-relative+0": "الجمعة الحالي",
-	"field-fri-relative+1": "الجمعة القادم",
-	"field-day": "يوم",
-	"field-second-narrow": "الثواني",
-	"field-zone": "التوقيت",
-	"field-year-relative+-1": "السنة الماضية",
-	"field-month-relative+-1": "الشهر الماضي",
-	"field-thu-short-relative+0": "الخميس الحالي",
-	"field-thu-short-relative+1": "الخميس القادم",
-	"field-quarter-narrow-relative+0": "هذا الربع",
-	"field-quarter-narrow-relative+1": "الربع القادم",
-	"field-quarter": "ربع السنة",
-	"field-month": "الشهر",
-	"field-tue-relative+0": "الثلاثاء الحالي",
-	"field-quarter-short-relative+0": "هذا الربع",
-	"field-tue-relative+1": "الثلاثاء القادم",
-	"field-quarter-short-relative+1": "الربع القادم",
+	"field-week-narrow": "الأسبوع",
+	"field-era": "العصر",
 	"field-fri-narrow-relative+0": "الجمعة الحالي",
-	"field-fri-narrow-relative+1": "الجمعة القادم",
-	"field-fri-short-relative+-1": "الجمعة الماضي",
-	"field-sun-narrow-relative+-1": "الأحد الماضي",
-	"field-quarter-short-relative+-1": "الربع الأخير",
-	"field-sun-narrow-relative+0": "الأحد الحالي",
-	"field-thu-narrow-relative+0": "الخميس الحالي",
-	"field-sun-narrow-relative+1": "الأحد القادم",
-	"field-thu-narrow-relative+1": "الخميس القادم",
-	"field-tue-narrow-relative+0": "الثلاثاء الحالي",
-	"field-mon-relative+0": "الاثنين الحالي",
-	"field-tue-narrow-relative+1": "الثلاثاء القادم",
-	"field-mon-relative+1": "الاثنين القادم",
-	"field-tue-narrow-relative+-1": "الثلاثاء الماضي",
-	"field-second-short": "الثواني",
-	"field-second": "الثواني",
-	"field-fri-short-relative+0": "الجمعة الحالي",
-	"field-sat-relative+-1": "السبت الماضي",
-	"field-fri-short-relative+1": "الجمعة القادم",
-	"field-sun-relative+-1": "الأحد الماضي",
-	"field-month-relative+0": "هذا الشهر",
-	"field-quarter-narrow-relative+-1": "الربع الأخير",
-	"field-month-relative+1": "الشهر القادم",
-	"field-week": "الأسبوع",
-	"field-sat-short-relative+0": "السبت الحالي",
-	"field-sat-short-relative+1": "السبت القادم",
-	"field-year-relative+0": "السنة الحالية",
-	"field-week-relative+-1": "الأسبوع الماضي",
-	"field-year-relative+1": "السنة القادمة",
-	"field-quarter-short": "ربع السنة",
-	"field-sun-short-relative+-1": "الأحد الماضي",
-	"field-thu-short-relative+-1": "الخميس الماضي",
-	"field-tue-short-relative+-1": "الثلاثاء الماضي",
-	"field-mon-relative+-1": "الاثنين الماضي",
-	"field-sat-narrow-relative+-1": "السبت الماضي",
-	"field-month-narrow": "الشهر",
-	"field-week-relative+0": "هذا الأسبوع",
-	"field-sun-short-relative+0": "الأحد الحالي",
-	"field-week-relative+1": "الأسبوع القادم",
-	"field-sun-short-relative+1": "الأحد القادم"
+	"field-fri-narrow-relative+1": "الجمعة القادم"
 }
 //end v1.x content
 );
\ No newline at end of file
