@@ -4,19 +4,19 @@ define(
 	"scientificFormat": "#E0",
 	"infinity": "∞",
 	"superscriptingExponent": "×",
-	"list": ";",
+	"list": "؛",
 	"percentSign": "‎%‎",
 	"minusSign": "‎-",
-	"decimalFormat-short": "000 ترليو",
+	"decimalFormat-short": "000 ترليون",
 	"nan": "ليس رقمًا",
 	"plusSign": "‎+",
 	"currencyFormat": "¤#,##0.00;(¤#,##0.00)",
 	"perMille": "‰",
 	"group": ",",
 	"percentFormat": "#,##0%",
-	"decimalFormat-long": "000 تريليون",
+	"decimalFormat-long": "000 ترليون",
 	"decimalFormat": "#,##0.###",
-	"currencyFormat-short": "¤ 000 ترليو",
+	"currencyFormat-short": "000 ترليون ¤",
 	"timeSeparator": ":",
 	"decimal": ".",
 	"exponential": "E"
