@@ -4,7 +4,7 @@ define(
 	"dayPeriods-standAlone-abbr-noon": "podne",
 	"field-tue-relative+-1": "prošli utorak",
 	"field-year": "godina",
-	"dateFormatItem-yw": "w. 'sedmica' 'u' y.",
+	"dateFormatItem-yw": "w. 'sedmica' 'u' Y.",
 	"dayPeriods-format-abbr-afternoon1": "poslijepodne",
 	"dateFormatItem-Hm": "HH:mm",
 	"field-wed-relative+0": "ova srijeda",
@@ -16,26 +16,30 @@ define(
 	"field-tue-narrow-relative+1": "sljedeći uto.",
 	"field-thu-short-relative+0": "ovaj čet.",
 	"dateTimeFormat-short": "{1} {0}",
-	"field-thu-short-relative+1": "sljedeći čet.",
 	"field-day-relative+0": "danas",
+	"field-thu-short-relative+1": "sljedeći čet.",
 	"field-day-relative+1": "sutra",
 	"field-day-relative+2": "prekosutra",
+	"dateFormatItem-EBhms": "E h:mm:ss B",
 	"field-wed-narrow-relative+-1": "prošla sri.",
 	"field-year-narrow": "g.",
+	"field-era-short": "era",
 	"field-tue-relative+0": "ovaj utorak",
 	"field-tue-relative+1": "sljedeći utorak",
-	"field-second-short": "sek.",
 	"dayPeriods-format-narrow-am": "prijepodne",
+	"field-weekdayOfMonth": "dan u mjesecu",
+	"field-second-short": "sek.",
 	"dayPeriods-standAlone-abbr-morning1": "ujutro",
 	"dateFormatItem-MMMd": "d. MMM",
 	"dayPeriods-format-narrow-morning1": "ujutro",
-	"dayPeriods-format-abbr-am": "prijepodne",
-	"field-week-relative+0": "ove sedmice",
+	"field-weekdayOfMonth-narrow": "d. u mj.",
+	"dayPeriods-format-abbr-am": "AM",
 	"field-month-relative+0": "ovaj mjesec",
-	"field-week-relative+1": "sljedeće sedmice",
-	"field-month-relative+1": "sljedeći mjesec",
-	"field-sun-narrow-relative+0": "ova ned.",
+	"field-week-relative+0": "ove sedmice",
 	"timeFormat-medium": "HH:mm:ss",
+	"field-month-relative+1": "sljedeći mjesec",
+	"field-week-relative+1": "sljedeće sedmice",
+	"field-sun-narrow-relative+0": "ova ned.",
 	"field-mon-short-relative+0": "ovaj pon.",
 	"field-sun-narrow-relative+1": "sljedeća ned.",
 	"field-mon-short-relative+1": "sljedeći pon",
@@ -59,12 +63,14 @@ define(
 		"prije nove ere",
 		"nove ere"
 	],
-	"dayPeriods-standAlone-abbr-pm": "popodne",
-	"field-month-short": "mj.",
+	"dayPeriods-standAlone-abbr-pm": "PM",
+	"field-weekOfMonth": "sedmica u mjesecu",
 	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
+	"field-month-short": "mj.",
 	"field-day": "dan",
 	"dayPeriods-standAlone-wide-night1": "po noći",
 	"field-year-relative+-1": "prošle godine",
+	"field-dayOfYear-short": "dan u god.",
 	"dayPeriods-format-wide-am": "prijepodne",
 	"field-sat-short-relative+-1": "prošla sub.",
 	"dayPeriods-format-narrow-afternoon1": "poslijepodne",
@@ -72,8 +78,6 @@ define(
 	"field-hour-relative+0": "ovaj sat",
 	"field-wed-relative+-1": "prošla srijeda",
 	"dateTimeFormat-medium": "{1} {0}",
-	"field-sat-narrow-relative+-1": "prošla sub.",
-	"field-second": "sekunda",
 	"days-standAlone-narrow": [
 		"n",
 		"p",
@@ -84,6 +88,8 @@ define(
 		"s"
 	],
 	"dayPeriods-standAlone-narrow-noon": "podne",
+	"field-sat-narrow-relative+-1": "prošla sub.",
+	"field-second": "sekunda",
 	"dayPeriods-standAlone-wide-pm": "popodne",
 	"dateFormatItem-Ehms": "E h:mm:ss a",
 	"dateFormat-long": "d. MMMM y.",
@@ -115,8 +121,8 @@ define(
 	"field-mon-relative+-1": "prošli ponedjeljak",
 	"dateFormatItem-GyMMM": "MMM y. G",
 	"field-month": "mjesec",
-	"field-day-narrow": "dan",
 	"dayPeriods-standAlone-abbr-night1": "po noći",
+	"field-day-narrow": "dan",
 	"dayPeriods-standAlone-narrow-afternoon1": "poslijepodne",
 	"dateFormatItem-MMM": "LLL",
 	"field-minute-short": "min.",
@@ -124,23 +130,23 @@ define(
 	"field-sat-short-relative+0": "ova sub.",
 	"field-sat-short-relative+1": "sljedeća sub.",
 	"dayPeriods-format-narrow-pm": "popodne",
-	"dateFormat-medium": "d. MMM. y.",
+	"dateFormat-medium": "d. MMM y.",
 	"eraAbbr": [
 		"p. n. e.",
 		"n. e."
 	],
 	"quarters-standAlone-abbr": [
-		"K1",
-		"K2",
-		"K3",
-		"K4"
+		"KV1",
+		"KV2",
+		"KV3",
+		"KV4"
 	],
-	"dayPeriods-format-abbr-pm": "popodne",
+	"dayPeriods-format-abbr-pm": "PM",
 	"field-second-narrow": "s",
-	"field-mon-relative+0": "ovaj ponedjeljak",
 	"dayPeriods-standAlone-narrow-night1": "po noći",
-	"field-mon-relative+1": "sljedeći ponedjeljak",
+	"field-mon-relative+0": "ovaj ponedjeljak",
 	"field-year-short": "god.",
+	"field-mon-relative+1": "sljedeći ponedjeljak",
 	"months-format-narrow": [
 		"j",
 		"f",
@@ -158,6 +164,7 @@ define(
 	"dayPeriods-format-wide-morning1": "ujutro",
 	"field-quarter-relative+-1": "posljednji kvartal",
 	"dayPeriods-standAlone-narrow-am": "prijepodne",
+	"field-dayperiod-narrow": "prijepodne/poslijepodne",
 	"days-format-short": [
 		"ned",
 		"pon",
@@ -174,11 +181,12 @@ define(
 		"4."
 	],
 	"dayPeriods-format-wide-pm": "popodne",
+	"field-dayOfYear": "dan u godini",
 	"field-sat-relative+-1": "prošla subota",
 	"dateTimeFormat-long": "{1} 'u' {0}",
 	"dateFormatItem-Md": "d.M.",
 	"field-hour": "sat",
-	"dateFormatItem-yQQQQ": "QQQQ y",
+	"dateFormatItem-yQQQQ": "QQQQ y.",
 	"months-format-wide": [
 		"januar",
 		"februar",
@@ -187,7 +195,7 @@ define(
 		"maj",
 		"juni",
 		"juli",
-		"avgust",
+		"august",
 		"septembar",
 		"oktobar",
 		"novembar",
@@ -203,6 +211,7 @@ define(
 	"field-fri-relative+0": "ovaj petak",
 	"field-sat-narrow-relative+1": "sljedeća sub.",
 	"field-fri-relative+1": "sljedeći petak",
+	"dateFormatItem-EBhm": "E h:mm B",
 	"dayPeriods-format-narrow-noon": "podne",
 	"field-sun-short-relative+0": "ova ned.",
 	"field-sun-short-relative+1": "sljedeća ned.",
@@ -216,23 +225,24 @@ define(
 		"maj",
 		"jun",
 		"jul",
-		"avg",
+		"aug",
 		"sep",
 		"okt",
 		"nov",
 		"dec"
 	],
 	"dayPeriods-format-wide-midnight": "ponoć",
+	"timeFormat-long": "HH:mm:ss z",
 	"field-quarter-relative+0": "ovaj kvartal",
 	"field-minute-relative+0": "ova minuta",
-	"timeFormat-long": "HH:mm:ss z",
 	"field-quarter-relative+1": "sljedeći kvartal",
 	"field-wed-short-relative+-1": "prošla sri.",
 	"dateFormatItem-yMMM": "MMM y.",
-	"dateFormat-short": "d.M.yy.",
-	"field-thu-short-relative+-1": "prošli čet.",
+	"dateFormat-short": "d. M. y.",
+	"dateFormatItem-Bh": "h B",
 	"dayPeriods-format-abbr-night1": "po noći",
-	"dateFormatItem-MMMMW": "W. 'sedmica' 'u' MMM",
+	"dateFormatItem-MMMMW": "W. 'sedmica' 'mjesec' MMMM",
+	"field-thu-short-relative+-1": "prošli čet.",
 	"days-standAlone-wide": [
 		"nedjelja",
 		"ponedjeljak",
@@ -246,8 +256,9 @@ define(
 	"dateFormatItem-MMMMd": "d. MMMM",
 	"field-thu-narrow-relative+-1": "prošli čet.",
 	"dateFormatItem-E": "ccc",
-	"field-tue-narrow-relative+-1": "prošli uto.",
 	"dateFormatItem-H": "HH",
+	"field-weekOfMonth-short": "sed. u mj.",
+	"field-tue-narrow-relative+-1": "prošli uto.",
 	"dayPeriods-format-abbr-evening1": "navečer",
 	"dayPeriods-standAlone-narrow-pm": "popodne",
 	"dateFormatItem-M": "L",
@@ -259,7 +270,7 @@ define(
 		"maj",
 		"juni",
 		"juli",
-		"avgust",
+		"august",
 		"septembar",
 		"oktobar",
 		"novembar",
@@ -295,7 +306,7 @@ define(
 		"maj",
 		"jun",
 		"jul",
-		"avg",
+		"aug",
 		"sep",
 		"okt",
 		"nov",
@@ -305,8 +316,11 @@ define(
 	"dayPeriods-format-abbr-morning1": "ujutro",
 	"dayPeriods-standAlone-narrow-evening1": "navečer",
 	"dateFormatItem-yMM": "M/y",
+	"field-dayOfYear-narrow": "dan u g.",
 	"timeFormat-full": "HH:mm:ss zzzz",
+	"field-weekdayOfMonth-short": "dan u mj.",
 	"dateFormatItem-MEd": "E, d.M.",
+	"field-zone-narrow": "zona",
 	"dateFormatItem-y": "y.",
 	"field-thu-narrow-relative+0": "ovaj čet.",
 	"field-sun-narrow-relative+-1": "prošla ned.",
@@ -338,6 +352,7 @@ define(
 	"field-wed-narrow-relative+0": "ova sri.",
 	"field-wed-narrow-relative+1": "sljedeća sri.",
 	"dayPeriods-standAlone-wide-morning1": "ujutro",
+	"field-dayperiod-short": "prijepodne/poslijepodne",
 	"field-fri-short-relative+0": "ovaj pet.",
 	"field-fri-short-relative+1": "sljedeći pet.",
 	"days-standAlone-short": [
@@ -352,27 +367,30 @@ define(
 	"dayPeriods-standAlone-narrow-morning1": "ujutro",
 	"dayPeriods-format-abbr-midnight": "ponoć",
 	"field-hour-short": "h",
+	"field-zone-short": "zona",
 	"quarters-format-abbr": [
-		"K1",
-		"K2",
-		"K3",
-		"K4"
+		"KV1",
+		"KV2",
+		"KV3",
+		"KV4"
 	],
 	"field-month-narrow": "mj.",
 	"field-hour-narrow": "h",
 	"field-fri-narrow-relative+-1": "prošli pet.",
 	"field-year-relative+0": "ove godine",
 	"field-year-relative+1": "sljedeće godine",
+	"field-era-narrow": "era",
 	"field-fri-relative+-1": "prošli petak",
 	"eraNarrow": [
-		"p. n. e.",
-		"n. e."
+		"p.n.e.",
+		"n.e."
 	],
+	"dateFormatItem-Bhms": "h:mm:ss B",
 	"dayPeriods-format-wide-noon": "podne",
 	"field-tue-short-relative+-1": "prošli uto.",
 	"field-minute-narrow": "min.",
 	"dayPeriods-standAlone-wide-afternoon1": "poslijepodne",
-	"dateFormatItem-yQQQ": "QQQ y",
+	"dateFormatItem-yQQQ": "QQQ y.",
 	"days-format-wide": [
 		"nedjelja",
 		"ponedjeljak",
@@ -384,21 +402,25 @@ define(
 	],
 	"field-mon-narrow-relative+0": "ovaj pon.",
 	"dateFormatItem-EHm": "E HH:mm",
-	"field-mon-narrow-relative+1": "sljedeći pon",
+	"field-mon-narrow-relative+1": "sljedeći pon.",
 	"dayPeriods-standAlone-wide-midnight": "ponoć",
 	"dateFormatItem-yM": "MM/y",
 	"field-zone": "vremenska zona",
 	"dateFormatItem-yMMMM": "LLLL y.",
 	"dateFormatItem-MMMEd": "E, d. MMM",
+	"field-weekOfMonth-narrow": "s. u mj.",
 	"dateFormatItem-EHms": "E HH:mm:ss",
 	"dateFormatItem-yMEd": "E, d.M.y.",
+	"field-weekday-narrow": "dan u sed.",
 	"dayPeriods-standAlone-narrow-midnight": "ponoć",
 	"field-quarter-narrow": "kv.",
-	"dayPeriods-standAlone-abbr-am": "prijepodne",
+	"dayPeriods-standAlone-abbr-am": "AM",
 	"field-day-relative+-1": "jučer",
 	"field-sun-short-relative+-1": "prošla ned.",
 	"field-day-relative+-2": "prekjučer",
 	"dayPeriods-format-narrow-night1": "po noći",
+	"field-weekday-short": "dan u sed.",
+	"dateFormatItem-Bhm": "h:mm B",
 	"days-format-abbr": [
 		"ned",
 		"pon",
