@@ -6,14 +6,14 @@ define(
 	"field-tue-relative+-1": "sidste tirsdag",
 	"field-year": "år",
 	"field-wed-relative+0": "på onsdag",
-	"field-wed-relative+1": "næste onsdag",
+	"field-wed-relative+1": "på onsdag",
 	"field-minute": "minut",
 	"field-month-narrow-relative+-1": "sidste md.",
 	"field-tue-narrow-relative+0": "på ti.",
-	"field-tue-narrow-relative+1": "næste ti.",
+	"field-tue-narrow-relative+1": "på ti.",
 	"field-thu-short-relative+0": "på tor.",
 	"field-day-short-relative+-1": "i går",
-	"field-thu-short-relative+1": "næste tor.",
+	"field-thu-short-relative+1": "på tor.",
 	"field-day-relative+0": "i dag",
 	"field-day-short-relative+-2": "i forgårs",
 	"field-day-relative+1": "i morgen",
@@ -22,25 +22,30 @@ define(
 	"field-week-narrow-relative+1": "næste uge",
 	"field-wed-narrow-relative+-1": "sidste on.",
 	"field-year-narrow": "år",
+	"field-era-short": "æra",
 	"field-year-narrow-relative+0": "i år",
 	"field-tue-relative+0": "på tirsdag",
 	"field-year-narrow-relative+1": "næste år",
-	"field-tue-relative+1": "næste tirsdag",
+	"field-tue-relative+1": "på tirsdag",
+	"field-weekdayOfMonth": "ugedag i måneden",
 	"field-second-short": "sek.",
+	"field-weekdayOfMonth-narrow": "ugedag i md.",
 	"field-week-relative+0": "denne uge",
 	"field-month-relative+0": "denne måned",
 	"field-week-relative+1": "næste uge",
 	"field-month-relative+1": "næste måned",
 	"field-sun-narrow-relative+0": "på sø.",
 	"field-mon-short-relative+0": "på man.",
-	"field-sun-narrow-relative+1": "næste sø.",
-	"field-mon-short-relative+1": "næste man.",
+	"field-sun-narrow-relative+1": "på sø.",
+	"field-mon-short-relative+1": "på man.",
 	"field-second-relative+0": "nu",
+	"field-weekOfMonth": "uge i måneden",
 	"field-month-short": "md.",
 	"field-day": "dag",
+	"field-dayOfYear-short": "dag i året",
 	"field-year-relative+-1": "sidste år",
 	"field-sat-short-relative+-1": "sidste lør.",
-	"field-hour-relative+0": "i den kommende time",
+	"field-hour-relative+0": "denne time",
 	"field-wed-relative+-1": "sidste onsdag",
 	"field-sat-narrow-relative+-1": "sidste lø.",
 	"field-second": "sekund",
@@ -52,7 +57,7 @@ define(
 	"field-day-narrow-relative+1": "i morgen",
 	"field-day-narrow-relative+2": "i overmorgen",
 	"field-tue-short-relative+0": "på tir.",
-	"field-tue-short-relative+1": "næste tir.",
+	"field-tue-short-relative+1": "på tir.",
 	"field-month-short-relative+-1": "sidste md.",
 	"field-mon-relative+-1": "sidste mandag",
 	"field-month": "måned",
@@ -60,35 +65,37 @@ define(
 	"field-minute-short": "min.",
 	"field-dayperiod": "AM/PM",
 	"field-sat-short-relative+0": "på lør.",
-	"field-sat-short-relative+1": "næste lør.",
+	"field-sat-short-relative+1": "på lør.",
 	"dateFormat-medium": "d. MMM y G",
 	"field-second-narrow": "s",
 	"field-mon-relative+0": "på mandag",
-	"field-mon-relative+1": "næste mandag",
+	"field-mon-relative+1": "på mandag",
 	"field-day-narrow-relative+-1": "i går",
 	"field-year-short": "år",
 	"field-day-narrow-relative+-2": "i forgårs",
 	"field-quarter-relative+-1": "sidste kvartal",
+	"field-dayperiod-narrow": "AM/PM",
 	"field-week-narrow-relative+-1": "sidste uge",
+	"field-dayOfYear": "dag i året",
 	"field-sat-relative+-1": "sidste lørdag",
 	"field-hour": "time",
-	"field-minute-narrow-relative+0": "denne minut",
+	"field-minute-narrow-relative+0": "dette min.",
 	"dateFormat-full": "EEEE d. MMMM y G",
 	"field-month-relative+-1": "sidste måned",
 	"field-quarter-short": "kvt.",
 	"field-sat-narrow-relative+0": "på lø.",
 	"field-fri-relative+0": "på fredag",
-	"field-sat-narrow-relative+1": "næste lø.",
-	"field-fri-relative+1": "næste fredag",
+	"field-sat-narrow-relative+1": "på lø.",
+	"field-fri-relative+1": "på fredag",
 	"field-month-narrow-relative+0": "denne md.",
 	"field-month-narrow-relative+1": "næste md.",
 	"field-sun-short-relative+0": "på søn.",
-	"field-sun-short-relative+1": "næste søn.",
+	"field-sun-short-relative+1": "på søn.",
 	"field-week-relative+-1": "sidste uge",
 	"field-quarter-short-relative+-1": "sidste kvt.",
-	"field-minute-short-relative+0": "denne minut",
+	"field-minute-short-relative+0": "dette min.",
 	"field-quarter-relative+0": "dette kvartal",
-	"field-minute-relative+0": "i det kommende minut",
+	"field-minute-relative+0": "dette minut",
 	"field-quarter-relative+1": "næste kvartal",
 	"field-wed-short-relative+-1": "sidste ons.",
 	"dateFormat-short": "d/M/y",
@@ -97,8 +104,9 @@ define(
 	"field-mon-narrow-relative+-1": "sidste ma.",
 	"field-thu-narrow-relative+-1": "sidste to.",
 	"field-tue-narrow-relative+-1": "sidste ti.",
+	"field-weekOfMonth-short": "uge i md.",
 	"field-wed-short-relative+0": "på ons.",
-	"field-wed-short-relative+1": "næste ons.",
+	"field-wed-short-relative+1": "på ons.",
 	"field-sun-relative+-1": "sidste søndag",
 	"field-weekday": "ugedag",
 	"field-day-short-relative+0": "i dag",
@@ -106,54 +114,63 @@ define(
 	"field-sat-relative+0": "på lørdag",
 	"field-day-short-relative+1": "i morgen",
 	"field-quarter-narrow-relative+1": "næste kvt.",
-	"field-sat-relative+1": "næste lørdag",
+	"field-sat-relative+1": "på lørdag",
 	"field-day-short-relative+2": "i overmorgen",
 	"field-week-short-relative+0": "denne uge",
 	"field-week-short-relative+1": "næste uge",
+	"field-dayOfYear-narrow": "dag i året",
 	"field-month-short-relative+0": "denne md.",
 	"field-month-short-relative+1": "næste md.",
+	"field-weekdayOfMonth-short": "ugedag i md.",
+	"field-zone-narrow": "zone",
 	"field-thu-narrow-relative+0": "på to.",
-	"field-thu-narrow-relative+1": "næste to.",
+	"field-thu-narrow-relative+1": "på to.",
 	"field-sun-narrow-relative+-1": "sidste sø.",
 	"field-mon-short-relative+-1": "sidste man.",
 	"field-thu-relative+0": "på torsdag",
-	"field-thu-relative+1": "næste torsdag",
+	"field-thu-relative+1": "på torsdag",
 	"field-fri-short-relative+-1": "sidste fre.",
 	"field-thu-relative+-1": "sidste torsdag",
 	"field-week": "uge",
 	"field-wed-narrow-relative+0": "på on.",
-	"field-wed-narrow-relative+1": "næste on.",
+	"field-wed-narrow-relative+1": "på on.",
 	"field-quarter-narrow-relative+-1": "sidste kvt.",
 	"field-year-short-relative+0": "i år",
+	"field-dayperiod-short": "AM/PM",
 	"field-year-short-relative+1": "næste år",
 	"field-fri-short-relative+0": "på fre.",
-	"field-fri-short-relative+1": "næste fre.",
+	"field-fri-short-relative+1": "på fre.",
 	"field-week-short-relative+-1": "sidste uge",
 	"field-hour-narrow-relative+0": "denne time",
 	"field-hour-short": "t.",
+	"field-zone-short": "zone",
 	"field-month-narrow": "md.",
-	"field-hour-narrow": "t",
+	"field-hour-narrow": "t.",
 	"field-fri-narrow-relative+-1": "sidste fr.",
 	"field-year-relative+0": "i år",
 	"field-year-relative+1": "næste år",
+	"field-era-narrow": "æra",
 	"field-fri-relative+-1": "sidste fredag",
 	"field-tue-short-relative+-1": "sidste tir.",
-	"field-minute-narrow": "min",
+	"field-minute-narrow": "min.",
 	"field-mon-narrow-relative+0": "på ma.",
-	"field-mon-narrow-relative+1": "næste ma.",
+	"field-mon-narrow-relative+1": "på ma.",
 	"field-year-short-relative+-1": "sidste år",
 	"field-zone": "tidszone",
+	"field-weekOfMonth-narrow": "uge i md.",
+	"field-weekday-narrow": "ugedag",
 	"field-quarter-narrow": "kvt.",
 	"field-sun-short-relative+-1": "sidste søn.",
 	"field-day-relative+-1": "i går",
 	"field-day-relative+-2": "i forgårs",
+	"field-weekday-short": "ugedag",
 	"field-sun-relative+0": "på søndag",
-	"field-sun-relative+1": "næste søndag",
+	"field-sun-relative+1": "på søndag",
 	"field-day-short": "dag",
 	"field-week-narrow": "uge",
 	"field-era": "æra",
 	"field-fri-narrow-relative+0": "på fr.",
-	"field-fri-narrow-relative+1": "næste fr."
+	"field-fri-narrow-relative+1": "på fr."
 }
 //end v1.x content
 );
\ No newline at end of file
