@@ -11,22 +11,28 @@ define(
 	"field-month-narrow-relative+-1": "el mes pasado",
 	"field-tue-narrow-relative+0": "este MA",
 	"field-tue-narrow-relative+1": "el próximo MA",
-	"field-thu-short-relative+0": "este jue.",
 	"field-day-short-relative+-1": "ayer",
+	"field-thu-short-relative+0": "este jue.",
 	"dateTimeFormat-short": "{1} {0}",
 	"field-day-relative+0": "hoy",
 	"field-day-short-relative+-2": "anteayer",
 	"field-thu-short-relative+1": "el próximo jue.",
 	"field-day-relative+1": "mañana",
+	"field-week-narrow-relative+0": "esta sem.",
 	"field-day-relative+2": "pasado mañana",
+	"field-week-narrow-relative+1": "próx. sem.",
+	"dateFormatItem-EBhms": "E h:mm:ss B",
 	"field-wed-narrow-relative+-1": "el MI pasado",
 	"field-year-narrow": "a",
+	"field-era-short": "era",
 	"field-year-narrow-relative+0": "este año",
 	"field-tue-relative+0": "este martes",
 	"field-year-narrow-relative+1": "el próximo año",
 	"field-tue-relative+1": "el próximo martes",
+	"field-weekdayOfMonth": "día de la semana del mes",
 	"field-second-short": "s",
 	"dateFormatItem-MMMd": "d MMM",
+	"field-weekdayOfMonth-narrow": "día de sem. de mes",
 	"field-week-relative+0": "esta semana",
 	"field-month-relative+0": "este mes",
 	"field-week-relative+1": "la próxima semana",
@@ -37,11 +43,13 @@ define(
 	"field-mon-short-relative+1": "el próximo lun.",
 	"field-second-relative+0": "ahora",
 	"dateFormatItem-yyyyQQQ": "QQQ y G",
+	"field-weekOfMonth": "semana del mes",
 	"field-month-short": "m",
 	"dateFormatItem-GyMMMM": "MMMM 'de' y G",
 	"dateFormatItem-GyMMMEd": "E, d MMM y G",
 	"dateFormatItem-yyyyMd": "d/M/y GGGGG",
 	"field-day": "día",
+	"field-dayOfYear-short": "día del a",
 	"field-year-relative+-1": "el año pasado",
 	"field-sat-short-relative+-1": "el sáb. pasado",
 	"dateFormatItem-yyyyMMMMd": "d 'de' MMMM 'de' y G",
@@ -51,6 +59,7 @@ define(
 	"dateTimeFormat-medium": "{1} {0}",
 	"field-sat-narrow-relative+-1": "el SA pasado",
 	"field-second": "segundo",
+	"dateFormatItem-Ehms": "E h:mm:ss a",
 	"dateFormat-long": "d 'de' MMMM 'de' y G",
 	"dateFormatItem-GyMMMd": "d MMM y G",
 	"field-quarter": "trimestre",
@@ -68,7 +77,7 @@ define(
 	"field-day-narrow": "d",
 	"dateFormatItem-MMM": "LLL",
 	"field-minute-short": "min",
-	"field-dayperiod": "a. m./p. m.",
+	"field-dayperiod": "a. m./p. m.",
 	"field-sat-short-relative+0": "este sáb.",
 	"field-sat-short-relative+1": "el próximo sáb.",
 	"dateFormat-medium": "d/M/y G",
@@ -82,6 +91,9 @@ define(
 	"field-day-narrow-relative+-2": "anteayer",
 	"field-quarter-relative+-1": "el trimestre pasado",
 	"dateFormatItem-yyyyMMMd": "d MMM y G",
+	"field-dayperiod-narrow": "a. m./p. m.",
+	"field-week-narrow-relative+-1": "sem. ant.",
+	"field-dayOfYear": "día del año",
 	"field-sat-relative+-1": "el sábado pasado",
 	"dateTimeFormat-long": "{1}, {0}",
 	"dateFormatItem-Md": "d/M",
@@ -94,45 +106,54 @@ define(
 	"field-fri-relative+0": "este viernes",
 	"field-sat-narrow-relative+1": "el próximo SA",
 	"field-fri-relative+1": "el próximo viernes",
+	"dateFormatItem-EBhm": "E h:mm B",
 	"field-month-narrow-relative+0": "este mes",
 	"field-month-narrow-relative+1": "el próximo mes",
 	"field-sun-short-relative+0": "este dom.",
 	"field-sun-short-relative+1": "el próximo dom.",
 	"field-week-relative+-1": "la semana pasada",
+	"dateFormatItem-Ehm": "E h:mm a",
 	"field-quarter-relative+0": "este trimestre",
 	"field-minute-relative+0": "este minuto",
 	"field-quarter-relative+1": "el próximo trimestre",
 	"field-wed-short-relative+-1": "el mié. pasado",
 	"dateFormat-short": "d/M/yy G",
-	"field-thu-short-relative+-1": "el jue. pasado",
+	"dateFormatItem-Bh": "h B",
 	"field-year-narrow-relative+-1": "el año pasado",
+	"field-thu-short-relative+-1": "el jue. pasado",
 	"dateFormatItem-yyyyMMMEd": "EEE, d MMM y G",
 	"field-mon-narrow-relative+-1": "el LU pasado",
 	"dateFormatItem-MMMMd": "d 'de' MMMM",
 	"field-thu-narrow-relative+-1": "el JU pasado",
 	"dateFormatItem-E": "ccc",
-	"field-tue-narrow-relative+-1": "el MA pasado",
 	"dateFormatItem-H": "HH",
+	"field-weekOfMonth-short": "sem. de mes",
+	"field-tue-narrow-relative+-1": "el MA pasado",
 	"dateFormatItem-yyyy": "y G",
-	"field-wed-short-relative+0": "este mié.",
 	"dateFormatItem-M": "L",
+	"field-wed-short-relative+0": "este mié.",
 	"field-wed-short-relative+1": "el próximo mié.",
 	"field-sun-relative+-1": "el domingo pasado",
 	"dateFormatItem-MMMMEd": "E, d 'de' MMMM",
 	"dateTimeFormat-full": "{1}, {0}",
-	"dateFormatItem-hm": "hh:mm a",
+	"dateFormatItem-hm": "h:mm a",
 	"dateFormatItem-d": "d",
 	"field-weekday": "día de la semana",
 	"field-day-short-relative+0": "hoy",
 	"field-day-short-relative+1": "mañana",
 	"field-sat-relative+0": "este sábado",
-	"dateFormatItem-h": "hh a",
+	"dateFormatItem-h": "h a",
 	"field-day-short-relative+2": "pasado mañana",
 	"field-sat-relative+1": "el próximo sábado",
+	"field-week-short-relative+0": "esta sem.",
+	"field-week-short-relative+1": "próx. sem.",
 	"dateFormatItem-GyMMMMEd": "E, d 'de' MMMM 'de' y G",
+	"field-dayOfYear-narrow": "día del a",
 	"field-month-short-relative+0": "este mes",
 	"field-month-short-relative+1": "el próximo mes",
+	"field-weekdayOfMonth-short": "día de sem. de mes",
 	"dateFormatItem-MEd": "E, d/M",
+	"field-zone-narrow": "zona",
 	"dateFormatItem-y": "y G",
 	"field-thu-narrow-relative+0": "este JU",
 	"field-sun-narrow-relative+-1": "el DO pasado",
@@ -140,7 +161,7 @@ define(
 	"field-thu-narrow-relative+1": "el próximo JU",
 	"field-thu-relative+0": "este jueves",
 	"field-thu-relative+1": "el próximo jueves",
-	"dateFormatItem-hms": "hh:mm:ss a",
+	"dateFormatItem-hms": "h:mm:ss a",
 	"field-fri-short-relative+-1": "el vie. pasado",
 	"field-thu-relative+-1": "el jueves pasado",
 	"field-week": "semana",
@@ -149,29 +170,40 @@ define(
 	"field-wed-narrow-relative+1": "el próximo MI",
 	"field-year-short-relative+0": "este año",
 	"dateFormatItem-yyyyMMM": "MMM y G",
+	"field-dayperiod-short": "a. m./p. m.",
 	"field-year-short-relative+1": "el próximo año",
 	"field-fri-short-relative+0": "este vie.",
 	"field-fri-short-relative+1": "el próximo vie.",
+	"field-week-short-relative+-1": "sem. ant.",
 	"dateFormatItem-GyMMMMd": "d 'de' MMMM 'de' y G",
 	"dateFormatItem-yyyyQQQQ": "QQQQ 'de' y G",
 	"field-hour-short": "h",
+	"field-zone-short": "zona",
 	"field-month-narrow": "m",
 	"field-hour-narrow": "h",
 	"field-fri-narrow-relative+-1": "el VI pasado",
 	"field-year-relative+0": "este año",
 	"field-year-relative+1": "el próximo año",
+	"field-era-narrow": "era",
 	"field-fri-relative+-1": "el viernes pasado",
+	"dateFormatItem-Bhms": "h:mm:ss B",
 	"field-tue-short-relative+-1": "el mar. pasado",
 	"field-minute-narrow": "min",
 	"field-mon-narrow-relative+0": "este LU",
+	"dateFormatItem-EHm": "E HH:mm",
 	"field-mon-narrow-relative+1": "el próximo LU",
 	"field-year-short-relative+-1": "el año pasado",
 	"field-zone": "zona horaria",
 	"dateFormatItem-MMMEd": "E, d MMM",
+	"field-weekOfMonth-narrow": "sem. de mes",
+	"dateFormatItem-EHms": "E HH:mm:ss",
+	"field-weekday-narrow": "día de sem.",
 	"field-quarter-narrow": "trim.",
 	"field-sun-short-relative+-1": "el dom. pasado",
 	"field-day-relative+-1": "ayer",
 	"field-day-relative+-2": "anteayer",
+	"field-weekday-short": "día de sem.",
+	"dateFormatItem-Bhm": "h:mm B",
 	"field-sun-relative+0": "este domingo",
 	"field-sun-relative+1": "el próximo domingo",
 	"dateFormatItem-Gy": "y G",
