@@ -16,17 +16,22 @@ define(
 	"field-day-relative+0": "hoy",
 	"field-day-short-relative+-2": "anteayer",
 	"field-day-relative+1": "mañana",
+	"field-week-narrow-relative+0": "esta sem.",
 	"field-day-relative+2": "pasado mañana",
+	"field-week-narrow-relative+1": "próx. sem.",
 	"field-wed-narrow-relative+-1": "el MI pasado",
 	"field-year-narrow": "a",
+	"field-era-short": "era",
 	"field-year-narrow-relative+0": "este año",
 	"field-tue-relative+0": "este martes",
 	"field-year-narrow-relative+1": "el próximo año",
 	"field-tue-relative+1": "el próximo martes",
+	"field-weekdayOfMonth": "día de la semana del mes",
 	"field-second-short": "s",
-	"dayPeriods-format-narrow-am": "a. m.",
+	"dayPeriods-format-narrow-am": "a. m.",
 	"dateFormatItem-MMMd": "d MMM",
-	"dayPeriods-format-abbr-am": "a. m.",
+	"field-weekdayOfMonth-narrow": "día de sem. de mes",
+	"dayPeriods-format-abbr-am": "a. m.",
 	"field-week-relative+0": "esta semana",
 	"field-month-relative+0": "este mes",
 	"field-week-relative+1": "la próxima semana",
@@ -38,13 +43,32 @@ define(
 	"field-mon-short-relative+1": "el próximo lun.",
 	"field-second-relative+0": "ahora",
 	"dateFormatItem-yyyyQQQ": "QQQ y G",
-	"dayPeriods-standAlone-abbr-pm": "p. m.",
+	"months-standAlone-narrow": [
+		"1",
+		"2",
+		"3",
+		"4",
+		"5",
+		"6",
+		"7",
+		"8",
+		"9",
+		"10",
+		"11",
+		"12"
+	],
+	"eraNames": [
+		"AH"
+	],
+	"field-weekOfMonth": "semana del mes",
+	"dayPeriods-standAlone-abbr-pm": "p. m.",
 	"field-month-short": "m",
 	"dateFormatItem-GyMMMEd": "E, d MMM y G",
 	"dateFormatItem-yyyyMd": "d/M/y GGGGG",
 	"field-day": "día",
+	"field-dayOfYear-short": "día del a",
 	"field-year-relative+-1": "el año pasado",
-	"dayPeriods-format-wide-am": "a. m.",
+	"dayPeriods-format-wide-am": "a. m.",
 	"field-sat-short-relative+-1": "el sáb. pasado",
 	"field-hour-relative+0": "esta hora",
 	"dateFormatItem-yyyyMEd": "E, d/M/y GGGGG",
@@ -60,7 +84,7 @@ define(
 		"V",
 		"S"
 	],
-	"dayPeriods-standAlone-wide-pm": "p. m.",
+	"dayPeriods-standAlone-wide-pm": "p. m.",
 	"dateFormat-long": "d 'de' MMMM 'de' y G",
 	"dateFormatItem-GyMMMd": "d MMM y G",
 	"field-quarter": "trimestre",
@@ -91,10 +115,10 @@ define(
 	"field-month": "mes",
 	"field-day-narrow": "d",
 	"field-minute-short": "min",
-	"field-dayperiod": "a. m./p. m.",
+	"field-dayperiod": "a. m./p. m.",
 	"field-sat-short-relative+0": "este sáb.",
 	"field-sat-short-relative+1": "el próximo sáb.",
-	"dayPeriods-format-narrow-pm": "p. m.",
+	"dayPeriods-format-narrow-pm": "p. m.",
 	"dateFormat-medium": "d/M/y G",
 	"dateFormatItem-yyyyMMMM": "MMMM 'de' y G",
 	"eraAbbr": [
@@ -106,7 +130,7 @@ define(
 		"T3",
 		"T4"
 	],
-	"dayPeriods-format-abbr-pm": "p. m.",
+	"dayPeriods-format-abbr-pm": "p. m.",
 	"dateFormatItem-yyyyM": "M/y GGGGG",
 	"field-second-narrow": "s",
 	"field-mon-relative+0": "este lunes",
@@ -114,9 +138,25 @@ define(
 	"field-day-narrow-relative+-1": "ayer",
 	"field-year-short": "a",
 	"field-day-narrow-relative+-2": "anteayer",
+	"months-format-narrow": [
+		"1",
+		"2",
+		"3",
+		"4",
+		"5",
+		"6",
+		"7",
+		"8",
+		"9",
+		"10",
+		"11",
+		"12"
+	],
 	"field-quarter-relative+-1": "el trimestre pasado",
 	"dateFormatItem-yyyyMMMd": "d MMM y G",
-	"dayPeriods-standAlone-narrow-am": "a. m.",
+	"field-dayperiod-narrow": "a. m./p. m.",
+	"dayPeriods-standAlone-narrow-am": "a. m.",
+	"field-week-narrow-relative+-1": "sem. ant.",
 	"days-format-short": [
 		"DO",
 		"LU",
@@ -126,11 +166,26 @@ define(
 		"VI",
 		"SA"
 	],
-	"dayPeriods-format-wide-pm": "p. m.",
+	"dayPeriods-format-wide-pm": "p. m.",
+	"field-dayOfYear": "día del año",
 	"field-sat-relative+-1": "el sábado pasado",
 	"dateTimeFormat-long": "{1}, {0}",
 	"dateFormatItem-Md": "d/M",
 	"field-hour": "hora",
+	"months-format-wide": [
+		"muharram",
+		"safar",
+		"rabiʻ I",
+		"rabiʻ II",
+		"jumada I",
+		"jumada II",
+		"rajab",
+		"shaʻban",
+		"ramadán",
+		"shawwal",
+		"dhuʻl-qiʻdah",
+		"dhuʻl-hijjah"
+	],
 	"dateFormat-full": "EEEE, d 'de' MMMM 'de' y G",
 	"field-month-relative+-1": "el mes pasado",
 	"field-quarter-short": "trim.",
@@ -143,6 +198,20 @@ define(
 	"field-sun-short-relative+0": "este dom.",
 	"field-sun-short-relative+1": "el próximo dom.",
 	"field-week-relative+-1": "la semana pasada",
+	"months-format-abbr": [
+		"muh.",
+		"saf.",
+		"rab. I",
+		"rab. II",
+		"jum. I",
+		"jum. II",
+		"raj.",
+		"sha.",
+		"ram.",
+		"shaw.",
+		"dhuʻl-q.",
+		"dhuʻl-h."
+	],
 	"field-quarter-relative+0": "este trimestre",
 	"field-minute-relative+0": "este minuto",
 	"timeFormat-long": "H:mm:ss z",
@@ -165,33 +234,65 @@ define(
 	"dateFormatItem-MMMMd": "d 'de' MMMM",
 	"field-thu-narrow-relative+-1": "el JU pasado",
 	"field-tue-narrow-relative+-1": "el MA pasado",
+	"field-weekOfMonth-short": "sem. de mes",
 	"dateFormatItem-yyyy": "y G",
-	"dayPeriods-standAlone-narrow-pm": "p. m.",
+	"dayPeriods-standAlone-narrow-pm": "p. m.",
 	"field-wed-short-relative+0": "este mié.",
+	"months-standAlone-wide": [
+		"muharram",
+		"safar",
+		"rabiʻ I",
+		"rabiʻ II",
+		"jumada I",
+		"jumada II",
+		"rajab",
+		"shaʻban",
+		"ramadán",
+		"shawwal",
+		"dhuʻl-qiʻdah",
+		"dhuʻl-hijjah"
+	],
 	"field-wed-short-relative+1": "el próximo mié.",
 	"field-sun-relative+-1": "el domingo pasado",
 	"days-standAlone-abbr": [
-		"dom.",
-		"lun.",
-		"mar.",
-		"mié.",
-		"jue.",
-		"vie.",
-		"sáb."
+		"dom",
+		"lun",
+		"mar",
+		"mié",
+		"jue",
+		"vie",
+		"sáb"
 	],
 	"dateTimeFormat-full": "{1}, {0}",
-	"dateFormatItem-hm": "hh:mm a",
 	"field-weekday": "día de la semana",
 	"field-day-short-relative+0": "hoy",
 	"field-sat-relative+0": "este sábado",
 	"field-day-short-relative+1": "mañana",
-	"dateFormatItem-h": "hh a",
 	"field-sat-relative+1": "el próximo sábado",
 	"field-day-short-relative+2": "pasado mañana",
+	"field-week-short-relative+0": "esta sem.",
+	"field-week-short-relative+1": "próx. sem.",
+	"months-standAlone-abbr": [
+		"muh.",
+		"saf.",
+		"rab. I",
+		"rab. II",
+		"jum. I",
+		"jum. II",
+		"raj.",
+		"sha.",
+		"ram.",
+		"shaw.",
+		"dhuʻl-q.",
+		"dhuʻl-h."
+	],
+	"field-dayOfYear-narrow": "día del a",
 	"field-month-short-relative+0": "este mes",
 	"field-month-short-relative+1": "el próximo mes",
+	"field-weekdayOfMonth-short": "día de sem. de mes",
 	"timeFormat-full": "H:mm:ss (zzzz)",
 	"dateFormatItem-MEd": "E, d/M",
+	"field-zone-narrow": "zona",
 	"dateFormatItem-y": "y G",
 	"field-thu-narrow-relative+0": "este JU",
 	"field-thu-narrow-relative+1": "el próximo JU",
@@ -200,7 +301,6 @@ define(
 	"field-thu-relative+0": "este jueves",
 	"field-thu-relative+1": "el próximo jueves",
 	"field-fri-short-relative+-1": "el vie. pasado",
-	"dateFormatItem-hms": "hh:mm:ss a",
 	"field-thu-relative+-1": "el jueves pasado",
 	"field-week": "semana",
 	"quarters-format-wide": [
@@ -213,6 +313,7 @@ define(
 	"field-wed-narrow-relative+0": "este MI",
 	"field-wed-narrow-relative+1": "el próximo MI",
 	"field-year-short-relative+0": "este año",
+	"field-dayperiod-short": "a. m./p. m.",
 	"dateFormatItem-yyyyMMM": "MMM y G",
 	"field-year-short-relative+1": "el próximo año",
 	"field-fri-short-relative+0": "este vie.",
@@ -226,8 +327,10 @@ define(
 		"VI",
 		"SA"
 	],
+	"field-week-short-relative+-1": "sem. ant.",
 	"dateFormatItem-yyyyQQQQ": "QQQQ 'de' y G",
 	"field-hour-short": "h",
+	"field-zone-short": "zona",
 	"quarters-format-abbr": [
 		"T1",
 		"T2",
@@ -239,7 +342,9 @@ define(
 	"field-fri-narrow-relative+-1": "el VI pasado",
 	"field-year-relative+0": "este año",
 	"field-year-relative+1": "el próximo año",
+	"field-era-narrow": "era",
 	"field-fri-relative+-1": "el viernes pasado",
+	"eraNarrow": "AH",
 	"field-tue-short-relative+-1": "el mar. pasado",
 	"field-minute-narrow": "min",
 	"days-format-wide": [
@@ -256,19 +361,22 @@ define(
 	"field-year-short-relative+-1": "el año pasado",
 	"field-zone": "zona horaria",
 	"dateFormatItem-MMMEd": "E, d MMM",
+	"field-weekOfMonth-narrow": "sem. de mes",
+	"field-weekday-narrow": "día de sem.",
 	"field-quarter-narrow": "trim.",
 	"field-sun-short-relative+-1": "el dom. pasado",
 	"field-day-relative+-1": "ayer",
-	"dayPeriods-standAlone-abbr-am": "a. m.",
+	"dayPeriods-standAlone-abbr-am": "a. m.",
 	"field-day-relative+-2": "anteayer",
+	"field-weekday-short": "día de sem.",
 	"days-format-abbr": [
-		"dom.",
-		"lun.",
-		"mar.",
-		"mié.",
-		"jue.",
-		"vie.",
-		"sáb."
+		"dom",
+		"lun",
+		"mar",
+		"mié",
+		"jue",
+		"vie",
+		"sáb"
 	],
 	"field-sun-relative+0": "este domingo",
 	"field-sun-relative+1": "el próximo domingo",
@@ -278,7 +386,7 @@ define(
 	"field-era": "era",
 	"field-fri-narrow-relative+0": "este VI",
 	"field-fri-narrow-relative+1": "el próximo VI",
-	"dayPeriods-standAlone-wide-am": "a. m."
+	"dayPeriods-standAlone-wide-am": "a. m."
 }
 //end v1.x content
 );
\ No newline at end of file
