@@ -24,14 +24,18 @@ define(
 	"field-day-relative+2": "ylihuomenna",
 	"field-week-narrow-relative+1": "ensi vk",
 	"field-wed-narrow-relative+-1": "viime ke",
+	"dateFormatItem-EBhms": "E h.mm.ss B",
 	"field-year-narrow": "v",
+	"field-era-short": "aikakausi",
 	"field-year-narrow-relative+0": "tänä v",
 	"field-tue-relative+0": "tänä tiistaina",
 	"field-year-narrow-relative+1": "ensi v",
 	"field-tue-relative+1": "ensi tiistaina",
+	"field-weekdayOfMonth": "kuukauden viikonpäivä",
 	"field-second-short": "s",
 	"dayPeriods-format-narrow-am": "ap.",
 	"dateFormatItem-MMMd": "d. MMM",
+	"field-weekdayOfMonth-narrow": "kuukauden vk päivä",
 	"dayPeriods-format-abbr-am": "ap.",
 	"field-week-relative+0": "tällä viikolla",
 	"field-month-relative+0": "tässä kuussa",
@@ -44,11 +48,16 @@ define(
 	"field-mon-short-relative+1": "ensi ma",
 	"field-second-relative+0": "nyt",
 	"dateFormatItem-yyyyQQQ": "QQQ y G",
+	"eraNames": [
+		"hidžran jälkeen"
+	],
+	"field-weekOfMonth": "kuukauden viikko",
 	"dayPeriods-standAlone-abbr-pm": "ip.",
 	"field-month-short": "kk",
 	"dateFormatItem-GyMMMEd": "E d. MMM y G",
 	"dateFormatItem-yyyyMd": "d.M.y G",
 	"field-day": "päivä",
+	"field-dayOfYear-short": "vuodenpv",
 	"field-year-relative+-1": "viime vuonna",
 	"dayPeriods-format-wide-am": "ap.",
 	"field-sat-short-relative+-1": "viime la",
@@ -69,6 +78,7 @@ define(
 		"L"
 	],
 	"dayPeriods-standAlone-wide-pm": "ip.",
+	"dateFormatItem-Ehms": "E h.mm.ss a",
 	"dateFormat-long": "d. MMMM y G",
 	"dateFormatItem-GyMMMd": "d. MMM y G",
 	"field-hour-short-relative+0": "tunnin sisällä",
@@ -122,6 +132,7 @@ define(
 	"field-day-narrow-relative+-2": "toissap.",
 	"field-quarter-relative+-1": "viime neljännesvuonna",
 	"dateFormatItem-yyyyMMMd": "d. MMM y G",
+	"field-dayperiod-narrow": "vuorokaudenaika",
 	"dayPeriods-standAlone-narrow-am": "ap.",
 	"field-week-narrow-relative+-1": "viime vk",
 	"days-format-short": [
@@ -134,6 +145,7 @@ define(
 		"la"
 	],
 	"dayPeriods-format-wide-pm": "ip.",
+	"field-dayOfYear": "vuodenpäivä",
 	"field-sat-relative+-1": "viime lauantaina",
 	"dateTimeFormat-long": "{1} 'klo' {0}",
 	"dateFormatItem-Md": "d.M.",
@@ -161,6 +173,7 @@ define(
 	"field-fri-relative+0": "tänä perjantaina",
 	"field-sat-narrow-relative+1": "ensi la",
 	"field-fri-relative+1": "ensi perjantaina",
+	"dateFormatItem-EBhm": "E h.mm B",
 	"field-month-narrow-relative+0": "tässä kk",
 	"field-month-narrow-relative+1": "ensi kk",
 	"field-sun-short-relative+0": "tänä su",
@@ -168,6 +181,7 @@ define(
 	"field-week-relative+-1": "viime viikolla",
 	"field-quarter-short-relative+-1": "viime neljänneksenä",
 	"field-minute-short-relative+0": "minuutin sisällä",
+	"dateFormatItem-Ehm": "E h.mm a",
 	"months-format-abbr": [
 		"muharram",
 		"safar",
@@ -204,9 +218,10 @@ define(
 	"dateFormatItem-MMMMd": "d. MMMM",
 	"field-thu-narrow-relative+-1": "viime to",
 	"field-tue-narrow-relative+-1": "viime ti",
+	"field-weekOfMonth-short": "kuukauden vk",
 	"dateFormatItem-H": "H",
-	"dateFormatItem-yyyy": "y G",
 	"dayPeriods-standAlone-narrow-pm": "ip.",
+	"dateFormatItem-yyyy": "y G",
 	"field-wed-short-relative+0": "tänä ke",
 	"months-standAlone-wide": [
 		"muharram",
@@ -260,10 +275,13 @@ define(
 		"dhu-l-qa’da",
 		"dhu-l-hiddža"
 	],
+	"field-dayOfYear-narrow": "vuodenpv",
 	"field-month-short-relative+0": "tässä kk",
 	"field-month-short-relative+1": "ensi kk",
+	"field-weekdayOfMonth-short": "kuukauden vk päivä",
 	"timeFormat-full": "H.mm.ss zzzz",
 	"dateFormatItem-MEd": "E d.M.",
+	"field-zone-narrow": "aikavyöhyke",
 	"dateFormatItem-y": "y G",
 	"field-thu-narrow-relative+0": "tänä to",
 	"field-thu-narrow-relative+1": "ensi to",
@@ -286,6 +304,7 @@ define(
 	"field-wed-narrow-relative+1": "ensi ke",
 	"field-quarter-narrow-relative+-1": "viime nelj.",
 	"field-year-short-relative+0": "tänä v",
+	"field-dayperiod-short": "vuorokaudenaika",
 	"dateFormatItem-yyyyMMM": "LLL y G",
 	"field-year-short-relative+1": "ensi v",
 	"field-fri-short-relative+0": "tänä pe",
@@ -303,6 +322,7 @@ define(
 	"field-hour-narrow-relative+0": "tunnin sisällä",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
 	"field-hour-short": "t",
+	"field-zone-short": "aikavyöhyke",
 	"quarters-format-abbr": [
 		"1. nelj.",
 		"2. nelj.",
@@ -314,7 +334,9 @@ define(
 	"field-fri-narrow-relative+-1": "viime pe",
 	"field-year-relative+0": "tänä vuonna",
 	"field-year-relative+1": "ensi vuonna",
+	"field-era-narrow": "aikakausi",
 	"field-fri-relative+-1": "viime perjantaina",
+	"dateFormatItem-Bhms": "h.mm.ss B",
 	"field-tue-short-relative+-1": "viime ti",
 	"field-minute-narrow": "min",
 	"days-format-wide": [
@@ -328,14 +350,19 @@ define(
 	],
 	"field-mon-narrow-relative+0": "tänä ma",
 	"field-mon-narrow-relative+1": "ensi ma",
+	"dateFormatItem-EHm": "E HH.mm",
 	"field-year-short-relative+-1": "viime v",
 	"field-zone": "aikavyöhyke",
 	"dateFormatItem-MMMEd": "ccc d. MMM",
+	"field-weekOfMonth-narrow": "kuukauden vk",
+	"dateFormatItem-EHms": "E HH.mm.ss",
+	"field-weekday-narrow": "viikonpäivä",
 	"field-quarter-narrow": "nelj.",
 	"field-sun-short-relative+-1": "viime su",
 	"field-day-relative+-1": "eilen",
 	"dayPeriods-standAlone-abbr-am": "ap.",
 	"field-day-relative+-2": "toissa päivänä",
+	"field-weekday-short": "viikonpäivä",
 	"days-format-abbr": [
 		"su",
 		"ma",
@@ -345,6 +372,7 @@ define(
 		"pe",
 		"la"
 	],
+	"dateFormatItem-Bhm": "h.mm B",
 	"field-sun-relative+0": "tänä sunnuntaina",
 	"field-sun-relative+1": "ensi sunnuntaina",
 	"dateFormatItem-Gy": "y G",
