@@ -1,131 +1,184 @@
 define(
 //begin v1.x content
 {
-	"field-second-relative+0": "maintenant",
-	"field-quarter-relative+-1": "le trimestre dernier",
-	"field-weekday": "jour de la semaine",
-	"field-mon-narrow-relative+0": "ce lun",
-	"field-mon-narrow-relative+1": "lun proch",
+	"field-quarter-short-relative+0": "ce trim.",
+	"field-quarter-short-relative+1": "le trim. proch.",
+	"field-tue-relative+-1": "mardi dernier",
+	"field-year": "année",
 	"field-wed-relative+0": "ce mercredi",
 	"field-wed-relative+1": "mercredi prochain",
-	"field-week-short": "sem.",
-	"field-tue-relative+-1": "mardi dernier",
-	"field-year-short": "an",
-	"field-thu-narrow-relative+-1": "jeu dern",
-	"field-hour-relative+0": "cette heure-ci",
-	"field-quarter-narrow": "trim.",
-	"field-fri-relative+-1": "vendredi dernier",
-	"field-hour-short": "h",
-	"field-wed-relative+-1": "mercredi dernier",
-	"field-mon-short-relative+-1": "lun. dernier",
-	"field-thu-relative+-1": "jeudi dernier",
-	"field-era": "ère",
-	"field-sat-narrow-relative+0": "ce sam",
-	"field-sat-narrow-relative+1": "sam proch",
-	"field-year": "année",
-	"field-hour": "heure",
-	"field-sat-relative+0": "ce samedi",
-	"field-sat-relative+1": "samedi prochain",
-	"field-sat-short-relative+-1": "sam. dernier",
-	"field-minute-narrow": "min",
+	"field-minute": "minute",
+	"field-month-narrow-relative+-1": "le mois dernier",
+	"field-tue-narrow-relative+0": "ce mar.",
+	"field-tue-narrow-relative+1": "mar. prochain",
+	"field-thu-short-relative+0": "ce jeu.",
+	"field-day-short-relative+-1": "hier",
+	"field-thu-short-relative+1": "jeu. prochain",
 	"field-day-relative+0": "aujourd’hui",
+	"field-day-short-relative+-2": "avant-hier",
 	"field-day-relative+1": "demain",
-	"field-thu-relative+0": "ce jeudi",
-	"field-mon-narrow-relative+-1": "lun dern",
+	"field-week-narrow-relative+0": "cette semaine",
 	"field-day-relative+2": "après-demain",
-	"field-wed-narrow-relative+0": "ce mer",
-	"field-thu-relative+1": "jeudi prochain",
-	"field-wed-narrow-relative+1": "mer proch",
-	"field-mon-short-relative+0": "ce lun.",
-	"field-mon-short-relative+1": "lun. prochain",
-	"field-wed-short-relative+-1": "mer. dernier",
-	"field-fri-narrow-relative+-1": "ven dern",
-	"field-hour-narrow": "h",
-	"field-tue-short-relative+0": "ce mar.",
+	"field-week-narrow-relative+1": "la semaine prochaine",
+	"field-wed-narrow-relative+-1": "mer. dernier",
 	"field-year-narrow": "a",
-	"field-tue-short-relative+1": "mar. prochain",
-	"field-minute-short": "min",
-	"field-day-narrow": "j",
-	"field-wed-short-relative+0": "ce mer.",
-	"field-wed-short-relative+1": "mer. prochain",
-	"field-sun-relative+0": "ce dimanche",
-	"field-sun-relative+1": "dimanche prochain",
-	"eraAbbr": [
+	"field-era-short": "ère",
+	"field-year-narrow-relative+0": "cette année",
+	"field-tue-relative+0": "ce mardi",
+	"field-year-narrow-relative+1": "l’année prochaine",
+	"field-tue-relative+1": "mardi prochain",
+	"field-weekdayOfMonth": "jour (mois)",
+	"field-second-short": "s",
+	"field-weekdayOfMonth-narrow": "jour (mois)",
+	"field-week-relative+0": "cette semaine",
+	"field-month-relative+0": "ce mois-ci",
+	"field-week-relative+1": "la semaine prochaine",
+	"field-month-relative+1": "le mois prochain",
+	"field-sun-narrow-relative+0": "ce dim.",
+	"field-mon-short-relative+0": "ce lun.",
+	"field-sun-narrow-relative+1": "dim. prochain",
+	"field-mon-short-relative+1": "lun. prochain",
+	"field-second-relative+0": "maintenant",
+	"eraNames": [
 		"avant RdC",
 		"RdC"
 	],
-	"field-minute": "minute",
+	"field-weekOfMonth": "semaine (mois)",
 	"field-month-short": "m.",
-	"field-dayperiod": "cadran",
-	"field-day-relative+-1": "hier",
-	"field-day-relative+-2": "avant-hier",
-	"field-minute-relative+0": "cette minute-ci",
-	"field-week-narrow": "sem.",
-	"field-wed-narrow-relative+-1": "mer dern",
-	"field-day-short": "j",
-	"field-quarter-relative+0": "ce trimestre",
-	"field-quarter-relative+1": "le trimestre prochain",
-	"field-fri-relative+0": "ce vendredi",
-	"field-fri-relative+1": "vendredi prochain",
 	"field-day": "jour",
-	"field-second-narrow": "s",
-	"field-zone": "fuseau horaire",
+	"field-dayOfYear-short": "j (an)",
 	"field-year-relative+-1": "l’année dernière",
-	"field-minute-narrow-relative+0": "cette min",
-	"field-month-relative+-1": "le mois dernier",
-	"field-thu-short-relative+0": "ce jeu.",
-	"field-thu-short-relative+1": "jeu. prochain",
-	"field-minute-short-relative+0": "cette min",
-	"field-quarter-narrow-relative+0": "ce trim",
-	"field-quarter-narrow-relative+1": "trim proch",
-	"field-quarter": "trimestre",
-	"field-month": "mois",
-	"field-tue-relative+0": "ce mardi",
-	"field-quarter-short-relative+0": "ce trim.",
-	"field-tue-relative+1": "mardi prochain",
-	"field-quarter-short-relative+1": "le trim. proch.",
-	"field-fri-narrow-relative+0": "ce ven",
-	"field-fri-narrow-relative+1": "ven proch",
-	"field-hour-short-relative+0": "cette h",
-	"field-fri-short-relative+-1": "ven. dernier",
-	"field-sun-narrow-relative+-1": "dim dern",
-	"field-quarter-short-relative+-1": "le trim. dern.",
-	"field-sun-narrow-relative+0": "ce dim",
-	"field-thu-narrow-relative+0": "ce jeu",
-	"field-sun-narrow-relative+1": "dim proch",
-	"field-thu-narrow-relative+1": "jeu proch",
-	"field-tue-narrow-relative+0": "ce mar",
-	"field-mon-relative+0": "ce lundi",
-	"field-tue-narrow-relative+1": "mar proch",
-	"field-mon-relative+1": "lundi prochain",
-	"field-tue-narrow-relative+-1": "mar dern",
-	"field-second-short": "s",
+	"field-sat-short-relative+-1": "sam. dernier",
+	"field-hour-relative+0": "cette heure-ci",
+	"field-wed-relative+-1": "mercredi dernier",
+	"field-sat-narrow-relative+-1": "sam. dernier",
 	"field-second": "seconde",
-	"field-fri-short-relative+0": "ce ven.",
-	"field-sat-relative+-1": "samedi dernier",
-	"field-fri-short-relative+1": "ven. prochain",
-	"field-sun-relative+-1": "dimanche dernier",
-	"field-month-relative+0": "ce mois-ci",
-	"field-quarter-narrow-relative+-1": "trim dern",
-	"field-month-relative+1": "le mois prochain",
-	"field-week": "semaine",
+	"field-hour-short-relative+0": "cette h",
+	"field-quarter": "trimestre",
+	"field-week-short": "sem.",
+	"field-day-narrow-relative+0": "aujourd’hui",
+	"field-day-narrow-relative+1": "demain",
+	"field-day-narrow-relative+2": "après-demain",
+	"field-tue-short-relative+0": "ce mar.",
+	"field-tue-short-relative+1": "mar. prochain",
+	"field-month-short-relative+-1": "le mois dernier",
+	"field-mon-relative+-1": "lundi dernier",
+	"field-month": "mois",
+	"field-day-narrow": "j",
+	"field-minute-short": "min",
+	"field-dayperiod": "cadran",
 	"field-sat-short-relative+0": "ce sam.",
 	"field-sat-short-relative+1": "sam. prochain",
-	"field-hour-narrow-relative+0": "cette h",
-	"field-year-relative+0": "cette année",
-	"field-week-relative+-1": "la semaine dernière",
-	"field-year-relative+1": "l’année prochaine",
+	"eraAbbr": [
+		"av. RdC",
+		"RdC"
+	],
+	"field-second-narrow": "s",
+	"field-mon-relative+0": "ce lundi",
+	"field-mon-relative+1": "lundi prochain",
+	"field-day-narrow-relative+-1": "hier",
+	"field-year-short": "an",
+	"field-day-narrow-relative+-2": "avant-hier",
+	"field-quarter-relative+-1": "le trimestre dernier",
+	"field-dayperiod-narrow": "cadran",
+	"field-week-narrow-relative+-1": "la semaine dernière",
+	"field-dayOfYear": "jour (année)",
+	"field-sat-relative+-1": "samedi dernier",
+	"field-hour": "heure",
+	"field-minute-narrow-relative+0": "cette min",
+	"field-month-relative+-1": "le mois dernier",
 	"field-quarter-short": "trim.",
-	"field-sun-short-relative+-1": "dim. dernier",
-	"field-thu-short-relative+-1": "jeu. dernier",
-	"field-tue-short-relative+-1": "mar. dernier",
-	"field-mon-relative+-1": "lundi dernier",
-	"field-sat-narrow-relative+-1": "sam dern",
-	"field-month-narrow": "m.",
-	"field-week-relative+0": "cette semaine",
+	"field-sat-narrow-relative+0": "ce sam.",
+	"field-fri-relative+0": "ce vendredi",
+	"field-sat-narrow-relative+1": "sam. prochain",
+	"field-fri-relative+1": "vendredi prochain",
+	"field-month-narrow-relative+0": "ce mois-ci",
+	"field-month-narrow-relative+1": "le mois prochain",
 	"field-sun-short-relative+0": "ce dim.",
-	"field-week-relative+1": "la semaine prochaine",
-	"field-sun-short-relative+1": "dim. prochain"
+	"field-sun-short-relative+1": "dim. prochain",
+	"field-week-relative+-1": "la semaine dernière",
+	"field-quarter-short-relative+-1": "le trim. dern.",
+	"field-minute-short-relative+0": "cette min",
+	"field-quarter-relative+0": "ce trimestre",
+	"field-minute-relative+0": "cette minute-ci",
+	"field-quarter-relative+1": "le trimestre prochain",
+	"field-wed-short-relative+-1": "mer. dernier",
+	"field-thu-short-relative+-1": "jeu. dernier",
+	"field-year-narrow-relative+-1": "l’année dernière",
+	"field-mon-narrow-relative+-1": "lun. dernier",
+	"field-thu-narrow-relative+-1": "jeu. dernier",
+	"field-tue-narrow-relative+-1": "mar. dernier",
+	"field-weekOfMonth-short": "sem. (m.)",
+	"field-wed-short-relative+0": "ce mer.",
+	"field-wed-short-relative+1": "mer. prochain",
+	"field-sun-relative+-1": "dimanche dernier",
+	"field-weekday": "jour de la semaine",
+	"field-day-short-relative+0": "aujourd’hui",
+	"field-quarter-narrow-relative+0": "ce trim.",
+	"field-sat-relative+0": "ce samedi",
+	"field-day-short-relative+1": "demain",
+	"field-quarter-narrow-relative+1": "trim. proch.",
+	"field-sat-relative+1": "samedi prochain",
+	"field-day-short-relative+2": "après-demain",
+	"field-week-short-relative+0": "cette semaine",
+	"field-week-short-relative+1": "la semaine prochaine",
+	"field-dayOfYear-narrow": "j (an)",
+	"field-month-short-relative+0": "ce mois-ci",
+	"field-month-short-relative+1": "le mois prochain",
+	"field-weekdayOfMonth-short": "jour (mois)",
+	"field-zone-narrow": "fuseau horaire",
+	"field-thu-narrow-relative+0": "ce jeu.",
+	"field-thu-narrow-relative+1": "jeu. prochain",
+	"field-sun-narrow-relative+-1": "dim. dernier",
+	"field-mon-short-relative+-1": "lun. dernier",
+	"field-thu-relative+0": "ce jeudi",
+	"field-thu-relative+1": "jeudi prochain",
+	"field-fri-short-relative+-1": "ven. dernier",
+	"field-thu-relative+-1": "jeudi dernier",
+	"field-week": "semaine",
+	"field-wed-narrow-relative+0": "ce mer.",
+	"field-wed-narrow-relative+1": "mer. prochain",
+	"field-quarter-narrow-relative+-1": "trim. dern.",
+	"field-year-short-relative+0": "cette année",
+	"field-dayperiod-short": "cadran",
+	"field-year-short-relative+1": "l’année prochaine",
+	"field-fri-short-relative+0": "ce ven.",
+	"field-fri-short-relative+1": "ven. prochain",
+	"field-week-short-relative+-1": "la semaine dernière",
+	"field-hour-narrow-relative+0": "cette h",
+	"field-hour-short": "h",
+	"field-zone-short": "fuseau horaire",
+	"field-month-narrow": "m.",
+	"field-hour-narrow": "h",
+	"field-fri-narrow-relative+-1": "ven. dernier",
+	"field-year-relative+0": "cette année",
+	"field-year-relative+1": "l’année prochaine",
+	"field-era-narrow": "ère",
+	"field-fri-relative+-1": "vendredi dernier",
+	"eraNarrow": [
+		"av. RdC",
+		"RdC"
+	],
+	"field-tue-short-relative+-1": "mar. dernier",
+	"field-minute-narrow": "min",
+	"field-mon-narrow-relative+0": "ce lun.",
+	"field-mon-narrow-relative+1": "lun. prochain",
+	"field-year-short-relative+-1": "l’année dernière",
+	"field-zone": "fuseau horaire",
+	"field-weekOfMonth-narrow": "sem. (m.)",
+	"field-weekday-narrow": "j (sem.)",
+	"field-quarter-narrow": "trim.",
+	"field-sun-short-relative+-1": "dim. dernier",
+	"field-day-relative+-1": "hier",
+	"field-day-relative+-2": "avant-hier",
+	"field-weekday-short": "j (sem.)",
+	"field-sun-relative+0": "ce dimanche",
+	"field-sun-relative+1": "dimanche prochain",
+	"field-day-short": "j",
+	"field-week-narrow": "sem.",
+	"field-era": "ère",
+	"field-fri-narrow-relative+0": "ce ven.",
+	"field-fri-narrow-relative+1": "ven. prochain"
 }
 //end v1.x content
 );
\ No newline at end of file
