@@ -7,7 +7,7 @@ define({ root:
 	"field-quarter-short-relative+1": "next quarter",
 	"field-tue-relative+-1": "last Tuesday",
 	"field-year": "Year",
-	"dateFormatItem-yw": "'week' w 'of' y",
+	"dateFormatItem-yw": "'week' w 'of' Y",
 	"dateFormatItem-Hm": "HH:mm",
 	"field-wed-relative+0": "this Wednesday",
 	"field-wed-relative+1": "next Wednesday",
@@ -26,14 +26,18 @@ define({ root:
 	"field-week-narrow-relative+0": "this week",
 	"field-week-narrow-relative+1": "next week",
 	"field-wed-narrow-relative+-1": "last Wednesday",
+	"dateFormatItem-EBhms": "E h:mm:ss B",
 	"field-year-narrow": "Year",
+	"field-era-short": "Era",
 	"field-year-narrow-relative+0": "this year",
 	"field-tue-relative+0": "this Tuesday",
 	"field-year-narrow-relative+1": "next year",
 	"field-tue-relative+1": "next Tuesday",
+	"field-weekdayOfMonth": "Weekday Of Month",
 	"field-second-short": "Second",
 	"dayPeriods-format-narrow-am": "AM",
 	"dateFormatItem-MMMd": "MMM d",
+	"field-weekdayOfMonth-narrow": "Weekday Of Month",
 	"dayPeriods-format-abbr-am": "AM",
 	"field-week-relative+0": "this week",
 	"field-month-relative+0": "this month",
@@ -64,10 +68,12 @@ define({ root:
 		"BCE",
 		"CE"
 	],
+	"field-weekOfMonth": "Week Of Month",
 	"dayPeriods-standAlone-abbr-pm": "PM",
 	"field-month-short": "Month",
 	"dateFormatItem-GyMMMEd": "G y MMM d, E",
 	"field-day": "Day",
+	"field-dayOfYear-short": "Day Of Year",
 	"field-year-relative+-1": "last year",
 	"dayPeriods-format-wide-am": "AM",
 	"field-sat-short-relative+-1": "last Saturday",
@@ -157,6 +163,7 @@ define({ root:
 		"12"
 	],
 	"field-quarter-relative+-1": "last quarter",
+	"field-dayperiod-narrow": "Dayperiod",
 	"dayPeriods-standAlone-narrow-am": "AM",
 	"field-week-narrow-relative+-1": "last week",
 	"days-format-short": [
@@ -175,6 +182,7 @@ define({ root:
 		"4"
 	],
 	"dayPeriods-format-wide-pm": "PM",
+	"field-dayOfYear": "Day Of Year",
 	"field-sat-relative+-1": "last Saturday",
 	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
 	"dateTimeFormat-long": "{1} {0}",
@@ -205,6 +213,7 @@ define({ root:
 	"field-fri-relative+0": "this Friday",
 	"field-sat-narrow-relative+1": "next Saturday",
 	"field-fri-relative+1": "next Friday",
+	"dateFormatItem-EBhm": "E h:mm B",
 	"field-month-narrow-relative+0": "this month",
 	"field-month-narrow-relative+1": "next month",
 	"field-sun-short-relative+0": "this Sunday",
@@ -235,9 +244,10 @@ define({ root:
 	"field-wed-short-relative+-1": "last Wednesday",
 	"dateFormatItem-yMMM": "y MMM",
 	"dateFormat-short": "y-MM-dd",
+	"dateFormatItem-Bh": "h B",
 	"field-thu-short-relative+-1": "last Thursday",
 	"field-year-narrow-relative+-1": "last year",
-	"dateFormatItem-MMMMW": "'week' W 'of' MMM",
+	"dateFormatItem-MMMMW": "'week' W 'of' MMMM",
 	"days-standAlone-wide": [
 		"Sun",
 		"Mon",
@@ -254,6 +264,7 @@ define({ root:
 	"dateFormatItem-E": "ccc",
 	"field-tue-narrow-relative+-1": "last Tuesday",
 	"dateFormatItem-H": "HH",
+	"field-weekOfMonth-short": "Week Of Month",
 	"dayPeriods-standAlone-narrow-pm": "PM",
 	"field-wed-short-relative+0": "this Wednesday",
 	"dateFormatItem-M": "L",
@@ -312,10 +323,13 @@ define({ root:
 		"M11",
 		"M12"
 	],
+	"field-dayOfYear-narrow": "Day Of Year",
 	"field-month-short-relative+0": "this month",
 	"field-month-short-relative+1": "next month",
+	"field-weekdayOfMonth-short": "Weekday Of Month",
 	"timeFormat-full": "HH:mm:ss zzzz",
 	"dateFormatItem-MEd": "MM-dd, E",
+	"field-zone-narrow": "Zone",
 	"dateFormatItem-y": "y",
 	"field-thu-narrow-relative+0": "this Thursday",
 	"field-thu-narrow-relative+1": "next Thursday",
@@ -348,6 +362,7 @@ define({ root:
 	"field-wed-narrow-relative+1": "next Wednesday",
 	"field-quarter-narrow-relative+-1": "last quarter",
 	"field-year-short-relative+0": "this year",
+	"field-dayperiod-short": "Dayperiod",
 	"field-year-short-relative+1": "next year",
 	"field-fri-short-relative+0": "this Friday",
 	"field-fri-short-relative+1": "next Friday",
@@ -363,6 +378,7 @@ define({ root:
 	],
 	"field-week-short-relative+-1": "last week",
 	"field-hour-narrow-relative+0": "this hour",
+	"field-zone-short": "Zone",
 	"field-hour-short": "Hour",
 	"quarters-format-abbr": [
 		"Q1",
@@ -375,11 +391,13 @@ define({ root:
 	"field-fri-narrow-relative+-1": "last Friday",
 	"field-year-relative+0": "this year",
 	"field-year-relative+1": "next year",
+	"field-era-narrow": "Era",
 	"field-fri-relative+-1": "last Friday",
 	"eraNarrow": [
 		"BCE",
 		"CE"
 	],
+	"dateFormatItem-Bhms": "h:mm:ss B",
 	"field-tue-short-relative+-1": "last Tuesday",
 	"field-minute-narrow": "Minute",
 	"dateFormatItem-yQQQ": "y QQQ",
@@ -401,12 +419,16 @@ define({ root:
 	"dateFormatItem-yM": "y-MM",
 	"dateFormatItem-yMMMM": "y MMMM",
 	"dateFormatItem-MMMEd": "MMM d, E",
+	"field-weekOfMonth-narrow": "Week Of Month",
 	"dateFormatItem-yMEd": "y-MM-dd, E",
 	"dateFormatItem-EHms": "E HH:mm:ss",
+	"field-weekday-narrow": "Day of the Week",
 	"field-quarter-narrow": "Quarter",
 	"field-sun-short-relative+-1": "last Sunday",
 	"field-day-relative+-1": "yesterday",
 	"dayPeriods-standAlone-abbr-am": "AM",
+	"field-weekday-short": "Day of the Week",
+	"dateFormatItem-Bhm": "h:mm B",
 	"days-format-abbr": [
 		"Sun",
 		"Mon",
