@@ -1,55 +1,68 @@
 define(
 //begin v1.x content
 {
-	"field-second-relative+0": "עכשיו",
-	"field-quarter-relative+-1": "הרבעון הקודם",
-	"field-weekday": "יום בשבוע",
-	"field-mon-narrow-relative+0": "יום ב׳",
-	"field-mon-narrow-relative+1": "יום ב׳ הבא",
+	"field-quarter-short-relative+0": "רבעון זה",
+	"field-quarter-short-relative+1": "הרבעון הבא",
+	"field-tue-relative+-1": "יום שלישי שעבר",
+	"field-year": "שנה",
 	"field-wed-relative+0": "יום רביעי",
 	"field-wed-relative+1": "יום רביעי הבא",
-	"field-week-short": "שב׳",
-	"field-tue-relative+-1": "יום שלישי שעבר",
-	"field-year-short": "שנ׳",
-	"field-thu-narrow-relative+-1": "יום ה׳ שעבר",
-	"field-hour-relative+0": "בשעה זו",
-	"field-quarter-narrow": "רבע׳",
-	"field-fri-relative+-1": "יום שישי שעבר",
-	"field-hour-short": "שעה",
-	"field-wed-relative+-1": "יום רביעי שעבר",
-	"field-mon-short-relative+-1": "יום ב׳ שעבר",
-	"field-thu-relative+-1": "יום חמישי שעבר",
-	"field-era": "תקופה",
-	"field-sat-narrow-relative+0": "שבת",
-	"field-sat-narrow-relative+1": "שבת הבאה",
-	"field-year": "שנה",
-	"field-hour": "שעה",
-	"field-sat-relative+0": "יום שבת",
-	"field-sat-relative+1": "יום שבת הבא",
-	"field-sat-short-relative+-1": "שבת שעברה",
-	"field-minute-narrow": "דק׳",
+	"field-minute": "דקה",
+	"field-month-narrow-relative+-1": "החודש שעבר",
+	"field-tue-narrow-relative+0": "יום ג׳",
+	"field-tue-narrow-relative+1": "יום ג׳ הבא",
+	"field-thu-short-relative+0": "יום ה׳",
+	"field-day-short-relative+-1": "אתמול",
+	"field-thu-short-relative+1": "יום ה׳ הבא",
 	"field-day-relative+0": "היום",
+	"field-day-short-relative+-2": "שלשום",
 	"field-day-relative+1": "מחר",
-	"field-thu-relative+0": "יום חמישי",
-	"field-wed-narrow-relative+0": "יום ד׳",
-	"field-mon-narrow-relative+-1": "יום ב׳ שעבר",
+	"field-week-narrow-relative+0": "השבוע",
 	"field-day-relative+2": "מחרתיים",
-	"field-thu-relative+1": "יום חמישי הבא",
-	"field-wed-narrow-relative+1": "יום ד׳ הבא",
-	"field-mon-short-relative+0": "יום ב׳",
-	"field-mon-short-relative+1": "יום ב׳ הבא",
-	"field-wed-short-relative+-1": "יום ד׳ שעבר",
-	"field-fri-narrow-relative+-1": "יום ו׳ שעבר",
-	"field-hour-narrow": "שע׳",
-	"field-tue-short-relative+0": "יום ג׳",
+	"field-week-narrow-relative+1": "השבוע הבא",
+	"field-wed-narrow-relative+-1": "יום ד׳ שעבר",
 	"field-year-narrow": "שנ׳",
+	"field-era-short": "תקופה",
+	"field-year-narrow-relative+0": "השנה",
+	"field-tue-relative+0": "יום שלישי",
+	"field-year-narrow-relative+1": "השנה הבאה",
+	"field-tue-relative+1": "יום שלישי הבא",
+	"field-weekdayOfMonth": "יום חול בחודש",
+	"field-second-short": "שנ׳",
+	"field-weekdayOfMonth-narrow": "יום בחודש",
+	"field-week-relative+0": "השבוע",
+	"field-month-relative+0": "החודש",
+	"field-week-relative+1": "השבוע הבא",
+	"field-month-relative+1": "החודש הבא",
+	"field-sun-narrow-relative+0": "יום א׳",
+	"field-mon-short-relative+0": "יום ב׳",
+	"field-sun-narrow-relative+1": "יום א׳ הבא",
+	"field-mon-short-relative+1": "יום ב׳ הבא",
+	"field-second-relative+0": "עכשיו",
+	"field-weekOfMonth": "השבוע בחודש",
+	"field-month-short": "חו׳",
+	"field-day": "יום",
+	"field-dayOfYear-short": "יום בשנה",
+	"field-year-relative+-1": "השנה שעברה",
+	"field-sat-short-relative+-1": "שבת שעברה",
+	"field-hour-relative+0": "בשעה זו",
+	"field-wed-relative+-1": "יום רביעי שעבר",
+	"field-sat-narrow-relative+-1": "שבת שעברה",
+	"field-second": "שנייה",
+	"field-quarter": "רבעון",
+	"field-week-short": "שב׳",
+	"field-day-narrow-relative+0": "היום",
+	"field-day-narrow-relative+1": "מחר",
+	"field-tue-short-relative+0": "יום ג׳",
 	"field-tue-short-relative+1": "יום ג׳ הבא",
-	"field-minute-short": "דק׳",
+	"field-month-short-relative+-1": "החודש שעבר",
+	"field-mon-relative+-1": "יום שני שעבר",
+	"field-month": "חודש",
 	"field-day-narrow": "יום",
-	"field-wed-short-relative+0": "יום ד׳",
-	"field-wed-short-relative+1": "יום ד׳ הבא",
-	"field-sun-relative+0": "ביום ראשון הזה",
-	"field-sun-relative+1": "ביום ראשון הבא",
+	"field-minute-short": "דק׳",
+	"field-dayperiod": "לפנה״צ/אחה״צ",
+	"field-sat-short-relative+0": "שבת",
+	"field-sat-short-relative+1": "שבת הבאה",
 	"eraAbbr": [
 		"טאיקה",
 		null,
@@ -126,68 +139,105 @@ define(
 		null,
 		"שוטוקו"
 	],
-	"field-minute": "דקה",
-	"field-month-short": "חו׳",
-	"field-dayperiod": "לפנה״צ/אחה״צ",
+	"field-second-narrow": "שנ׳",
+	"field-mon-relative+0": "יום שני",
+	"field-mon-relative+1": "יום שני הבא",
+	"field-day-narrow-relative+-1": "אתמול",
+	"field-year-short": "שנ׳",
+	"field-day-narrow-relative+-2": "שלשום",
+	"field-quarter-relative+-1": "הרבעון הקודם",
+	"field-dayperiod-narrow": "AM/PM",
+	"field-week-narrow-relative+-1": "השבוע שעבר",
+	"field-dayOfYear": "יום בשנה",
+	"field-sat-relative+-1": "יום שבת שעבר",
+	"field-hour": "שעה",
+	"field-month-relative+-1": "החודש שעבר",
+	"field-quarter-short": "רבע׳",
+	"field-sat-narrow-relative+0": "שבת",
+	"field-fri-relative+0": "יום שישי",
+	"field-sat-narrow-relative+1": "שבת הבאה",
+	"field-fri-relative+1": "יום שישי הבא",
+	"field-month-narrow-relative+0": "החודש",
+	"field-month-narrow-relative+1": "החודש הבא",
+	"field-sun-short-relative+0": "יום א׳",
+	"field-sun-short-relative+1": "יום א׳ הבא",
+	"field-week-relative+-1": "השבוע שעבר",
+	"field-quarter-short-relative+-1": "הרבעון הקודם",
+	"field-quarter-relative+0": "רבעון זה",
+	"field-minute-relative+0": "בדקה זו",
+	"field-quarter-relative+1": "הרבעון הבא",
+	"field-wed-short-relative+-1": "יום ד׳ שעבר",
+	"field-thu-short-relative+-1": "יום ה׳ שעבר",
+	"field-year-narrow-relative+-1": "השנה שעברה",
+	"field-mon-narrow-relative+-1": "יום ב׳ שעבר",
+	"field-thu-narrow-relative+-1": "יום ה׳ שעבר",
+	"field-tue-narrow-relative+-1": "יום ג׳ שעבר",
+	"field-weekOfMonth-short": "השבוע בחודש",
+	"field-wed-short-relative+0": "יום ד׳",
+	"field-wed-short-relative+1": "יום ד׳ הבא",
+	"field-sun-relative+-1": "ביום ראשון שעבר",
+	"field-weekday": "יום בשבוע",
+	"field-day-short-relative+0": "היום",
+	"field-quarter-narrow-relative+0": "רבעון זה",
+	"field-sat-relative+0": "יום שבת",
+	"field-day-short-relative+1": "מחר",
+	"field-quarter-narrow-relative+1": "הרבעון הבא",
+	"field-sat-relative+1": "יום שבת הבא",
+	"field-day-short-relative+2": "מחרתיים",
+	"field-week-short-relative+0": "השבוע",
+	"field-week-short-relative+1": "השבוע הבא",
+	"field-dayOfYear-narrow": "יום בשנה",
+	"field-month-short-relative+0": "החודש",
+	"field-month-short-relative+1": "החודש הבא",
+	"field-weekdayOfMonth-short": "יום בחודש",
+	"field-zone-narrow": "אזור",
+	"field-thu-narrow-relative+0": "יום ה׳",
+	"field-thu-narrow-relative+1": "יום ה׳ הבא",
+	"field-sun-narrow-relative+-1": "יום א׳ שעבר",
+	"field-mon-short-relative+-1": "יום ב׳ שעבר",
+	"field-thu-relative+0": "יום חמישי",
+	"field-thu-relative+1": "יום חמישי הבא",
+	"field-fri-short-relative+-1": "יום ו׳ שעבר",
+	"field-thu-relative+-1": "יום חמישי שעבר",
+	"field-week": "שבוע",
+	"field-wed-narrow-relative+0": "יום ד׳",
+	"field-wed-narrow-relative+1": "יום ד׳ הבא",
+	"field-quarter-narrow-relative+-1": "הרבעון הקודם",
+	"field-year-short-relative+0": "השנה",
+	"field-dayperiod-short": "AM/PM",
+	"field-year-short-relative+1": "השנה הבאה",
+	"field-fri-short-relative+0": "יום ו׳",
+	"field-fri-short-relative+1": "יום ו׳ הבא",
+	"field-week-short-relative+-1": "השבוע שעבר",
+	"field-hour-short": "שעה",
+	"field-zone-short": "אזור",
+	"field-month-narrow": "חו׳",
+	"field-hour-narrow": "שע׳",
+	"field-fri-narrow-relative+-1": "יום ו׳ שעבר",
+	"field-year-relative+0": "השנה",
+	"field-year-relative+1": "השנה הבאה",
+	"field-era-narrow": "תקופה",
+	"field-fri-relative+-1": "יום שישי שעבר",
+	"field-tue-short-relative+-1": "יום ג׳ שעבר",
+	"field-minute-narrow": "דק׳",
+	"field-mon-narrow-relative+0": "יום ב׳",
+	"field-mon-narrow-relative+1": "יום ב׳ הבא",
+	"field-year-short-relative+-1": "השנה שעברה",
+	"field-zone": "אזור זמן",
+	"field-weekOfMonth-narrow": "השבוע בחודש",
+	"field-weekday-narrow": "יום בשבוע",
+	"field-quarter-narrow": "רבע׳",
+	"field-sun-short-relative+-1": "יום א׳ שעבר",
 	"field-day-relative+-1": "אתמול",
 	"field-day-relative+-2": "שלשום",
-	"field-minute-relative+0": "בדקה זו",
-	"field-week-narrow": "שב׳",
-	"field-wed-narrow-relative+-1": "יום ד׳ שעבר",
+	"field-weekday-short": "יום בשבוע",
+	"field-sun-relative+0": "ביום ראשון הזה",
+	"field-sun-relative+1": "ביום ראשון הבא",
 	"field-day-short": "יום",
-	"field-quarter-relative+0": "רבעון זה",
-	"field-quarter-relative+1": "הרבעון הבא",
-	"field-fri-relative+0": "יום שישי",
-	"field-fri-relative+1": "יום שישי הבא",
-	"field-day": "יום",
-	"field-second-narrow": "שנ׳",
-	"field-zone": "אזור",
-	"field-year-relative+-1": "השנה שעברה",
-	"field-month-relative+-1": "החודש שעבר",
-	"field-thu-short-relative+0": "יום ה׳",
-	"field-thu-short-relative+1": "יום ה׳ הבא",
-	"field-quarter": "רבעון",
-	"field-month": "חודש",
-	"field-tue-relative+0": "יום שלישי",
-	"field-tue-relative+1": "יום שלישי הבא",
+	"field-week-narrow": "שב׳",
+	"field-era": "תקופה",
 	"field-fri-narrow-relative+0": "יום ו׳",
-	"field-fri-narrow-relative+1": "יום ו׳ הבא",
-	"field-fri-short-relative+-1": "יום ו׳ שעבר",
-	"field-sun-narrow-relative+-1": "יום א׳ שעבר",
-	"field-sun-narrow-relative+0": "יום א׳",
-	"field-thu-narrow-relative+0": "יום ה׳",
-	"field-sun-narrow-relative+1": "יום א׳ הבא",
-	"field-thu-narrow-relative+1": "יום ה׳ הבא",
-	"field-tue-narrow-relative+0": "יום ג׳",
-	"field-mon-relative+0": "יום שני",
-	"field-tue-narrow-relative+1": "יום ג׳ הבא",
-	"field-mon-relative+1": "יום שני הבא",
-	"field-tue-narrow-relative+-1": "יום ג׳ שעבר",
-	"field-second-short": "שנ׳",
-	"field-second": "שנייה",
-	"field-fri-short-relative+0": "יום ו׳",
-	"field-sat-relative+-1": "יום שבת שעבר",
-	"field-fri-short-relative+1": "ביום ו׳ הבא",
-	"field-sun-relative+-1": "ביום ראשון שעבר",
-	"field-month-relative+0": "החודש",
-	"field-month-relative+1": "החודש הבא",
-	"field-week": "שבוע",
-	"field-sat-short-relative+0": "שבת",
-	"field-sat-short-relative+1": "שבת הבאה",
-	"field-year-relative+0": "השנה",
-	"field-week-relative+-1": "השבוע שעבר",
-	"field-year-relative+1": "השנה הבאה",
-	"field-quarter-short": "רבע׳",
-	"field-sun-short-relative+-1": "יום א׳ שעבר",
-	"field-thu-short-relative+-1": "יום ה׳ שעבר",
-	"field-tue-short-relative+-1": "יום ג׳ שעבר",
-	"field-mon-relative+-1": "יום שני שעבר",
-	"field-sat-narrow-relative+-1": "שבת שעברה",
-	"field-month-narrow": "חו׳",
-	"field-week-relative+0": "השבוע",
-	"field-sun-short-relative+0": "יום א׳",
-	"field-week-relative+1": "השבוע הבא",
-	"field-sun-short-relative+1": "יום א׳ הבא"
+	"field-fri-narrow-relative+1": "יום ו׳ הבא"
 }
 //end v1.x content
 );
\ No newline at end of file
