@@ -22,11 +22,14 @@ define(
 	"field-week-narrow-relative+1": "sljedeći tj.",
 	"field-wed-narrow-relative+-1": "prošla sri.",
 	"field-year-narrow": "g.",
+	"field-era-short": "era",
 	"field-year-narrow-relative+0": "ove g.",
 	"field-tue-relative+0": "ovaj utorak",
 	"field-year-narrow-relative+1": "sljedeće g.",
 	"field-tue-relative+1": "sljedeći utorak",
+	"field-weekdayOfMonth": "radni dan u mjesecu",
 	"field-second-short": "s",
+	"field-weekdayOfMonth-narrow": "r. dan u mj.",
 	"field-week-relative+0": "ovaj tjedan",
 	"field-month-relative+0": "ovaj mjesec",
 	"field-week-relative+1": "sljedeći tjedan",
@@ -36,8 +39,10 @@ define(
 	"field-sun-narrow-relative+1": "sljedeća ned.",
 	"field-mon-short-relative+1": "sljedeći pon.",
 	"field-second-relative+0": "sad",
+	"field-weekOfMonth": "tjedan u mjesecu",
 	"field-month-short": "mj.",
 	"field-day": "dan",
+	"field-dayOfYear-short": "dan u god.",
 	"field-year-relative+-1": "prošle godine",
 	"field-sat-short-relative+-1": "prošla sub.",
 	"field-hour-relative+0": "ovaj sat",
@@ -68,7 +73,9 @@ define(
 	"field-year-short": "g.",
 	"field-day-narrow-relative+-2": "prekjučer",
 	"field-quarter-relative+-1": "prošli kvartal",
+	"field-dayperiod-narrow": "AM/PM",
 	"field-week-narrow-relative+-1": "prošli tj.",
+	"field-dayOfYear": "dan u godini",
 	"field-sat-relative+-1": "prošla subota",
 	"field-hour": "sat",
 	"dateFormat-full": "E, d. M. y.",
@@ -94,6 +101,7 @@ define(
 	"field-mon-narrow-relative+-1": "prošli pon.",
 	"field-thu-narrow-relative+-1": "prošli čet.",
 	"field-tue-narrow-relative+-1": "prošli uto.",
+	"field-weekOfMonth-short": "tj. u mj.",
 	"field-wed-short-relative+0": "ova sri.",
 	"field-wed-short-relative+1": "sljedeća sri.",
 	"field-sun-relative+-1": "prošla nedjelja",
@@ -107,8 +115,11 @@ define(
 	"field-day-short-relative+2": "prekosutra",
 	"field-week-short-relative+0": "ovaj tj.",
 	"field-week-short-relative+1": "sljedeći tj.",
+	"field-dayOfYear-narrow": "dan u g.",
 	"field-month-short-relative+0": "ovaj mj.",
 	"field-month-short-relative+1": "sljedeći mj.",
+	"field-weekdayOfMonth-short": "radni dan u mj.",
+	"field-zone-narrow": "zona",
 	"field-thu-narrow-relative+0": "ovaj čet.",
 	"field-thu-narrow-relative+1": "sljedeći čet.",
 	"field-sun-narrow-relative+-1": "prošla ned.",
@@ -122,16 +133,19 @@ define(
 	"field-wed-narrow-relative+1": "sljedeća sri.",
 	"field-quarter-narrow-relative+-1": "prošli kv.",
 	"field-year-short-relative+0": "ove god.",
+	"field-dayperiod-short": "AM/PM",
 	"field-year-short-relative+1": "sljedeće god.",
 	"field-fri-short-relative+0": "ovaj pet.",
 	"field-fri-short-relative+1": "sljedeći pet.",
 	"field-week-short-relative+-1": "prošli tj.",
 	"field-hour-short": "h",
+	"field-zone-short": "zona",
 	"field-month-narrow": "m.",
 	"field-hour-narrow": "h",
 	"field-fri-narrow-relative+-1": "prošli pet.",
 	"field-year-relative+0": "ove godine",
 	"field-year-relative+1": "sljedeće godine",
+	"field-era-narrow": "era",
 	"field-fri-relative+-1": "prošli petak",
 	"field-tue-short-relative+-1": "prošli uto.",
 	"field-minute-narrow": "min",
@@ -139,10 +153,13 @@ define(
 	"field-mon-narrow-relative+1": "sljedeći pon.",
 	"field-year-short-relative+-1": "prošle god.",
 	"field-zone": "vremenska zona",
+	"field-weekOfMonth-narrow": "tj. u mjesecu",
+	"field-weekday-narrow": "dan u tj.",
 	"field-quarter-narrow": "kv.",
 	"field-sun-short-relative+-1": "prošla ned.",
 	"field-day-relative+-1": "jučer",
 	"field-day-relative+-2": "prekjučer",
+	"field-weekday-short": "dan u tjed.",
 	"field-sun-relative+0": "ova nedjelja",
 	"field-sun-relative+1": "sljedeća nedjelja",
 	"field-day-short": "d.",
