@@ -22,11 +22,14 @@ define(
 	"field-week-narrow-relative+1": "következő hét",
 	"field-wed-narrow-relative+-1": "előző szerda",
 	"field-year-narrow": "év",
+	"field-era-short": "éra",
 	"field-year-narrow-relative+0": "ez az év",
 	"field-tue-relative+0": "ez a kedd",
 	"field-year-narrow-relative+1": "következő év",
 	"field-tue-relative+1": "következő kedd",
+	"field-weekdayOfMonth": "hónap hétköznapja",
 	"field-second-short": "másodperc",
+	"field-weekdayOfMonth-narrow": "hónap hétköznapja",
 	"field-week-relative+0": "ez a hét",
 	"field-month-relative+0": "ez a hónap",
 	"field-week-relative+1": "következő hét",
@@ -36,8 +39,14 @@ define(
 	"field-sun-narrow-relative+1": "következő vasárnap",
 	"field-mon-short-relative+1": "következő hétfő",
 	"field-second-relative+0": "most",
+	"eraNames": [
+		"ERA0",
+		"ERA1"
+	],
+	"field-weekOfMonth": "hónap hete",
 	"field-month-short": "hónap",
 	"field-day": "nap",
+	"field-dayOfYear-short": "év napja",
 	"field-year-relative+-1": "előző év",
 	"field-sat-short-relative+-1": "előző szombat",
 	"field-hour-relative+0": "ebben az órában",
@@ -59,7 +68,11 @@ define(
 	"field-dayperiod": "napszak",
 	"field-sat-short-relative+0": "ez a szombat",
 	"field-sat-short-relative+1": "következő szombat",
-	"field-second-narrow": "másodperc",
+	"eraAbbr": [
+		"ERA0",
+		"ERA1"
+	],
+	"field-second-narrow": "mp",
 	"field-mon-relative+0": "ez a hétfő",
 	"field-mon-relative+1": "következő hétfő",
 	"field-day-narrow-relative+-1": "tegnap",
@@ -81,11 +94,28 @@ define(
 		"13"
 	],
 	"field-quarter-relative+-1": "előző negyedév",
+	"field-dayperiod-narrow": "napszak",
 	"field-week-narrow-relative+-1": "előző hét",
+	"field-dayOfYear": "év napja",
 	"field-sat-relative+-1": "előző szombat",
 	"field-hour": "óra",
+	"months-format-wide": [
+		"Thot",
+		"Paophi",
+		"Athür",
+		"Koiak",
+		"Tübi",
+		"Mehir",
+		"Phamenóth",
+		"Pharmuthi",
+		"Pakhónsz",
+		"Pauni",
+		"Epip",
+		"Meszoré",
+		"Pi Kogi Enavot"
+	],
 	"field-month-relative+-1": "előző hónap",
-	"field-quarter-short": "negyedév",
+	"field-quarter-short": "n.év",
 	"field-sat-narrow-relative+0": "ez a szombat",
 	"field-fri-relative+0": "ez a péntek",
 	"field-sat-narrow-relative+1": "következő szombat",
@@ -97,19 +127,19 @@ define(
 	"field-week-relative+-1": "előző hét",
 	"field-quarter-short-relative+-1": "előző negyedév",
 	"months-format-abbr": [
-		"Tout",
-		"Baba",
-		"Hator",
-		"Kiahk",
-		"Toba",
-		"Amshir",
-		"Baramhat",
-		"Baramouda",
-		"Bashans",
-		"Paona",
-		"Epep",
-		"Mesra",
-		"Nasie"
+		"Thot",
+		"Paophi",
+		"Athür",
+		"Koiak",
+		"Tübi",
+		"Mehir",
+		"Phamenóth",
+		"Pharmuthi",
+		"Pakhónsz",
+		"Pauni",
+		"Epip",
+		"Meszoré",
+		"Pi Kogi Enavot"
 	],
 	"field-quarter-relative+0": "ez a negyedév",
 	"field-minute-relative+0": "ebben a percben",
@@ -120,51 +150,55 @@ define(
 	"field-mon-narrow-relative+-1": "előző hétfő",
 	"field-thu-narrow-relative+-1": "előző csütörtök",
 	"field-tue-narrow-relative+-1": "előző kedd",
+	"field-weekOfMonth-short": "hónap hete",
 	"field-wed-short-relative+0": "ez a szerda",
 	"months-standAlone-wide": [
-		"Tout",
-		"Baba",
-		"Hator",
-		"Kiahk",
-		"Toba",
-		"Amshir",
-		"Baramhat",
-		"Baramouda",
-		"Bashans",
-		"Paona",
-		"Epep",
-		"Mesra",
-		"Nasie"
+		"Thot",
+		"Paophi",
+		"Athür",
+		"Koiak",
+		"Tübi",
+		"Mehir",
+		"Phamenóth",
+		"Pharmuthi",
+		"Pakhónsz",
+		"Pauni",
+		"Epip",
+		"Meszoré",
+		"Pi Kogi Enavot"
 	],
 	"field-wed-short-relative+1": "következő szerda",
 	"field-sun-relative+-1": "előző vasárnap",
 	"field-weekday": "hét napja",
 	"field-day-short-relative+0": "ma",
 	"field-quarter-narrow-relative+0": "ez a negyedév",
-	"field-sat-relative+0": "ez a szombat",
 	"field-day-short-relative+1": "holnap",
+	"field-sat-relative+0": "ez a szombat",
 	"field-quarter-narrow-relative+1": "következő negyedév",
-	"field-sat-relative+1": "következő szombat",
 	"field-day-short-relative+2": "holnapután",
+	"field-sat-relative+1": "következő szombat",
 	"field-week-short-relative+0": "ez a hét",
 	"field-week-short-relative+1": "következő hét",
 	"months-standAlone-abbr": [
-		"Tout",
-		"Baba",
-		"Hator",
-		"Kiahk",
-		"Toba",
-		"Amshir",
-		"Baramhat",
-		"Baramouda",
-		"Bashans",
-		"Paona",
-		"Epep",
-		"Mesra",
-		"Nasie"
+		"Thot",
+		"Paophi",
+		"Athür",
+		"Koiak",
+		"Tübi",
+		"Mehir",
+		"Phamenóth",
+		"Pharmuthi",
+		"Pakhónsz",
+		"Pauni",
+		"Epip",
+		"Meszoré",
+		"Pi Kogi Enavot"
 	],
+	"field-dayOfYear-narrow": "év napja",
 	"field-month-short-relative+0": "ez a hónap",
 	"field-month-short-relative+1": "következő hónap",
+	"field-weekdayOfMonth-short": "hónap hétköznapja",
+	"field-zone-narrow": "időzóna",
 	"field-thu-narrow-relative+0": "ez a csütörtök",
 	"field-thu-narrow-relative+1": "következő csütörtök",
 	"field-sun-narrow-relative+-1": "előző vasárnap",
@@ -178,27 +212,37 @@ define(
 	"field-wed-narrow-relative+1": "következő szerda",
 	"field-quarter-narrow-relative+-1": "előző negyedév",
 	"field-year-short-relative+0": "ez az év",
+	"field-dayperiod-short": "napszak",
 	"field-year-short-relative+1": "következő év",
 	"field-fri-short-relative+0": "ez a péntek",
 	"field-fri-short-relative+1": "következő péntek",
 	"field-week-short-relative+-1": "előző hét",
 	"field-hour-short": "óra",
+	"field-zone-short": "időzóna",
 	"field-month-narrow": "hónap",
-	"field-hour-narrow": "óra",
+	"field-hour-narrow": "ó",
 	"field-fri-narrow-relative+-1": "előző péntek",
 	"field-year-relative+0": "ez az év",
 	"field-year-relative+1": "következő év",
+	"field-era-narrow": "éra",
 	"field-fri-relative+-1": "előző péntek",
+	"eraNarrow": [
+		"ERA0",
+		"ERA1"
+	],
 	"field-tue-short-relative+-1": "előző kedd",
-	"field-minute-narrow": "perc",
+	"field-minute-narrow": "p",
 	"field-mon-narrow-relative+0": "ez a hétfő",
 	"field-mon-narrow-relative+1": "következő hétfő",
 	"field-year-short-relative+-1": "előző év",
 	"field-zone": "időzóna",
-	"field-quarter-narrow": "negyedév",
+	"field-weekOfMonth-narrow": "hónap hete",
+	"field-weekday-narrow": "hét napja",
+	"field-quarter-narrow": "n.év",
 	"field-sun-short-relative+-1": "előző vasárnap",
 	"field-day-relative+-1": "tegnap",
 	"field-day-relative+-2": "tegnapelőtt",
+	"field-weekday-short": "hét napja",
 	"field-sun-relative+0": "ez a vasárnap",
 	"field-sun-relative+1": "következő vasárnap",
 	"field-day-short": "nap",
