@@ -1,135 +1,171 @@
 define(
 //begin v1.x content
 {
-	"field-second-relative+0": "sekarang",
-	"field-quarter-relative+-1": "Kuartal lalu",
-	"field-weekday": "Hari dalam Seminggu",
-	"field-mon-narrow-relative+0": "Sen. ini",
-	"field-mon-narrow-relative+1": "Sen. berikutnya",
-	"field-wed-relative+0": "Rabu ini",
-	"dateFormatItem-MMMEd": "E, d MMM",
-	"field-wed-relative+1": "Rabu berikutnya",
-	"field-week-short": "mgg.",
 	"field-tue-relative+-1": "Selasa lalu",
-	"field-year-short": "thn.",
-	"field-thu-narrow-relative+-1": "Kam. lalu",
-	"field-hour-relative+0": "jam ini",
-	"dateFormat-long": "d MMMM y G",
-	"field-quarter-narrow": "krtl.",
-	"field-fri-relative+-1": "Jumat lalu",
-	"field-hour-short": "jam",
-	"field-wed-relative+-1": "Rabu lalu",
-	"dateFormat-full": "EEEE, dd MMMM y G",
-	"field-mon-short-relative+-1": "Sen. lalu",
-	"field-thu-relative+-1": "Kamis lalu",
-	"dateFormatItem-Md": "d/M",
-	"field-era": "Era",
-	"field-sat-narrow-relative+0": "Sab. ini",
-	"field-sat-narrow-relative+1": "Sab. berikutnya",
-	"field-year": "Tahun",
-	"field-hour": "Jam",
-	"field-sat-relative+0": "Sabtu ini",
-	"field-sat-relative+1": "Sabtu berikutnya",
-	"field-sat-short-relative+-1": "Sab. lalu",
-	"field-minute-narrow": "m",
-	"field-day-relative+0": "hari ini",
-	"field-day-relative+1": "besok",
-	"field-thu-relative+0": "Kamis ini",
-	"field-mon-narrow-relative+-1": "Sen. lalu",
-	"field-day-relative+2": "lusa",
-	"field-wed-narrow-relative+0": "Rab. ini",
-	"field-thu-relative+1": "Kamis berikutnya",
-	"field-wed-narrow-relative+1": "Rab. berikutnya",
-	"field-mon-short-relative+0": "Sen. ini",
-	"field-mon-short-relative+1": "Sen. berikutnya",
-	"dateFormatItem-M": "L",
-	"field-wed-short-relative+-1": "Rab. lalu",
-	"field-fri-narrow-relative+-1": "Jum. lalu",
-	"dateFormatItem-MMMMd": "d MMMM",
-	"field-hour-narrow": "j",
-	"field-year-narrow": "thn.",
-	"field-tue-short-relative+0": "Sel. ini",
-	"field-tue-short-relative+1": "Sel. berikutnya",
-	"field-minute-short": "mnt.",
-	"field-day-narrow": "h",
-	"field-wed-short-relative+0": "Rab. ini",
-	"field-wed-short-relative+1": "Rab. berikutnya",
-	"field-sun-relative+0": "hari Minggu ini",
-	"field-sun-relative+1": "hari Minggu berikutnya",
-	"eraAbbr": [
-		"Sebelum R.O.C.",
-		"R.O.C."
-	],
-	"field-minute": "Menit",
-	"field-month-short": "bln.",
-	"field-dayperiod": "AM/PM",
-	"dateFormatItem-d": "d",
-	"field-day-relative+-1": "kemarin",
-	"field-day-relative+-2": "kemarin dulu",
-	"field-minute-relative+0": "menit ini",
-	"field-week-narrow": "mgg.",
-	"field-wed-narrow-relative+-1": "Rab. lalu",
-	"dateFormatItem-MMMd": "d MMM",
-	"field-day-short": "h",
-	"field-quarter-relative+0": "Kuartal ini",
-	"field-quarter-relative+1": "Kuartal berikutnya",
-	"dateFormatItem-MEd": "E, d/M",
-	"field-fri-relative+0": "Jumat ini",
-	"field-fri-relative+1": "Jumat berikutnya",
-	"field-day": "Hari",
-	"field-second-narrow": "d",
-	"field-zone": "Zona Waktu",
-	"dateFormatItem-y": "G y",
-	"field-year-relative+-1": "tahun lalu",
-	"field-month-relative+-1": "bulan lalu",
+	"field-year": "tahun",
+	"field-wed-relative+0": "Rabu ini",
+	"field-wed-relative+1": "Rabu berikutnya",
+	"field-minute": "menit",
+	"field-month-narrow-relative+-1": "bln lalu",
+	"field-tue-narrow-relative+0": "Sel. ini",
+	"field-tue-narrow-relative+1": "Sel. berikutnya",
 	"field-thu-short-relative+0": "Kam. ini",
 	"field-thu-short-relative+1": "Kam. berikutnya",
-	"field-quarter": "Kuartal",
-	"field-month": "Bulan",
-	"dateFormatItem-MMM": "LLL",
+	"field-day-relative+0": "hari ini",
+	"field-day-relative+1": "besok",
+	"field-week-narrow-relative+0": "mgg ini",
+	"field-day-relative+2": "lusa",
+	"field-week-narrow-relative+1": "mgg depan",
+	"field-wed-narrow-relative+-1": "Rab. lalu",
+	"field-year-narrow": "thn.",
+	"field-era-short": "era",
+	"field-year-narrow-relative+0": "thn ini",
 	"field-tue-relative+0": "Selasa ini",
+	"field-year-narrow-relative+1": "thn depan",
 	"field-tue-relative+1": "Selasa berikutnya",
-	"field-fri-narrow-relative+0": "Jum. ini",
-	"field-fri-narrow-relative+1": "Jum. berikutnya",
-	"field-fri-short-relative+-1": "Jum. lalu",
-	"dateFormatItem-MMMMEd": "E, d MMMM",
-	"field-sun-narrow-relative+-1": "Min. lalu",
-	"field-sun-narrow-relative+0": "Min. ini",
-	"field-thu-narrow-relative+0": "Kam. ini",
-	"field-sun-narrow-relative+1": "Min. berikutnya",
-	"field-thu-narrow-relative+1": "Kam. berikutnya",
-	"field-tue-narrow-relative+0": "Sel. ini",
-	"field-mon-relative+0": "Senin ini",
-	"field-tue-narrow-relative+1": "Sel. berikutnya",
-	"field-mon-relative+1": "Senin berikutnya",
-	"dateFormat-short": "d/M/y GGGGG",
-	"field-tue-narrow-relative+-1": "Sel. lalu",
+	"field-weekdayOfMonth": "hari kerja",
 	"field-second-short": "dtk.",
-	"field-second": "Detik",
-	"field-fri-short-relative+0": "Jum. ini",
-	"field-sat-relative+-1": "Sabtu lalu",
-	"field-fri-short-relative+1": "Jum. berikutnya",
-	"field-sun-relative+-1": "hari Minggu lalu",
-	"field-month-relative+0": "bulan ini",
-	"field-month-relative+1": "Bulan berikutnya",
-	"field-week": "Minggu",
-	"field-sat-short-relative+0": "Sab. ini",
-	"dateFormat-medium": "d MMM y G",
-	"field-sat-short-relative+1": "Sab. berikutnya",
-	"field-year-relative+0": "tahun ini",
-	"field-week-relative+-1": "minggu lalu",
-	"field-year-relative+1": "tahun depan",
-	"field-quarter-short": "krtl.",
-	"field-sun-short-relative+-1": "Min. lalu",
-	"field-thu-short-relative+-1": "Kam. lalu",
-	"field-tue-short-relative+-1": "Sel. lalu",
-	"field-mon-relative+-1": "Senin lalu",
-	"field-sat-narrow-relative+-1": "Sab. lalu",
-	"field-month-narrow": "bln.",
+	"dateFormatItem-MMMd": "d MMM",
+	"field-weekdayOfMonth-narrow": "hr kerja",
 	"field-week-relative+0": "minggu ini",
-	"field-sun-short-relative+0": "Min. ini",
+	"field-month-relative+0": "bulan ini",
 	"field-week-relative+1": "minggu depan",
-	"field-sun-short-relative+1": "Min. berikutnya"
+	"field-month-relative+1": "bulan berikutnya",
+	"field-sun-narrow-relative+0": "Min. ini",
+	"field-mon-short-relative+0": "Sen. ini",
+	"field-sun-narrow-relative+1": "Min. berikutnya",
+	"field-mon-short-relative+1": "Sen. berikutnya",
+	"field-second-relative+0": "sekarang",
+	"eraNames": [
+		"Sebelum R.O.C."
+	],
+	"field-weekOfMonth": "minggu",
+	"field-month-short": "bln.",
+	"field-day": "hari",
+	"field-dayOfYear-short": "hari dlm setahun",
+	"field-year-relative+-1": "tahun lalu",
+	"field-sat-short-relative+-1": "Sab. lalu",
+	"field-hour-relative+0": "jam ini",
+	"field-wed-relative+-1": "Rabu lalu",
+	"field-sat-narrow-relative+-1": "Sab. lalu",
+	"field-second": "detik",
+	"dateFormat-long": "d MMMM y G",
+	"field-quarter": "kuartal",
+	"field-week-short": "mgg.",
+	"field-day-narrow-relative+2": "lusa",
+	"field-tue-short-relative+0": "Sel. ini",
+	"field-tue-short-relative+1": "Sel. berikutnya",
+	"field-month-short-relative+-1": "bln lalu",
+	"field-mon-relative+-1": "Senin lalu",
+	"field-month": "bulan",
+	"field-day-narrow": "h",
+	"field-minute-short": "mnt.",
+	"field-dayperiod": "AM/PM",
+	"field-sat-short-relative+0": "Sab. ini",
+	"field-sat-short-relative+1": "Sab. berikutnya",
+	"dateFormat-medium": "d MMM y G",
+	"eraAbbr": [
+		"Sebelum R.O.C."
+	],
+	"field-second-narrow": "d",
+	"field-mon-relative+0": "Senin ini",
+	"field-mon-relative+1": "Senin berikutnya",
+	"field-year-short": "thn.",
+	"field-quarter-relative+-1": "Kuartal lalu",
+	"field-dayperiod-narrow": "AM/PM",
+	"field-week-narrow-relative+-1": "mgg lalu",
+	"field-dayOfYear": "hari dalam setahun",
+	"field-sat-relative+-1": "Sabtu lalu",
+	"dateFormatItem-Md": "d/M",
+	"field-hour": "Jam",
+	"dateFormat-full": "EEEE, dd MMMM y G",
+	"field-month-relative+-1": "bulan lalu",
+	"field-quarter-short": "krtl.",
+	"field-sat-narrow-relative+0": "Sab. ini",
+	"field-fri-relative+0": "Jumat ini",
+	"field-sat-narrow-relative+1": "Sab. berikutnya",
+	"field-fri-relative+1": "Jumat berikutnya",
+	"field-month-narrow-relative+0": "bln ini",
+	"field-month-narrow-relative+1": "bln berikutnya",
+	"field-sun-short-relative+0": "Min. ini",
+	"field-sun-short-relative+1": "Min. berikutnya",
+	"field-week-relative+-1": "minggu lalu",
+	"field-quarter-relative+0": "kuartal ini",
+	"field-minute-relative+0": "menit ini",
+	"field-quarter-relative+1": "kuartal berikutnya",
+	"field-wed-short-relative+-1": "Rab. lalu",
+	"dateFormat-short": "d/M/y GGGGG",
+	"field-thu-short-relative+-1": "Kam. lalu",
+	"field-year-narrow-relative+-1": "thn lalu",
+	"field-mon-narrow-relative+-1": "Sen. lalu",
+	"dateFormatItem-MMMMd": "d MMMM",
+	"field-thu-narrow-relative+-1": "Kam. lalu",
+	"field-tue-narrow-relative+-1": "Sel. lalu",
+	"field-weekOfMonth-short": "mgg.",
+	"field-wed-short-relative+0": "Rab. ini",
+	"field-wed-short-relative+1": "Rab. berikutnya",
+	"field-sun-relative+-1": "hari Minggu lalu",
+	"dateFormatItem-MMMMEd": "E, d MMMM",
+	"field-weekday": "hari dalam seminggu",
+	"field-sat-relative+0": "Sabtu ini",
+	"field-sat-relative+1": "Sabtu berikutnya",
+	"field-day-short-relative+2": "lusa",
+	"field-week-short-relative+0": "mgg ini",
+	"field-week-short-relative+1": "mgg depan",
+	"field-dayOfYear-narrow": "hari dlm 1 thn",
+	"field-month-short-relative+0": "bln ini",
+	"field-month-short-relative+1": "bln berikutnya",
+	"field-weekdayOfMonth-short": "hr kerja",
+	"dateFormatItem-MEd": "E, d/M",
+	"field-zone-narrow": "zona wkt",
+	"field-thu-narrow-relative+0": "Kam. ini",
+	"field-thu-narrow-relative+1": "Kam. berikutnya",
+	"field-sun-narrow-relative+-1": "Min. lalu",
+	"field-mon-short-relative+-1": "Sen. lalu",
+	"field-thu-relative+0": "Kamis ini",
+	"field-thu-relative+1": "Kamis berikutnya",
+	"field-fri-short-relative+-1": "Jum. lalu",
+	"field-thu-relative+-1": "Kamis lalu",
+	"field-week": "minggu",
+	"field-wed-narrow-relative+0": "Rab. ini",
+	"field-wed-narrow-relative+1": "Rab. berikutnya",
+	"field-year-short-relative+0": "thn ini",
+	"field-dayperiod-short": "AM/PM",
+	"field-year-short-relative+1": "thn depan",
+	"field-fri-short-relative+0": "Jum. ini",
+	"field-fri-short-relative+1": "Jum. berikutnya",
+	"field-week-short-relative+-1": "mgg lalu",
+	"field-hour-short": "jam",
+	"field-zone-short": "zona wkt",
+	"field-month-narrow": "bln.",
+	"field-hour-narrow": "j",
+	"field-fri-narrow-relative+-1": "Jum. lalu",
+	"field-year-relative+0": "tahun ini",
+	"field-year-relative+1": "tahun depan",
+	"field-era-narrow": "era",
+	"field-fri-relative+-1": "Jumat lalu",
+	"eraNarrow": "Sebelum R.O.C.",
+	"field-tue-short-relative+-1": "Sel. lalu",
+	"field-minute-narrow": "m",
+	"field-mon-narrow-relative+0": "Sen. ini",
+	"field-mon-narrow-relative+1": "Sen. berikutnya",
+	"field-year-short-relative+-1": "thn lalu",
+	"field-zone": "zona waktu",
+	"dateFormatItem-MMMEd": "E, d MMM",
+	"field-weekOfMonth-narrow": "mgg.",
+	"field-weekday-narrow": "hari dlm seminggu",
+	"field-quarter-narrow": "krtl.",
+	"field-sun-short-relative+-1": "Min. lalu",
+	"field-day-relative+-1": "kemarin",
+	"field-day-relative+-2": "kemarin dulu",
+	"field-weekday-short": "hari dlm seminggu",
+	"field-sun-relative+0": "hari Minggu ini",
+	"field-sun-relative+1": "hari Minggu berikutnya",
+	"field-day-short": "h",
+	"field-week-narrow": "mgg.",
+	"field-era": "era",
+	"field-fri-narrow-relative+0": "Jum. ini",
+	"field-fri-narrow-relative+1": "Jum. berikutnya"
 }
 //end v1.x content
 );
\ No newline at end of file
