@@ -1,6 +1,8 @@
 define(
 //begin v1.x content
 {
+	"field-quarter-short-relative+0": "今四半期",
+	"field-quarter-short-relative+1": "翌四半期",
 	"field-tue-relative+-1": "先週の火曜日",
 	"field-year": "年",
 	"field-wed-relative+0": "今週の水曜日",
@@ -17,18 +19,21 @@ define(
 	"field-day-relative+1": "明日",
 	"field-week-narrow-relative+0": "今週",
 	"field-day-relative+2": "明後日",
-	"field-week-narrow-relative+1": "翌週",
+	"field-week-narrow-relative+1": "来週",
 	"field-wed-narrow-relative+-1": "先週の水曜",
 	"field-year-narrow": "年",
+	"field-era-short": "時代",
 	"field-year-narrow-relative+0": "今年",
 	"field-tue-relative+0": "今週の火曜日",
-	"field-year-narrow-relative+1": "翌年",
+	"field-year-narrow-relative+1": "来年",
 	"field-tue-relative+1": "来週の火曜日",
+	"field-weekdayOfMonth": "月の曜日番号",
 	"field-second-short": "秒",
+	"field-weekdayOfMonth-narrow": "月の曜日番号",
 	"field-week-relative+0": "今週",
 	"field-month-relative+0": "今月",
-	"field-week-relative+1": "翌週",
-	"field-month-relative+1": "翌月",
+	"field-week-relative+1": "来週",
+	"field-month-relative+1": "来月",
 	"field-sun-narrow-relative+0": "今週の日曜",
 	"field-mon-short-relative+0": "今週の月曜",
 	"field-sun-narrow-relative+1": "来週の日曜",
@@ -49,8 +54,14 @@ define(
 		"12",
 		"13"
 	],
+	"eraNames": [
+		"ERA0",
+		"ERA1"
+	],
+	"field-weekOfMonth": "月の週番号",
 	"field-month-short": "月",
 	"field-day": "日",
+	"field-dayOfYear-short": "年の通日",
 	"field-year-relative+-1": "昨年",
 	"field-sat-short-relative+-1": "先週の土曜",
 	"field-hour-relative+0": "1 時間以内",
@@ -72,6 +83,10 @@ define(
 	"field-dayperiod": "午前/午後",
 	"field-sat-short-relative+0": "今週の土曜",
 	"field-sat-short-relative+1": "来週の土曜",
+	"eraAbbr": [
+		"ERA0",
+		"ERA1"
+	],
 	"field-second-narrow": "秒",
 	"field-mon-relative+0": "今週の月曜日",
 	"field-mon-relative+1": "来週の月曜日",
@@ -94,7 +109,9 @@ define(
 		"13"
 	],
 	"field-quarter-relative+-1": "前四半期",
+	"field-dayperiod-narrow": "午前/午後",
 	"field-week-narrow-relative+-1": "先週",
+	"field-dayOfYear": "年の通日",
 	"field-sat-relative+-1": "先週の土曜日",
 	"field-hour": "時",
 	"months-format-wide": [
@@ -119,10 +136,11 @@ define(
 	"field-sat-narrow-relative+1": "来週の土曜",
 	"field-fri-relative+1": "来週の金曜日",
 	"field-month-narrow-relative+0": "今月",
-	"field-month-narrow-relative+1": "翌月",
+	"field-month-narrow-relative+1": "来月",
 	"field-sun-short-relative+0": "今週の日曜",
 	"field-sun-short-relative+1": "来週の日曜",
 	"field-week-relative+-1": "先週",
+	"field-quarter-short-relative+-1": "前四半期",
 	"months-format-abbr": [
 		"トウト",
 		"ババ",
@@ -147,6 +165,7 @@ define(
 	"field-mon-narrow-relative+-1": "先週の月曜",
 	"field-thu-narrow-relative+-1": "先週の木曜",
 	"field-tue-narrow-relative+-1": "先週の火曜",
+	"field-weekOfMonth-short": "月の週番号",
 	"field-wed-short-relative+0": "今週の水曜",
 	"months-standAlone-wide": [
 		"トウト",
@@ -167,12 +186,14 @@ define(
 	"field-sun-relative+-1": "先週の日曜日",
 	"field-weekday": "曜日",
 	"field-day-short-relative+0": "今日",
-	"field-sat-relative+0": "今週の土曜日",
+	"field-quarter-narrow-relative+0": "今四半期",
 	"field-day-short-relative+1": "明日",
-	"field-sat-relative+1": "来週の土曜日",
+	"field-sat-relative+0": "今週の土曜日",
+	"field-quarter-narrow-relative+1": "翌四半期",
 	"field-day-short-relative+2": "明後日",
+	"field-sat-relative+1": "来週の土曜日",
 	"field-week-short-relative+0": "今週",
-	"field-week-short-relative+1": "翌週",
+	"field-week-short-relative+1": "来週",
 	"months-standAlone-abbr": [
 		"トウト",
 		"ババ",
@@ -188,8 +209,11 @@ define(
 		"メスラ",
 		"ナシエ"
 	],
+	"field-dayOfYear-narrow": "通日",
 	"field-month-short-relative+0": "今月",
-	"field-month-short-relative+1": "翌月",
+	"field-month-short-relative+1": "来月",
+	"field-weekdayOfMonth-short": "月の曜日番号",
+	"field-zone-narrow": "タイムゾーン",
 	"field-thu-narrow-relative+0": "今週の木曜",
 	"field-thu-narrow-relative+1": "来週の木曜",
 	"field-sun-narrow-relative+-1": "先週の日曜",
@@ -201,28 +225,39 @@ define(
 	"field-week": "週",
 	"field-wed-narrow-relative+0": "今週の水曜",
 	"field-wed-narrow-relative+1": "来週の水曜",
+	"field-quarter-narrow-relative+-1": "前四半期",
 	"field-year-short-relative+0": "今年",
-	"field-year-short-relative+1": "翌年",
+	"field-dayperiod-short": "午前/午後",
+	"field-year-short-relative+1": "来年",
 	"field-fri-short-relative+0": "今週の金曜",
 	"field-fri-short-relative+1": "来週の金曜",
 	"field-week-short-relative+-1": "先週",
 	"field-hour-short": "時",
+	"field-zone-short": "タイムゾーン",
 	"field-month-narrow": "月",
 	"field-hour-narrow": "時",
 	"field-fri-narrow-relative+-1": "先週の金曜",
 	"field-year-relative+0": "今年",
-	"field-year-relative+1": "翌年",
+	"field-year-relative+1": "来年",
+	"field-era-narrow": "時代",
 	"field-fri-relative+-1": "先週の金曜日",
+	"eraNarrow": [
+		"ERA0",
+		"ERA1"
+	],
 	"field-tue-short-relative+-1": "先週の火曜",
 	"field-minute-narrow": "分",
 	"field-mon-narrow-relative+0": "今週の月曜",
 	"field-mon-narrow-relative+1": "来週の月曜",
 	"field-year-short-relative+-1": "昨年",
 	"field-zone": "タイムゾーン",
+	"field-weekOfMonth-narrow": "月の週番号",
+	"field-weekday-narrow": "曜日",
 	"field-quarter-narrow": "四半期",
 	"field-sun-short-relative+-1": "先週の日曜",
 	"field-day-relative+-1": "昨日",
 	"field-day-relative+-2": "一昨日",
+	"field-weekday-short": "曜日",
 	"field-sun-relative+0": "今週の日曜日",
 	"field-sun-relative+1": "来週の日曜日",
 	"field-day-short": "日",
