@@ -4,22 +4,28 @@ define(
 	"field-tue-relative+-1": "지난 화요일",
 	"field-year": "년",
 	"dateFormatItem-MEEEEd": "M. d. EEEE",
+	"dateFormatItem-Hm": "HH:mm",
 	"field-wed-relative+0": "이번 수요일",
 	"field-wed-relative+1": "다음 수요일",
+	"dateFormatItem-ms": "mm:ss",
 	"field-minute": "분",
 	"field-tue-narrow-relative+0": "이번 화요일",
 	"field-tue-narrow-relative+1": "다음 화요일",
 	"field-thu-short-relative+0": "이번 목요일",
-	"field-thu-short-relative+1": "다음 목요일",
 	"field-day-relative+0": "오늘",
+	"field-thu-short-relative+1": "다음 목요일",
 	"field-day-relative+1": "내일",
 	"field-day-relative+2": "모레",
 	"field-wed-narrow-relative+-1": "지난 수요일",
+	"dateFormatItem-EBhms": "E B h:mm:ss",
 	"field-year-narrow": "년",
+	"field-era-short": "연호",
 	"field-tue-relative+0": "이번 화요일",
 	"field-tue-relative+1": "다음 화요일",
+	"field-weekdayOfMonth": "월의 평일",
 	"field-second-short": "초",
 	"dateFormatItem-MMMd": "MMM d일",
+	"field-weekdayOfMonth-narrow": "월의 평일",
 	"field-week-relative+0": "이번 주",
 	"field-month-relative+0": "이번 달",
 	"field-week-relative+1": "다음 주",
@@ -29,7 +35,7 @@ define(
 	"field-sun-narrow-relative+1": "다음 일요일",
 	"field-mon-short-relative+1": "다음 월요일",
 	"field-second-relative+0": "지금",
-	"dateFormatItem-yyyyQQQ": "U년 QQQ",
+	"dateFormatItem-yyyyQQQ": "r년(U년) QQQ",
 	"months-standAlone-narrow": [
 		"1",
 		"2",
@@ -44,26 +50,28 @@ define(
 		"11",
 		"12"
 	],
+	"field-weekOfMonth": "월의 주",
 	"field-month-short": "월",
-	"dateFormatItem-GyMMMEd": "U년 MMM d일 (E)",
-	"dateFormatItem-yyyyMd": "U. M. d.",
+	"dateFormatItem-GyMMMEd": "r년(U년) MMM d일 (E)",
+	"dateFormatItem-yyyyMd": "r. M. d.",
 	"field-day": "일",
+	"field-dayOfYear-short": "년의 일",
 	"field-year-relative+-1": "작년",
 	"field-sat-short-relative+-1": "지난 토요일",
 	"field-hour-relative+0": "현재 시간",
-	"dateFormatItem-yyyyMEd": "U. M. d. (E)",
+	"dateFormatItem-yyyyMEd": "r. M. d. (E)",
 	"field-wed-relative+-1": "지난 수요일",
 	"field-sat-narrow-relative+-1": "지난 토요일",
 	"field-second": "초",
 	"dateFormat-long": "U년 MMM d일",
-	"dateFormatItem-GyMMMd": "U년 MMM d일",
+	"dateFormatItem-GyMMMd": "r년 MMM d일",
 	"field-quarter": "분기",
 	"field-week-short": "주",
 	"dateFormatItem-MMMEEEEd": "MMM d일 EEEE",
 	"field-tue-short-relative+0": "이번 화요일",
 	"field-tue-short-relative+1": "다음 화요일",
 	"field-mon-relative+-1": "지난 월요일",
-	"dateFormatItem-GyMMM": "U년 MMM",
+	"dateFormatItem-GyMMM": "r년(U년) MMM",
 	"field-month": "월",
 	"field-day-narrow": "일",
 	"dateFormatItem-MMM": "LLL",
@@ -72,15 +80,18 @@ define(
 	"field-sat-short-relative+0": "이번 토요일",
 	"field-sat-short-relative+1": "다음 토요일",
 	"dateFormat-medium": "y. M. d.",
-	"dateFormatItem-yyyyMMMM": "U년 MMMM",
+	"dateFormatItem-yyyyMMMM": "r년(U년) MMMM",
+	"dateFormatItem-UMMM": "U년 MMM",
 	"dateFormatItem-EEEEd": "d일 EEEE",
-	"dateFormatItem-yyyyM": "U. M.",
+	"dateFormatItem-yyyyM": "r. M.",
 	"field-second-narrow": "초",
 	"field-mon-relative+0": "이번 월요일",
 	"field-mon-relative+1": "다음 월요일",
 	"field-year-short": "년",
 	"field-quarter-relative+-1": "지난 분기",
-	"dateFormatItem-yyyyMMMd": "U년 MMM d일",
+	"dateFormatItem-yyyyMMMd": "r년 MMM d일",
+	"field-dayperiod-narrow": "오전/오후",
+	"field-dayOfYear": "년의 일",
 	"field-sat-relative+-1": "지난 토요일",
 	"dateFormatItem-Md": "M. d.",
 	"field-hour": "시",
@@ -99,13 +110,15 @@ define(
 		"12월"
 	],
 	"dateFormat-full": "U년 MMM d일 EEEE",
+	"dateFormatItem-UMd": "U년 M. d.",
 	"field-month-relative+-1": "지난달",
-	"dateFormatItem-Hms": "H시 m분 s초",
+	"dateFormatItem-Hms": "HH:mm:ss",
 	"field-quarter-short": "분기",
 	"field-sat-narrow-relative+0": "이번 토요일",
 	"field-fri-relative+0": "이번 금요일",
 	"field-sat-narrow-relative+1": "다음 토요일",
 	"field-fri-relative+1": "다음 금요일",
+	"dateFormatItem-EBhm": "E B h:mm",
 	"field-sun-short-relative+0": "이번 일요일",
 	"field-sun-short-relative+1": "다음 일요일",
 	"field-week-relative+-1": "지난주",
@@ -128,14 +141,17 @@ define(
 	"field-quarter-relative+1": "다음 분기",
 	"field-wed-short-relative+-1": "지난 수요일",
 	"dateFormat-short": "y. M. d.",
+	"dateFormatItem-Bh": "B h시",
 	"field-thu-short-relative+-1": "지난 목요일",
-	"dateFormatItem-yyyyMMMEd": "U년 MMM d일 (E)",
+	"dateFormatItem-yyyyMMMEd": "r년(U년) MMM d일 (E)",
 	"field-mon-narrow-relative+-1": "지난 월요일",
 	"dateFormatItem-MMMMd": "MMMM d일",
 	"field-thu-narrow-relative+-1": "지난 목요일",
+	"dateFormatItem-E": "ccc",
 	"field-tue-narrow-relative+-1": "지난 화요일",
 	"dateFormatItem-H": "H시",
-	"dateFormatItem-yyyy": "U년",
+	"field-weekOfMonth-short": "월의 주",
+	"dateFormatItem-yyyy": "r년(U년)",
 	"field-wed-short-relative+0": "이번 수요일",
 	"dateFormatItem-M": "MMM",
 	"field-wed-short-relative+1": "다음 수요일",
@@ -145,54 +161,67 @@ define(
 	"field-weekday": "요일",
 	"field-sat-relative+0": "이번 토요일",
 	"dateFormatItem-h": "a h시",
-	"dateFormatItem-yyyyMEEEEd": "U. M. d. EEEE",
+	"dateFormatItem-yyyyMEEEEd": "r. M. d. EEEE",
 	"field-sat-relative+1": "다음 토요일",
+	"field-dayOfYear-narrow": "년의 일",
+	"field-weekdayOfMonth-short": "월의 평일",
 	"dateFormatItem-MEd": "M. d. (E)",
-	"dateFormatItem-y": "U년",
+	"field-zone-narrow": "시간대",
+	"dateFormatItem-y": "r년(U년)",
 	"field-thu-narrow-relative+0": "이번 목요일",
-	"field-thu-narrow-relative+1": "다음 목요일",
 	"field-sun-narrow-relative+-1": "지난 일요일",
 	"field-mon-short-relative+-1": "지난 월요일",
+	"field-thu-narrow-relative+1": "다음 목요일",
 	"field-thu-relative+0": "이번 목요일",
 	"field-thu-relative+1": "다음 목요일",
 	"dateFormatItem-hms": "a h:mm:ss",
 	"field-fri-short-relative+-1": "지난 금요일",
 	"field-thu-relative+-1": "지난 목요일",
-	"dateFormatItem-yMd": "U. M. d.",
+	"dateFormatItem-yMd": "r. M. d.",
 	"field-week": "주",
 	"dateFormatItem-Ed": "d일 (E)",
 	"field-wed-narrow-relative+0": "이번 수요일",
 	"field-wed-narrow-relative+1": "다음 수요일",
-	"dateFormatItem-yyyyMMMEEEEd": "U년 MMM d일 EEEE",
-	"dateFormatItem-yyyyMMM": "U년 MMM",
+	"dateFormatItem-yyyyMMMEEEEd": "r년(U년) MMM d일 EEEE",
+	"dateFormatItem-yyyyMMM": "r년(U년) MMM",
+	"field-dayperiod-short": "오전/오후",
 	"field-fri-short-relative+0": "이번 금요일",
 	"field-fri-short-relative+1": "다음 금요일",
-	"dateFormatItem-yyyyQQQQ": "U년 QQQQ",
+	"dateFormatItem-yyyyQQQQ": "r년(U년) QQQQ",
+	"dateFormatItem-UMMMd": "U년 MMM d일",
 	"field-hour-short": "시",
+	"field-zone-short": "시간대",
 	"field-month-narrow": "월",
 	"field-hour-narrow": "시",
 	"field-fri-narrow-relative+-1": "지난 금요일",
 	"field-year-relative+0": "올해",
 	"field-year-relative+1": "내년",
+	"field-era-narrow": "연호",
 	"field-fri-relative+-1": "지난 금요일",
+	"dateFormatItem-Bhms": "B h:mm:ss",
 	"field-tue-short-relative+-1": "지난 화요일",
 	"field-minute-narrow": "분",
 	"field-mon-narrow-relative+0": "이번 월요일",
 	"field-mon-narrow-relative+1": "다음 월요일",
-	"dateFormatItem-GyMMMEEEEd": "U년 MMM d일 EEEE",
+	"dateFormatItem-GyMMMEEEEd": "r년(U년) MMM d일 EEEE",
 	"field-zone": "시간대",
 	"dateFormatItem-MMMEd": "MMM d일 (E)",
+	"field-weekOfMonth-narrow": "월의 주",
+	"field-weekday-narrow": "요일",
 	"field-quarter-narrow": "분기",
 	"field-sun-short-relative+-1": "지난 일요일",
 	"field-day-relative+-1": "어제",
 	"field-day-relative+-2": "그저께",
+	"field-weekday-short": "요일",
+	"dateFormatItem-Bhm": "B h:mm",
 	"field-sun-relative+0": "이번 일요일",
 	"field-sun-relative+1": "다음 일요일",
-	"dateFormatItem-Gy": "U년",
+	"dateFormatItem-Gy": "r년(U년)",
 	"field-day-short": "일",
 	"field-week-narrow": "주",
 	"field-era": "연호",
 	"field-fri-narrow-relative+0": "이번 금요일",
+	"dateFormatItem-UM": "U년 MMM",
 	"field-fri-narrow-relative+1": "다음 금요일"
 }
 //end v1.x content
