@@ -5,7 +5,7 @@ define(
 	"field-tue-relative+-1": "지난 화요일",
 	"field-year": "년",
 	"dateFormatItem-MEEEEd": "M. d. EEEE",
-	"dateFormatItem-yw": "y년 w번째 주",
+	"dateFormatItem-yw": "Y년 w번째 주",
 	"dayPeriods-format-abbr-afternoon1": "오후",
 	"dateFormatItem-Hm": "HH:mm",
 	"field-wed-relative+0": "이번 수요일",
@@ -22,15 +22,19 @@ define(
 	"field-day-relative+1": "내일",
 	"field-day-relative+2": "모레",
 	"field-wed-narrow-relative+-1": "지난 수요일",
+	"dateFormatItem-EBhms": "(E) B h:mm:ss",
 	"field-year-narrow": "년",
+	"field-era-short": "연호",
 	"field-tue-relative+0": "이번 화요일",
 	"field-tue-relative+1": "다음 화요일",
+	"field-weekdayOfMonth": "월의 평일",
 	"field-second-short": "초",
 	"dayPeriods-format-narrow-am": "AM",
 	"dayPeriods-standAlone-abbr-morning1": "새벽",
 	"dayPeriods-standAlone-abbr-morning2": "오전",
 	"dateFormatItem-MMMd": "MMM d일",
 	"dayPeriods-format-narrow-morning1": "새벽",
+	"field-weekdayOfMonth-narrow": "월의 평일",
 	"dayPeriods-format-narrow-morning2": "오전",
 	"dayPeriods-format-abbr-am": "AM",
 	"field-week-relative+0": "이번 주",
@@ -62,11 +66,13 @@ define(
 		"기원전",
 		"서기"
 	],
+	"field-weekOfMonth": "월의 주",
 	"dayPeriods-standAlone-abbr-pm": "PM",
 	"field-month-short": "월",
 	"dateFormatItem-GyMMMEd": "G y년 MMM d일 (E)",
 	"field-day": "일",
 	"dayPeriods-standAlone-wide-night1": "밤",
+	"field-dayOfYear-short": "년의 일",
 	"field-year-relative+-1": "작년",
 	"dayPeriods-format-wide-am": "오전",
 	"field-sat-short-relative+-1": "지난 토요일",
@@ -163,6 +169,7 @@ define(
 	"dayPeriods-format-wide-morning1": "새벽",
 	"dayPeriods-format-wide-morning2": "오전",
 	"field-quarter-relative+-1": "지난 분기",
+	"field-dayperiod-narrow": "오전/오후",
 	"dayPeriods-standAlone-narrow-am": "AM",
 	"days-format-short": [
 		"일",
@@ -180,6 +187,7 @@ define(
 		"4"
 	],
 	"dayPeriods-format-wide-pm": "오후",
+	"field-dayOfYear": "년의 일",
 	"field-sat-relative+-1": "지난 토요일",
 	"dateTimeFormat-long": "{1} {0}",
 	"dateFormatItem-Md": "M. d.",
@@ -209,6 +217,7 @@ define(
 	"field-fri-relative+0": "이번 금요일",
 	"field-sat-narrow-relative+1": "다음 토요일",
 	"field-fri-relative+1": "다음 금요일",
+	"dateFormatItem-EBhm": "(E) B h:mm",
 	"dayPeriods-format-narrow-noon": "정오",
 	"field-sun-short-relative+0": "이번 일요일",
 	"field-sun-short-relative+1": "다음 일요일",
@@ -236,9 +245,10 @@ define(
 	"field-wed-short-relative+-1": "지난 수요일",
 	"dateFormatItem-yMMM": "y년 MMM",
 	"dateFormat-short": "yy. M. d.",
-	"field-thu-short-relative+-1": "지난 목요일",
+	"dateFormatItem-Bh": "B h시",
 	"dayPeriods-format-abbr-night1": "밤",
-	"dateFormatItem-MMMMW": "MMM W번째 주",
+	"dateFormatItem-MMMMW": "MMMM W번째 주",
+	"field-thu-short-relative+-1": "지난 목요일",
 	"days-standAlone-wide": [
 		"일요일",
 		"월요일",
@@ -255,6 +265,7 @@ define(
 	"dateFormatItem-E": "ccc",
 	"dateFormatItem-mmss": "mm:ss",
 	"dateFormatItem-H": "H시",
+	"field-weekOfMonth-short": "월의 주",
 	"field-tue-narrow-relative+-1": "지난 화요일",
 	"dayPeriods-format-abbr-evening1": "저녁",
 	"dayPeriods-standAlone-narrow-pm": "PM",
@@ -314,8 +325,11 @@ define(
 	"dayPeriods-standAlone-narrow-evening1": "저녁",
 	"dateFormatItem-yMM": "y. M.",
 	"dayPeriods-format-abbr-morning2": "오전",
+	"field-dayOfYear-narrow": "년의 일",
 	"timeFormat-full": "a h시 m분 s초 zzzz",
+	"field-weekdayOfMonth-short": "월의 평일",
 	"dateFormatItem-MEd": "M. d. (E)",
+	"field-zone-narrow": "시간대",
 	"dateFormatItem-y": "y년",
 	"field-thu-narrow-relative+0": "이번 목요일",
 	"field-sun-narrow-relative+-1": "지난 일요일",
@@ -348,6 +362,7 @@ define(
 	"field-wed-narrow-relative+1": "다음 수요일",
 	"dayPeriods-standAlone-wide-morning1": "새벽",
 	"dayPeriods-standAlone-wide-morning2": "오전",
+	"field-dayperiod-short": "오전/오후",
 	"field-fri-short-relative+0": "이번 금요일",
 	"field-fri-short-relative+1": "다음 금요일",
 	"days-standAlone-short": [
@@ -363,6 +378,7 @@ define(
 	"dayPeriods-standAlone-narrow-morning2": "오전",
 	"dayPeriods-format-abbr-midnight": "자정",
 	"field-hour-short": "시",
+	"field-zone-short": "시간대",
 	"quarters-format-abbr": [
 		"1분기",
 		"2분기",
@@ -373,12 +389,14 @@ define(
 	"field-hour-narrow": "시",
 	"field-fri-narrow-relative+-1": "지난 금요일",
 	"field-year-relative+0": "올해",
+	"field-era-narrow": "연호",
 	"field-year-relative+1": "내년",
 	"field-fri-relative+-1": "지난 금요일",
 	"eraNarrow": [
 		"BC",
 		"AD"
 	],
+	"dateFormatItem-Bhms": "B h:mm:ss",
 	"dayPeriods-format-wide-noon": "정오",
 	"field-tue-short-relative+-1": "지난 화요일",
 	"field-minute-narrow": "분",
@@ -402,8 +420,10 @@ define(
 	"field-zone": "시간대",
 	"dateFormatItem-yMMMM": "y년 MMMM",
 	"dateFormatItem-MMMEd": "MMM d일 (E)",
+	"field-weekOfMonth-narrow": "월의 주",
 	"dateFormatItem-EHms": "(E) HH:mm:ss",
 	"dateFormatItem-yMEd": "y. M. d. (E)",
+	"field-weekday-narrow": "요일",
 	"dayPeriods-standAlone-narrow-midnight": "자정",
 	"field-quarter-narrow": "분기",
 	"dayPeriods-standAlone-abbr-am": "AM",
@@ -411,6 +431,8 @@ define(
 	"field-sun-short-relative+-1": "지난 일요일",
 	"field-day-relative+-2": "그저께",
 	"dayPeriods-format-narrow-night1": "밤",
+	"field-weekday-short": "요일",
+	"dateFormatItem-Bhm": "B h:mm",
 	"days-format-abbr": [
 		"일",
 		"월",
