@@ -7,8 +7,8 @@ define(
 	"JPY_symbol": "JPY",
 	"USD_displayName": "Американски долар",
 	"CAD_symbol": "CA$",
-	"GBP_displayName": "Британска Фунта",
-	"CHF_displayName": "Швајцарски Франк",
+	"GBP_displayName": "Британска фунта",
+	"CHF_displayName": "Швајцарски франк",
 	"CNY_symbol": "CNY",
 	"EUR_displayName": "Евро",
 	"GBP_symbol": "GBP",
