@@ -7,16 +7,17 @@ define(
 	"list": ";",
 	"percentSign": "%",
 	"minusSign": "−",
-	"decimalFormat-short": "000 bill",
+	"decimalFormat-short": "000 bill'.'",
 	"nan": "NaN",
 	"plusSign": "+",
 	"currencyFormat": "¤ #,##0.00",
 	"perMille": "‰",
+	"approximatelySign": "ca.",
 	"group": " ",
 	"percentFormat": "#,##0 %",
 	"decimalFormat-long": "000 billioner",
 	"decimalFormat": "#,##0.###",
-	"currencyFormat-short": "¤ 000 bill",
+	"currencyFormat-short": "¤ 000 bill'.'",
 	"timeSeparator": ".",
 	"decimal": ",",
 	"exponential": "E"
