@@ -13,6 +13,7 @@ define(
 	"field-tue-narrow-relative+1": "volgende week di",
 	"field-thu-short-relative+0": "deze donder.",
 	"field-day-short-relative+-1": "gisteren",
+	"dateTimeFormat-short": "{1} {0}",
 	"field-thu-short-relative+1": "volgende week donder.",
 	"field-day-relative+0": "vandaag",
 	"field-day-short-relative+-2": "eergisteren",
@@ -22,13 +23,16 @@ define(
 	"field-week-narrow-relative+1": "volgende week",
 	"field-wed-narrow-relative+-1": "afgelopen wo",
 	"field-year-narrow": "jr",
+	"field-era-short": "tijdperk",
 	"field-year-narrow-relative+0": "dit jaar",
 	"field-tue-relative+0": "deze dinsdag",
 	"field-year-narrow-relative+1": "volgend jaar",
 	"field-tue-relative+1": "volgende week dinsdag",
+	"field-weekdayOfMonth": "weekdag van de maand",
 	"field-second-short": "sec",
 	"dayPeriods-format-narrow-am": "a.m.",
 	"dateFormatItem-MMMd": "d MMM",
+	"field-weekdayOfMonth-narrow": "wkdag v.d. mnd",
 	"dayPeriods-format-abbr-am": "a.m.",
 	"field-week-relative+0": "deze week",
 	"field-month-relative+0": "deze maand",
@@ -54,11 +58,16 @@ define(
 		"N",
 		"D"
 	],
+	"eraNames": [
+		"BE"
+	],
+	"field-weekOfMonth": "week van de maand",
 	"dayPeriods-standAlone-abbr-pm": "p.m.",
 	"field-month-short": "mnd",
 	"dateFormatItem-GyMMMEd": "E d MMM y G",
 	"dateFormatItem-yyyyMd": "d-M-y GGGGG",
 	"field-day": "dag",
+	"field-dayOfYear-short": "dag van het jr",
 	"field-year-relative+-1": "vorig jaar",
 	"dayPeriods-format-wide-am": "a.m.",
 	"field-sat-short-relative+-1": "afgelopen zater.",
@@ -66,6 +75,7 @@ define(
 	"dateFormatItem-yyyyMEd": "E d-M-y GGGGG",
 	"field-second-short-relative+0": "nu",
 	"field-wed-relative+-1": "afgelopen woensdag",
+	"dateTimeFormat-medium": "{1} {0}",
 	"field-sat-narrow-relative+-1": "afgelopen za",
 	"field-second": "seconde",
 	"days-standAlone-narrow": [
@@ -80,6 +90,7 @@ define(
 	"dayPeriods-standAlone-wide-pm": "p.m.",
 	"dateFormat-long": "d MMMM y G",
 	"dateFormatItem-GyMMMd": "d MMM y G",
+	"field-hour-short-relative+0": "binnen een uur",
 	"field-quarter": "kwartaal",
 	"field-week-short": "wk",
 	"field-day-narrow-relative+0": "vandaag",
@@ -109,7 +120,7 @@ define(
 	"field-day-narrow": "dag",
 	"dateFormatItem-MMM": "LLL",
 	"field-minute-short": "min",
-	"field-dayperiod": "dagdeel",
+	"field-dayperiod": "a.m./p.m.",
 	"field-sat-short-relative+0": "deze zater.",
 	"field-sat-short-relative+1": "volgende week zater.",
 	"dayPeriods-format-narrow-pm": "p.m.",
@@ -148,6 +159,7 @@ define(
 	],
 	"field-quarter-relative+-1": "vorig kwartaal",
 	"dateFormatItem-yyyyMMMd": "d MMM y G",
+	"field-dayperiod-narrow": "a.m./p.m.",
 	"dayPeriods-standAlone-narrow-am": "a.m.",
 	"field-week-narrow-relative+-1": "vorige week",
 	"days-format-short": [
@@ -160,9 +172,11 @@ define(
 		"za"
 	],
 	"dayPeriods-format-wide-pm": "p.m.",
+	"field-dayOfYear": "dag van het jaar",
 	"field-sat-relative+-1": "afgelopen zaterdag",
 	"dateTimeFormat-long": "{1} 'om' {0}",
 	"dateFormatItem-Md": "d-M",
+	"field-minute-narrow-relative+0": "binnen een minuut",
 	"field-hour": "uur",
 	"months-format-wide": [
 		"januari",
@@ -191,6 +205,7 @@ define(
 	"field-sun-short-relative+1": "volgende week zon.",
 	"field-week-relative+-1": "vorige week",
 	"field-quarter-short-relative+-1": "vorig kwartaal",
+	"field-minute-short-relative+0": "binnen een minuut",
 	"months-format-abbr": [
 		"jan.",
 		"feb.",
@@ -227,10 +242,11 @@ define(
 	"field-thu-narrow-relative+-1": "afgelopen do",
 	"dateFormatItem-E": "ccc",
 	"field-tue-narrow-relative+-1": "afgelopen di",
+	"field-weekOfMonth-short": "wk van de mnd",
 	"dateFormatItem-yyyy": "y G",
 	"dayPeriods-standAlone-narrow-pm": "p.m.",
-	"field-wed-short-relative+0": "deze woens.",
 	"dateFormatItem-M": "L",
+	"field-wed-short-relative+0": "deze woens.",
 	"months-standAlone-wide": [
 		"januari",
 		"februari",
@@ -256,8 +272,8 @@ define(
 		"vr",
 		"za"
 	],
-	"field-second-narrow-relative+0": "nu",
 	"dateTimeFormat-full": "{1} 'om' {0}",
+	"field-second-narrow-relative+0": "nu",
 	"dateFormatItem-d": "d",
 	"field-weekday": "dag van de week",
 	"field-day-short-relative+0": "vandaag",
@@ -283,14 +299,17 @@ define(
 		"nov.",
 		"dec."
 	],
+	"field-dayOfYear-narrow": "dag v.h. jr",
 	"field-month-short-relative+0": "deze maand",
 	"field-month-short-relative+1": "volgende maand",
+	"field-weekdayOfMonth-short": "wkdag van de mnd",
 	"dateFormatItem-MEd": "E d-M",
+	"field-zone-narrow": "zone",
 	"dateFormatItem-y": "y G",
 	"field-thu-narrow-relative+0": "deze do",
-	"field-thu-narrow-relative+1": "volgende week do",
 	"field-sun-narrow-relative+-1": "afgelopen zo",
 	"field-mon-short-relative+-1": "afgelopen maan.",
+	"field-thu-narrow-relative+1": "volgende week do",
 	"field-thu-relative+0": "deze donderdag",
 	"field-thu-relative+1": "volgende week donderdag",
 	"field-fri-short-relative+-1": "afgelopen vrij.",
@@ -308,6 +327,7 @@ define(
 	"field-quarter-narrow-relative+-1": "vorig kwartaal",
 	"field-year-short-relative+0": "dit jaar",
 	"dateFormatItem-yyyyMMM": "MMM y G",
+	"field-dayperiod-short": "a.m./p.m.",
 	"field-year-short-relative+1": "volgend jaar",
 	"field-fri-short-relative+0": "deze vrij.",
 	"field-fri-short-relative+1": "volgende week vrij.",
@@ -321,8 +341,10 @@ define(
 		"za"
 	],
 	"field-week-short-relative+-1": "vorige week",
+	"field-hour-narrow-relative+0": "binnen een uur",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
 	"field-hour-short": "uur",
+	"field-zone-short": "zone",
 	"quarters-format-abbr": [
 		"K1",
 		"K2",
@@ -330,11 +352,13 @@ define(
 		"K4"
 	],
 	"field-month-narrow": "mnd",
-	"field-hour-narrow": "uur",
+	"field-hour-narrow": "u",
 	"field-fri-narrow-relative+-1": "afgelopen vr",
 	"field-year-relative+0": "dit jaar",
 	"field-year-relative+1": "volgend jaar",
+	"field-era-narrow": "tijdperk",
 	"field-fri-relative+-1": "afgelopen vrijdag",
+	"eraNarrow": "BE",
 	"field-tue-short-relative+-1": "afgelopen dins.",
 	"field-minute-narrow": "min",
 	"days-format-wide": [
@@ -351,11 +375,14 @@ define(
 	"field-year-short-relative+-1": "vorig jaar",
 	"field-zone": "tijdzone",
 	"dateFormatItem-MMMEd": "E d MMM",
+	"field-weekOfMonth-narrow": "wk v.d. mnd",
+	"field-weekday-narrow": "dag v.d. wk",
 	"field-quarter-narrow": "kwartaal",
 	"field-sun-short-relative+-1": "afgelopen zon.",
 	"field-day-relative+-1": "gisteren",
 	"dayPeriods-standAlone-abbr-am": "a.m.",
 	"field-day-relative+-2": "eergisteren",
+	"field-weekday-short": "dag van de wk",
 	"days-format-abbr": [
 		"zo",
 		"ma",
