@@ -1,198 +1,11 @@
 define(
 //begin v1.x content
 {
-	"field-quarter-short-relative+0": "dit kwartaal",
-	"field-quarter-short-relative+1": "volgend kwartaal",
-	"field-tue-relative+-1": "afgelopen dinsdag",
-	"field-year": "jaar",
-	"dateFormatItem-yw": "'week' w 'in' y",
-	"dayPeriods-format-abbr-afternoon1": "middag",
-	"dateFormatItem-Hm": "HH:mm",
-	"field-wed-relative+0": "deze woensdag",
-	"field-wed-relative+1": "volgende week woensdag",
-	"dateFormatItem-ms": "mm:ss",
-	"timeFormat-short": "HH:mm",
-	"field-minute": "minuut",
-	"field-month-narrow-relative+-1": "vorige maand",
-	"field-tue-narrow-relative+0": "deze di",
-	"field-tue-narrow-relative+1": "volgende week di",
-	"field-day-short-relative+-1": "gisteren",
-	"field-thu-short-relative+0": "deze donder.",
-	"dateTimeFormat-short": "{1} {0}",
-	"field-day-relative+0": "vandaag",
-	"field-day-short-relative+-2": "eergisteren",
-	"field-thu-short-relative+1": "volgende week donder.",
-	"field-day-relative+1": "morgen",
-	"field-week-narrow-relative+0": "deze week",
-	"field-day-relative+2": "overmorgen",
-	"field-week-narrow-relative+1": "volgende week",
-	"field-wed-narrow-relative+-1": "afgelopen wo",
-	"field-year-narrow": "jr",
-	"field-year-narrow-relative+0": "dit jaar",
-	"field-tue-relative+0": "deze dinsdag",
-	"field-year-narrow-relative+1": "volgend jaar",
-	"field-tue-relative+1": "volgende week dinsdag",
-	"dayPeriods-format-narrow-am": "a.m.",
-	"field-second-short": "sec",
-	"dayPeriods-standAlone-abbr-morning1": "ochtend",
-	"dateFormatItem-MMMd": "d MMM",
-	"dayPeriods-format-narrow-morning1": "‘s ochtends",
-	"dayPeriods-format-abbr-am": "a.m.",
-	"field-month-relative+0": "deze maand",
-	"field-week-relative+0": "deze week",
-	"timeFormat-medium": "HH:mm:ss",
-	"field-month-relative+1": "volgende maand",
-	"field-week-relative+1": "volgende week",
+	"dateFormatItem-yMMMM": "MMMM y",
+	"field-thu-narrow-relative+0": "deze do",
+	"field-thu-narrow-relative+1": "volgende week do",
 	"field-sun-narrow-relative+0": "deze zo",
-	"field-mon-short-relative+0": "deze maan.",
 	"field-sun-narrow-relative+1": "volgende week zo",
-	"field-mon-short-relative+1": "volgende week maan.",
-	"field-second-relative+0": "nu",
-	"months-standAlone-narrow": [
-		"J",
-		"F",
-		"M",
-		"A",
-		"M",
-		"J",
-		"J",
-		"A",
-		"S",
-		"O",
-		"N",
-		"D"
-	],
-	"eraNames": [
-		"voor Christus",
-		"na Christus"
-	],
-	"dayPeriods-standAlone-abbr-pm": "p.m.",
-	"dateFormatItem-GyMMMEd": "E d MMM y G",
-	"field-month-short": "mnd",
-	"field-day": "dag",
-	"dayPeriods-standAlone-wide-night1": "nacht",
-	"field-year-relative+-1": "vorig jaar",
-	"dayPeriods-format-wide-am": "a.m.",
-	"field-sat-short-relative+-1": "afgelopen zater.",
-	"dayPeriods-format-narrow-afternoon1": "‘s middags",
-	"dayPeriods-format-wide-afternoon1": "‘s middags",
-	"field-hour-relative+0": "binnen een uur",
-	"field-second-short-relative+0": "nu",
-	"field-wed-relative+-1": "afgelopen woensdag",
-	"dateTimeFormat-medium": "{1} {0}",
-	"days-standAlone-narrow": [
-		"Z",
-		"M",
-		"D",
-		"W",
-		"D",
-		"V",
-		"Z"
-	],
-	"field-sat-narrow-relative+-1": "afgelopen za",
-	"field-second": "seconde",
-	"dayPeriods-standAlone-wide-pm": "p.m.",
-	"dateFormatItem-Ehms": "E h:mm:ss a",
-	"dateFormat-long": "d MMMM y",
-	"dateFormatItem-GyMMMd": "d MMM y G",
-	"dayPeriods-standAlone-abbr-midnight": "middernacht",
-	"field-quarter": "kwartaal",
-	"field-week-short": "wk",
-	"dayPeriods-format-narrow-midnight": "middernacht",
-	"field-day-narrow-relative+0": "vandaag",
-	"dateFormatItem-yMMMEd": "E d MMM y",
-	"field-day-narrow-relative+1": "morgen",
-	"field-day-narrow-relative+2": "overmorgen",
-	"quarters-standAlone-wide": [
-		"1e kwartaal",
-		"2e kwartaal",
-		"3e kwartaal",
-		"4e kwartaal"
-	],
-	"days-format-narrow": [
-		"Z",
-		"M",
-		"D",
-		"W",
-		"D",
-		"V",
-		"Z"
-	],
-	"dayPeriods-format-wide-evening1": "‘s avonds",
-	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
-	"field-tue-short-relative+0": "deze dins.",
-	"field-tue-short-relative+1": "volgende week dins.",
-	"field-month-short-relative+-1": "vorige maand",
-	"field-mon-relative+-1": "afgelopen maandag",
-	"dateFormatItem-GyMMM": "MMM y G",
-	"field-month": "maand",
-	"dayPeriods-standAlone-abbr-night1": "nacht",
-	"field-day-narrow": "dag",
-	"dayPeriods-standAlone-narrow-afternoon1": "middag",
-	"dateFormatItem-MMM": "LLL",
-	"field-minute-short": "min",
-	"field-dayperiod": "dagdeel",
-	"field-sat-short-relative+0": "deze zater.",
-	"field-sat-short-relative+1": "volgende week zater.",
-	"dayPeriods-format-narrow-pm": "p.m.",
-	"dateFormat-medium": "d MMM y",
-	"eraAbbr": [
-		"v.Chr.",
-		"n.Chr."
-	],
-	"quarters-standAlone-abbr": [
-		"K1",
-		"K2",
-		"K3",
-		"K4"
-	],
-	"dayPeriods-format-abbr-pm": "p.m.",
-	"field-second-narrow": "s",
-	"dayPeriods-standAlone-narrow-night1": "nacht",
-	"field-mon-relative+0": "deze maandag",
-	"field-year-short": "jr",
-	"field-day-narrow-relative+-1": "gisteren",
-	"field-mon-relative+1": "volgende week maandag",
-	"field-day-narrow-relative+-2": "eergisteren",
-	"months-format-narrow": [
-		"J",
-		"F",
-		"M",
-		"A",
-		"M",
-		"J",
-		"J",
-		"A",
-		"S",
-		"O",
-		"N",
-		"D"
-	],
-	"dayPeriods-format-wide-morning1": "‘s ochtends",
-	"field-quarter-relative+-1": "vorig kwartaal",
-	"dayPeriods-standAlone-narrow-am": "a.m.",
-	"field-week-narrow-relative+-1": "vorige week",
-	"days-format-short": [
-		"zo",
-		"ma",
-		"di",
-		"wo",
-		"do",
-		"vr",
-		"za"
-	],
-	"quarters-format-narrow": [
-		"1",
-		"2",
-		"3",
-		"4"
-	],
-	"dayPeriods-format-wide-pm": "p.m.",
-	"field-sat-relative+-1": "afgelopen zaterdag",
-	"dateTimeFormat-long": "{1} 'om' {0}",
-	"dateFormatItem-Md": "d-M",
-	"field-hour": "uur",
-	"dateFormatItem-yQQQQ": "QQQQ y",
 	"months-format-wide": [
 		"januari",
 		"februari",
@@ -207,49 +20,30 @@ define(
 		"november",
 		"december"
 	],
-	"dayPeriods-format-wide-night1": "‘s nachts",
-	"dateFormat-full": "EEEE d MMMM y",
-	"field-month-relative+-1": "vorige maand",
+	"dayPeriods-standAlone-abbr-pm": "p.m.",
 	"dateFormatItem-Hms": "HH:mm:ss",
-	"field-quarter-short": "kwartaal",
-	"field-sat-narrow-relative+0": "deze za",
+	"field-fri-narrow-relative+0": "deze vr",
+	"field-fri-narrow-relative+1": "volgende week vr",
+	"eraNarrow": [
+		"v.C.",
+		"vgj",
+		"n.C.",
+		"gj"
+	],
 	"dateFormatItem-Hmv": "HH:mm v",
-	"field-fri-relative+0": "deze vrijdag",
-	"field-sat-narrow-relative+1": "volgende week za",
-	"field-fri-relative+1": "volgende week vrijdag",
-	"field-month-narrow-relative+0": "deze maand",
-	"field-month-narrow-relative+1": "volgende maand",
-	"field-sun-short-relative+0": "deze zon.",
-	"field-sun-short-relative+1": "volgende week zon.",
-	"field-week-relative+-1": "vorige week",
-	"field-quarter-short-relative+-1": "vorig kwartaal",
-	"dateFormatItem-Ehm": "E h:mm a",
-	"months-format-abbr": [
-		"jan.",
-		"feb.",
-		"mrt.",
-		"apr.",
-		"mei",
-		"jun.",
-		"jul.",
-		"aug.",
-		"sep.",
-		"okt.",
-		"nov.",
-		"dec."
+	"dateFormatItem-hmsv": "h:mm:ss a v",
+	"dateFormatItem-yMMMd": "d MMM y",
+	"dayPeriods-format-abbr-night1": "’s nachts",
+	"dayPeriods-format-narrow-evening1": "’s avonds",
+	"days-standAlone-narrow": [
+		"Z",
+		"M",
+		"D",
+		"W",
+		"D",
+		"V",
+		"Z"
 	],
-	"dayPeriods-format-wide-midnight": "middernacht",
-	"field-quarter-relative+0": "dit kwartaal",
-	"timeFormat-long": "HH:mm:ss z",
-	"field-minute-relative+0": "binnen een minuut",
-	"field-quarter-relative+1": "volgend kwartaal",
-	"field-wed-short-relative+-1": "afgelopen woens.",
-	"dateFormatItem-yMMM": "MMM y",
-	"dateFormat-short": "dd-MM-yy",
-	"field-year-narrow-relative+-1": "vorig jaar",
-	"dayPeriods-format-abbr-night1": "nacht",
-	"dateFormatItem-MMMMW": "'week' W 'van' MMM",
-	"field-thu-short-relative+-1": "afgelopen donder.",
 	"days-standAlone-wide": [
 		"zondag",
 		"maandag",
@@ -259,15 +53,68 @@ define(
 		"vrijdag",
 		"zaterdag"
 	],
-	"field-mon-narrow-relative+-1": "afgelopen ma",
-	"dateFormatItem-MMMMd": "d MMMM",
+	"dayPeriods-format-abbr-afternoon1": "’s middags",
+	"dayPeriods-format-wide-evening1": "’s avonds",
+	"dateFormatItem-Ehm": "E h:mm a",
+	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
+	"field-wed-narrow-relative+-1": "afgelopen wo",
+	"dayPeriods-standAlone-wide-evening1": "avond",
+	"field-minute-narrow-relative+0": "binnen een minuut",
+	"days-format-wide": [
+		"zondag",
+		"maandag",
+		"dinsdag",
+		"woensdag",
+		"donderdag",
+		"vrijdag",
+		"zaterdag"
+	],
+	"field-month-short-relative+0": "deze maand",
+	"field-month-short-relative+1": "volgende maand",
+	"dateFormatItem-Ehms": "E h:mm:ss a",
+	"dayPeriods-standAlone-narrow-evening1": "avond",
+	"dayPeriods-standAlone-abbr-afternoon1": "middag",
+	"field-thu-relative+0": "deze donderdag",
+	"dayPeriods-standAlone-abbr-night1": "nacht",
+	"field-thu-relative+1": "volgende week donderdag",
+	"dayPeriods-format-wide-am": "a.m.",
+	"field-fri-relative+0": "deze vrijdag",
+	"field-fri-relative+1": "volgende week vrijdag",
+	"dateFormatItem-yMd": "d-M-y",
 	"field-thu-narrow-relative+-1": "afgelopen do",
-	"dateFormatItem-E": "ccc",
-	"dateFormatItem-H": "HH",
-	"field-tue-narrow-relative+-1": "afgelopen di",
-	"dayPeriods-format-abbr-evening1": "avond",
-	"dayPeriods-standAlone-narrow-pm": "p.m.",
-	"dateFormatItem-M": "L",
+	"field-quarter-relative+0": "dit kwartaal",
+	"field-quarter-relative+1": "volgend kwartaal",
+	"field-sun-short-relative+0": "deze zon.",
+	"timeFormat-short": "HH:mm",
+	"field-sun-short-relative+1": "volgende week zon.",
+	"dateFormatItem-hms": "h:mm:ss a",
+	"dayPeriods-format-narrow-afternoon1": "’s middags",
+	"dateFormatItem-Md": "d-M",
+	"dateFormatItem-Hmsv": "HH:mm:ss v",
+	"dateFormatItem-hmv": "h:mm a v",
+	"field-week-narrow": "wk",
+	"field-hour-relative+0": "binnen een uur",
+	"field-day-relative+-1": "gisteren",
+	"field-day-relative+-2": "eergisteren",
+	"field-mon-narrow-relative+-1": "afgelopen ma",
+	"field-minute-narrow": "min",
+	"field-thu-short-relative+0": "deze donder.",
+	"field-mon-relative+0": "deze maandag",
+	"field-thu-short-relative+1": "volgende week donder.",
+	"field-mon-relative+1": "volgende week maandag",
+	"field-day-narrow-relative+0": "vandaag",
+	"field-era-short": "tijdperk",
+	"field-day-narrow-relative+1": "morgen",
+	"field-sat-narrow-relative+0": "deze za",
+	"field-day-narrow-relative+2": "overmorgen",
+	"timeFormat-long": "HH:mm:ss z",
+	"field-sat-narrow-relative+1": "volgende week za",
+	"field-week-narrow-relative+0": "deze week",
+	"field-week-narrow-relative+1": "volgende week",
+	"field-hour-short-relative+0": "binnen een uur",
+	"field-wed-narrow-relative+0": "deze wo",
+	"field-wed-narrow-relative+1": "volgende week wo",
+	"field-month": "maand",
 	"months-standAlone-wide": [
 		"januari",
 		"februari",
@@ -282,10 +129,195 @@ define(
 		"november",
 		"december"
 	],
+	"field-weekday-narrow": "dag v.d. wk",
+	"dayPeriods-standAlone-narrow-afternoon1": "middag",
+	"field-year-relative+0": "dit jaar",
+	"field-year-relative+1": "volgend jaar",
+	"dayPeriods-format-abbr-evening1": "’s avonds",
+	"dayPeriods-format-narrow-midnight": "middernacht",
+	"dayPeriods-format-wide-midnight": "middernacht",
+	"field-tue-relative+0": "deze dinsdag",
+	"field-tue-relative+1": "volgende week dinsdag",
+	"dayPeriods-standAlone-abbr-evening1": "avond",
+	"field-minute-short-relative+0": "binnen een minuut",
+	"dateFormatItem-hm": "h:mm a",
+	"dayPeriods-standAlone-wide-midnight": "middernacht",
+	"field-year-narrow": "jr",
+	"field-tue-short-relative+0": "deze dins.",
+	"dayPeriods-standAlone-narrow-midnight": "middernacht",
+	"field-tue-short-relative+1": "volgende week dins.",
+	"field-tue-narrow-relative+0": "deze di",
+	"field-tue-narrow-relative+1": "volgende week di",
+	"dateTimeFormat-full": "{1} 'om' {0}",
+	"dateFormatItem-E": "ccc",
+	"dateFormatItem-EBhm": "E h:mm B",
+	"dateFormatItem-H": "HH",
+	"field-wed-relative+0": "deze woensdag",
+	"field-wed-relative+1": "volgende week woensdag",
+	"dateFormatItem-M": "L",
 	"field-wed-short-relative+0": "deze woens.",
+	"field-fri-short-relative+0": "deze vrij.",
 	"field-wed-short-relative+1": "volgende week woens.",
-	"dateFormatItem-Hmsv": "HH:mm:ss v",
-	"field-sun-relative+-1": "afgelopen zondag",
+	"field-fri-short-relative+1": "volgende week vrij.",
+	"field-weekOfMonth-short": "wk van de mnd",
+	"field-quarter-short-relative+-1": "vorig kwartaal",
+	"field-year-short-relative+-1": "vorig jaar",
+	"dateFormatItem-Bhm": "h:mm B",
+	"dayPeriods-format-wide-night1": "’s nachts",
+	"dateTimeFormat-medium": "{1} {0}",
+	"field-quarter-narrow-relative+-1": "vorig kwartaal",
+	"dateFormatItem-d": "d",
+	"dayPeriods-format-abbr-pm": "p.m.",
+	"dateFormatItem-h": "h a",
+	"quarters-standAlone-wide": [
+		"1e kwartaal",
+		"2e kwartaal",
+		"3e kwartaal",
+		"4e kwartaal"
+	],
+	"field-weekOfMonth-narrow": "wk v.d. mnd",
+	"dateFormatItem-y": "y",
+	"field-minute-relative+0": "binnen een minuut",
+	"field-year-short-relative+0": "dit jaar",
+	"dateFormatItem-EBhms": "E h:mm:ss B",
+	"field-year-short-relative+1": "volgend jaar",
+	"field-weekday": "dag van de week",
+	"dayPeriods-format-narrow-pm": "p.m.",
+	"field-tue-narrow-relative+-1": "afgelopen di",
+	"dateFormatItem-yMEd": "E d-M-y",
+	"dayPeriods-standAlone-wide-night1": "nacht",
+	"field-year-narrow-relative+-1": "vorig jaar",
+	"field-sat-relative+-1": "afgelopen zaterdag",
+	"dayPeriods-format-abbr-midnight": "middernacht",
+	"dayPeriods-format-narrow-morning1": "’s ochtends",
+	"dayPeriods-format-wide-morning1": "’s ochtends",
+	"dayPeriods-standAlone-abbr-midnight": "middernacht",
+	"dayPeriods-standAlone-narrow-pm": "p.m.",
+	"dayPeriods-standAlone-wide-morning1": "ochtend",
+	"field-mon-narrow-relative+0": "deze ma",
+	"field-mon-narrow-relative+1": "volgende week ma",
+	"field-second": "seconde",
+	"dateFormatItem-yMMMEd": "E d MMM y",
+	"field-year-relative+-1": "vorig jaar",
+	"field-weekdayOfMonth-short": "wkdag van de mnd",
+	"dateFormat-short": "dd-MM-y",
+	"eraNames": [
+		"voor Christus",
+		"na Christus"
+	],
+	"field-second-short": "sec",
+	"field-thu-short-relative+-1": "afgelopen donder.",
+	"field-zone": "tijdzone",
+	"field-dayperiod-narrow": "a.m./p.m.",
+	"field-sun-short-relative+-1": "afgelopen zon.",
+	"dayPeriods-standAlone-narrow-morning1": "ochtend",
+	"eraAbbr": [
+		"v.Chr.",
+		"n.Chr."
+	],
+	"field-week-short": "wk",
+	"dayPeriods-standAlone-abbr-am": "a.m.",
+	"dayPeriods-standAlone-wide-pm": "p.m.",
+	"dateFormatItem-ms": "mm:ss",
+	"field-day-relative+0": "vandaag",
+	"field-day-relative+1": "morgen",
+	"field-day-relative+2": "overmorgen",
+	"field-day-short-relative+0": "vandaag",
+	"field-dayOfYear-short": "dag van het jr",
+	"field-day-short-relative+1": "morgen",
+	"dateFormat-long": "d MMMM y",
+	"field-day-short-relative+2": "overmorgen",
+	"field-sun-narrow-relative+-1": "afgelopen zo",
+	"field-second-relative+0": "nu",
+	"field-quarter-relative+-1": "vorig kwartaal",
+	"dayPeriods-format-narrow-night1": "’s nachts",
+	"quarters-format-abbr": [
+		"K1",
+		"K2",
+		"K3",
+		"K4"
+	],
+	"dayPeriods-standAlone-narrow-night1": "nacht",
+	"field-week-relative+-1": "vorige week",
+	"dayPeriods-format-abbr-morning1": "’s ochtends",
+	"field-month-relative+-1": "vorige maand",
+	"months-format-narrow": [
+		"J",
+		"F",
+		"M",
+		"A",
+		"M",
+		"J",
+		"J",
+		"A",
+		"S",
+		"O",
+		"N",
+		"D"
+	],
+	"field-year": "jaar",
+	"field-era": "tijdperk",
+	"dayPeriods-standAlone-abbr-morning1": "ochtend",
+	"days-standAlone-short": [
+		"zo",
+		"ma",
+		"di",
+		"wo",
+		"do",
+		"vr",
+		"za"
+	],
+	"quarters-format-narrow": [
+		"1",
+		"2",
+		"3",
+		"4"
+	],
+	"dateFormatItem-yQQQQ": "QQQQ y",
+	"field-day-short-relative+-1": "gisteren",
+	"field-day-short-relative+-2": "eergisteren",
+	"dateFormatItem-GyMMM": "MMM y G",
+	"timeFormat-full": "HH:mm:ss zzzz",
+	"dateFormatItem-Bhms": "h:mm:ss B",
+	"field-hour": "uur",
+	"field-dayOfYear-narrow": "dag v.h. jr",
+	"field-second-narrow-relative+0": "nu",
+	"field-quarter": "kwartaal",
+	"field-month-narrow-relative+0": "deze maand",
+	"field-month-narrow-relative+1": "volgende maand",
+	"field-day": "dag",
+	"field-mon-relative+-1": "afgelopen maandag",
+	"field-dayOfYear": "dag van het jaar",
+	"dateFormat-medium": "d MMM y",
+	"dateTimeFormat-short": "{1} {0}",
+	"dateFormatItem-yMMM": "MMM y",
+	"dateFormatItem-GyMMMd": "d MMM y G",
+	"dateFormatItem-MEd": "E d-M",
+	"field-tue-short-relative+-1": "afgelopen dins.",
+	"field-year-short": "jr",
+	"field-month-short": "mnd",
+	"dateFormatItem-MMMEd": "E d MMM",
+	"dayPeriods-format-wide-afternoon1": "’s middags",
+	"dateFormatItem-MMMd": "d MMM",
+	"dateFormatItem-Bh": "h B",
+	"months-format-abbr": [
+		"jan.",
+		"feb.",
+		"mrt.",
+		"apr.",
+		"mei",
+		"jun.",
+		"jul.",
+		"aug.",
+		"sep.",
+		"okt.",
+		"nov.",
+		"dec."
+	],
+	"dayPeriods-format-abbr-am": "a.m.",
+	"field-sat-relative+0": "deze zaterdag",
+	"field-sat-relative+1": "volgende week zaterdag",
+	"dayPeriods-format-wide-pm": "p.m.",
 	"days-standAlone-abbr": [
 		"zo",
 		"ma",
@@ -295,21 +327,96 @@ define(
 		"vr",
 		"za"
 	],
-	"dateTimeFormat-full": "{1} 'om' {0}",
-	"field-second-narrow-relative+0": "nu",
-	"dateFormatItem-hm": "h:mm a",
-	"dateFormatItem-d": "d",
-	"field-weekday": "dag van de week",
-	"dayPeriods-standAlone-wide-evening1": "avond",
-	"field-day-short-relative+0": "vandaag",
-	"field-quarter-narrow-relative+0": "dit kwartaal",
-	"field-day-short-relative+1": "morgen",
-	"field-sat-relative+0": "deze zaterdag",
-	"dateFormatItem-h": "h a",
-	"field-quarter-narrow-relative+1": "volgend kwartaal",
-	"field-day-short-relative+2": "overmorgen",
-	"field-sat-relative+1": "volgende week zaterdag",
+	"field-zone-short": "zone",
 	"field-week-short-relative+0": "deze week",
+	"field-week-short-relative+1": "volgende week",
+	"dayPeriods-standAlone-wide-afternoon1": "middag",
+	"field-fri-short-relative+-1": "afgelopen vrij.",
+	"field-month-narrow": "mnd",
+	"dayPeriods-format-narrow-am": "a.m.",
+	"field-month-narrow-relative+-1": "vorige maand",
+	"days-format-abbr": [
+		"zo",
+		"ma",
+		"di",
+		"wo",
+		"do",
+		"vr",
+		"za"
+	],
+	"field-weekday-short": "dag van de wk",
+	"field-day-narrow-relative+-1": "gisteren",
+	"field-day-narrow-relative+-2": "eergisteren",
+	"field-quarter-short": "kwartaal",
+	"days-format-short": [
+		"zo",
+		"ma",
+		"di",
+		"wo",
+		"do",
+		"vr",
+		"za"
+	],
+	"months-standAlone-narrow": [
+		"J",
+		"F",
+		"M",
+		"A",
+		"M",
+		"J",
+		"J",
+		"A",
+		"S",
+		"O",
+		"N",
+		"D"
+	],
+	"days-format-narrow": [
+		"Z",
+		"M",
+		"D",
+		"W",
+		"D",
+		"V",
+		"Z"
+	],
+	"dateFormatItem-EHm": "E HH:mm",
+	"field-quarter-narrow": "kwartaal",
+	"field-mon-short-relative+0": "deze maan.",
+	"field-mon-short-relative+1": "volgende week maan.",
+	"field-dayperiod-short": "a.m./p.m.",
+	"dayPeriods-standAlone-narrow-am": "a.m.",
+	"field-week-narrow-relative+-1": "vorige week",
+	"field-thu-relative+-1": "afgelopen donderdag",
+	"field-fri-narrow-relative+-1": "afgelopen vr",
+	"field-mon-short-relative+-1": "afgelopen maan.",
+	"timeFormat-medium": "HH:mm:ss",
+	"field-quarter-short-relative+0": "dit kwartaal",
+	"field-quarter-short-relative+1": "volgend kwartaal",
+	"dateFormatItem-Ed": "E d",
+	"field-wed-relative+-1": "afgelopen woensdag",
+	"field-weekOfMonth": "week van de maand",
+	"field-weekdayOfMonth-narrow": "wkdag v.d. mnd",
+	"dayPeriods-standAlone-wide-am": "a.m.",
+	"dateFormatItem-yQQQ": "QQQ y",
+	"field-fri-relative+-1": "afgelopen vrijdag",
+	"field-minute": "minuut",
+	"quarters-standAlone-narrow": [
+		"1",
+		"2",
+		"3",
+		"4"
+	],
+	"field-second-short-relative+0": "nu",
+	"quarters-format-wide": [
+		"1e kwartaal",
+		"2e kwartaal",
+		"3e kwartaal",
+		"4e kwartaal"
+	],
+	"field-day-short": "dag",
+	"field-dayperiod": "a.m./p.m.",
+	"field-hour-short": "uur",
 	"months-standAlone-abbr": [
 		"jan.",
 		"feb.",
@@ -324,132 +431,51 @@ define(
 		"nov.",
 		"dec."
 	],
-	"dateFormatItem-hmsv": "h:mm:ss a v",
-	"field-week-short-relative+1": "volgende week",
-	"dayPeriods-format-abbr-morning1": "ochtend",
-	"dayPeriods-standAlone-narrow-evening1": "avond",
-	"field-month-short-relative+0": "deze maand",
-	"timeFormat-full": "HH:mm:ss zzzz",
-	"field-month-short-relative+1": "volgende maand",
-	"dateFormatItem-MEd": "E d-M",
-	"dateFormatItem-y": "y",
-	"field-thu-narrow-relative+0": "deze do",
-	"field-sun-narrow-relative+-1": "afgelopen zo",
-	"field-mon-short-relative+-1": "afgelopen maan.",
-	"field-thu-narrow-relative+1": "volgende week do",
-	"field-thu-relative+0": "deze donderdag",
-	"dayPeriods-standAlone-abbr-afternoon1": "middag",
-	"field-thu-relative+1": "volgende week donderdag",
-	"dateFormatItem-hms": "h:mm:ss a",
-	"field-fri-short-relative+-1": "afgelopen vrij.",
-	"dateFormatItem-hmv": "h:mm a v",
-	"field-thu-relative+-1": "afgelopen donderdag",
-	"dateFormatItem-yMd": "d-M-y",
-	"quarters-standAlone-narrow": [
-		"1",
-		"2",
-		"3",
-		"4"
-	],
-	"field-week": "week",
-	"quarters-format-wide": [
-		"1e kwartaal",
-		"2e kwartaal",
-		"3e kwartaal",
-		"4e kwartaal"
-	],
-	"dateFormatItem-Ed": "E d",
-	"field-wed-narrow-relative+0": "deze wo",
-	"field-wed-narrow-relative+1": "volgende week wo",
-	"dayPeriods-standAlone-wide-morning1": "ochtend",
-	"field-quarter-narrow-relative+-1": "vorig kwartaal",
-	"field-year-short-relative+0": "dit jaar",
-	"field-year-short-relative+1": "volgend jaar",
-	"field-fri-short-relative+0": "deze vrij.",
-	"field-fri-short-relative+1": "volgende week vrij.",
-	"days-standAlone-short": [
-		"zo",
-		"ma",
-		"di",
-		"wo",
-		"do",
-		"vr",
-		"za"
-	],
+	"field-month-relative+0": "deze maand",
+	"field-second-narrow": "s",
+	"field-month-relative+1": "volgende maand",
+	"dateFormat-full": "EEEE d MMMM y",
+	"field-era-narrow": "tijdperk",
+	"field-sat-short-relative+-1": "afgelopen zater.",
 	"field-week-short-relative+-1": "vorige week",
-	"dayPeriods-standAlone-narrow-morning1": "ochtend",
-	"dayPeriods-format-abbr-midnight": "middernacht",
-	"field-hour-short": "uur",
-	"quarters-format-abbr": [
+	"dateTimeFormat-long": "{1} 'om' {0}",
+	"dateFormatItem-yM": "M-y",
+	"field-sun-relative+-1": "afgelopen zondag",
+	"field-wed-short-relative+-1": "afgelopen woens.",
+	"field-weekdayOfMonth": "weekdag van de maand",
+	"field-quarter-narrow-relative+0": "dit kwartaal",
+	"dateFormatItem-GyMMMEd": "E d MMM y G",
+	"field-quarter-narrow-relative+1": "volgend kwartaal",
+	"field-sat-short-relative+0": "deze zater.",
+	"field-hour-narrow": "u",
+	"field-sat-short-relative+1": "volgende week zater.",
+	"field-year-narrow-relative+0": "dit jaar",
+	"field-year-narrow-relative+1": "volgend jaar",
+	"dateFormatItem-Gy": "y G",
+	"field-zone-narrow": "zone",
+	"field-tue-relative+-1": "afgelopen dinsdag",
+	"field-minute-short": "min",
+	"dateFormatItem-yw": "'week' w 'in' Y",
+	"dateFormatItem-Hm": "HH:mm",
+	"field-week-relative+0": "deze week",
+	"field-week-relative+1": "volgende week",
+	"dateFormatItem-MMM": "LLL",
+	"field-sun-relative+0": "deze zondag",
+	"field-sun-relative+1": "volgende week zondag",
+	"field-sat-narrow-relative+-1": "afgelopen za",
+	"quarters-standAlone-abbr": [
 		"K1",
 		"K2",
 		"K3",
 		"K4"
 	],
-	"field-month-narrow": "mnd",
-	"field-hour-narrow": "uur",
-	"field-fri-narrow-relative+-1": "afgelopen vr",
-	"field-year-relative+0": "dit jaar",
-	"field-year-relative+1": "volgend jaar",
-	"field-fri-relative+-1": "afgelopen vrijdag",
-	"eraNarrow": [
-		"v.C.",
-		"vgj",
-		"n.C.",
-		"gj"
-	],
-	"field-tue-short-relative+-1": "afgelopen dins.",
-	"field-minute-narrow": "min",
-	"dayPeriods-standAlone-wide-afternoon1": "middag",
-	"dateFormatItem-yQQQ": "QQQ y",
-	"days-format-wide": [
-		"zondag",
-		"maandag",
-		"dinsdag",
-		"woensdag",
-		"donderdag",
-		"vrijdag",
-		"zaterdag"
-	],
-	"field-mon-narrow-relative+0": "deze ma",
-	"dateFormatItem-EHm": "E HH:mm",
-	"field-mon-narrow-relative+1": "volgende week ma",
-	"dayPeriods-standAlone-wide-midnight": "middernacht",
-	"field-year-short-relative+-1": "vorig jaar",
-	"dateFormatItem-yM": "M-y",
-	"field-zone": "tijdzone",
-	"dateFormatItem-yMMMM": "MMMM y",
-	"dateFormatItem-MMMEd": "E d MMM",
+	"dateFormatItem-MMMMW": "'week' W 'van' MMMM",
+	"field-month-short-relative+-1": "vorige maand",
 	"dateFormatItem-EHms": "E HH:mm:ss",
-	"dateFormatItem-yMEd": "E d-M-y",
-	"dayPeriods-standAlone-narrow-midnight": "middernacht",
-	"field-quarter-narrow": "kwartaal",
-	"dayPeriods-standAlone-abbr-am": "a.m.",
-	"field-day-relative+-1": "gisteren",
-	"field-sun-short-relative+-1": "afgelopen zon.",
-	"field-day-relative+-2": "eergisteren",
-	"dayPeriods-format-narrow-night1": "‘s nachts",
-	"days-format-abbr": [
-		"zo",
-		"ma",
-		"di",
-		"wo",
-		"do",
-		"vr",
-		"za"
-	],
-	"field-sun-relative+0": "deze zondag",
-	"field-sun-relative+1": "volgende week zondag",
-	"dateFormatItem-yMMMd": "d MMM y",
-	"dateFormatItem-Gy": "y G",
-	"field-era": "tijdperk",
-	"field-week-narrow": "wk",
-	"field-day-short": "dag",
-	"dayPeriods-standAlone-abbr-evening1": "avond",
-	"field-fri-narrow-relative+0": "deze vr",
-	"dayPeriods-format-narrow-evening1": "‘s avonds",
-	"field-fri-narrow-relative+1": "volgende week vr",
-	"dayPeriods-standAlone-wide-am": "a.m."
+	"dateFormatItem-MMMMd": "d MMMM",
+	"field-hour-narrow-relative+0": "binnen een uur",
+	"field-week": "week",
+	"field-day-narrow": "dag"
 }
 //end v1.x content
 );
\ No newline at end of file
