@@ -11,23 +11,27 @@ define(
 	"field-month-narrow-relative+-1": "vorige maand",
 	"field-tue-narrow-relative+0": "deze di",
 	"field-tue-narrow-relative+1": "volgende week di",
-	"field-thu-short-relative+0": "deze donder.",
 	"field-day-short-relative+-1": "gisteren",
-	"field-thu-short-relative+1": "volgende week donder.",
+	"field-thu-short-relative+0": "deze donder.",
+	"dateTimeFormat-short": "{1} {0}",
 	"field-day-relative+0": "vandaag",
 	"field-day-short-relative+-2": "eergisteren",
+	"field-thu-short-relative+1": "volgende week donder.",
 	"field-day-relative+1": "morgen",
 	"field-week-narrow-relative+0": "deze week",
 	"field-day-relative+2": "overmorgen",
 	"field-week-narrow-relative+1": "volgende week",
 	"field-wed-narrow-relative+-1": "afgelopen wo",
 	"field-year-narrow": "jr",
+	"field-era-short": "tijdperk",
 	"field-year-narrow-relative+0": "dit jaar",
 	"field-tue-relative+0": "deze dinsdag",
 	"field-year-narrow-relative+1": "volgend jaar",
 	"field-tue-relative+1": "volgende week dinsdag",
+	"field-weekdayOfMonth": "weekdag van de maand",
 	"field-second-short": "sec",
 	"dateFormatItem-MMMd": "d MMM",
+	"field-weekdayOfMonth-narrow": "wkdag v.d. mnd",
 	"field-week-relative+0": "deze week",
 	"field-month-relative+0": "deze maand",
 	"field-week-relative+1": "volgende week",
@@ -38,20 +42,28 @@ define(
 	"field-mon-short-relative+1": "volgende week maan.",
 	"field-second-relative+0": "nu",
 	"dateFormatItem-yyyyQQQ": "QQQ y G",
+	"eraNames": [
+		"voor R.O.C.",
+		"Minguo"
+	],
+	"field-weekOfMonth": "week van de maand",
 	"field-month-short": "mnd",
 	"dateFormatItem-GyMMMEd": "E d MMM y G",
 	"dateFormatItem-yyyyMd": "d-M-y GGGGG",
 	"field-day": "dag",
+	"field-dayOfYear-short": "dag van het jr",
 	"field-year-relative+-1": "vorig jaar",
 	"field-sat-short-relative+-1": "afgelopen zater.",
 	"field-hour-relative+0": "binnen een uur",
 	"dateFormatItem-yyyyMEd": "E d-M-y GGGGG",
 	"field-second-short-relative+0": "nu",
 	"field-wed-relative+-1": "afgelopen woensdag",
+	"dateTimeFormat-medium": "{1} {0}",
 	"field-sat-narrow-relative+-1": "afgelopen za",
 	"field-second": "seconde",
 	"dateFormat-long": "d MMMM y G",
 	"dateFormatItem-GyMMMd": "d MMM y G",
+	"field-hour-short-relative+0": "binnen een uur",
 	"field-quarter": "kwartaal",
 	"field-week-short": "wk",
 	"field-day-narrow-relative+0": "vandaag",
@@ -66,7 +78,7 @@ define(
 	"field-day-narrow": "dag",
 	"dateFormatItem-MMM": "LLL",
 	"field-minute-short": "min",
-	"field-dayperiod": "dagdeel",
+	"field-dayperiod": "a.m./p.m.",
 	"field-sat-short-relative+0": "deze zater.",
 	"field-sat-short-relative+1": "volgende week zater.",
 	"dateFormat-medium": "d MMM y G",
@@ -84,10 +96,14 @@ define(
 	"field-day-narrow-relative+-2": "eergisteren",
 	"field-quarter-relative+-1": "vorig kwartaal",
 	"dateFormatItem-yyyyMMMd": "d MMM y G",
+	"field-dayperiod-narrow": "a.m./p.m.",
 	"field-week-narrow-relative+-1": "vorige week",
+	"field-dayOfYear": "dag van het jaar",
 	"field-sat-relative+-1": "afgelopen zaterdag",
+	"dateTimeFormat-long": "{1} 'om' {0}",
 	"dateFormatItem-Md": "d-M",
 	"field-hour": "uur",
+	"field-minute-narrow-relative+0": "binnen een minuut",
 	"dateFormat-full": "EEEE d MMMM y G",
 	"field-month-relative+-1": "vorige maand",
 	"field-quarter-short": "kwartaal",
@@ -101,23 +117,27 @@ define(
 	"field-sun-short-relative+1": "volgende week zon.",
 	"field-week-relative+-1": "vorige week",
 	"field-quarter-short-relative+-1": "vorig kwartaal",
+	"field-minute-short-relative+0": "binnen een minuut",
 	"field-quarter-relative+0": "dit kwartaal",
 	"field-minute-relative+0": "binnen een minuut",
 	"field-quarter-relative+1": "volgend kwartaal",
 	"field-wed-short-relative+-1": "afgelopen woens.",
 	"dateFormat-short": "dd-MM-yy GGGGG",
-	"field-thu-short-relative+-1": "afgelopen donder.",
 	"field-year-narrow-relative+-1": "vorig jaar",
+	"field-thu-short-relative+-1": "afgelopen donder.",
 	"dateFormatItem-yyyyMMMEd": "E d MMM y G",
 	"field-mon-narrow-relative+-1": "afgelopen ma",
 	"dateFormatItem-MMMMd": "d MMMM",
 	"field-thu-narrow-relative+-1": "afgelopen do",
+	"dateFormatItem-E": "ccc",
 	"field-tue-narrow-relative+-1": "afgelopen di",
+	"field-weekOfMonth-short": "wk van de mnd",
 	"dateFormatItem-yyyy": "y G",
-	"field-wed-short-relative+0": "deze woens.",
 	"dateFormatItem-M": "L",
+	"field-wed-short-relative+0": "deze woens.",
 	"field-wed-short-relative+1": "volgende week woens.",
 	"field-sun-relative+-1": "afgelopen zondag",
+	"dateTimeFormat-full": "{1} 'om' {0}",
 	"field-second-narrow-relative+0": "nu",
 	"dateFormatItem-d": "d",
 	"field-weekday": "dag van de week",
@@ -130,14 +150,17 @@ define(
 	"field-sat-relative+1": "volgende week zaterdag",
 	"field-week-short-relative+0": "deze week",
 	"field-week-short-relative+1": "volgende week",
+	"field-dayOfYear-narrow": "dag v.h. jr",
 	"field-month-short-relative+0": "deze maand",
 	"field-month-short-relative+1": "volgende maand",
+	"field-weekdayOfMonth-short": "wkdag van de mnd",
 	"dateFormatItem-MEd": "E d-M",
+	"field-zone-narrow": "zone",
 	"dateFormatItem-y": "y G",
 	"field-thu-narrow-relative+0": "deze do",
-	"field-thu-narrow-relative+1": "volgende week do",
 	"field-sun-narrow-relative+-1": "afgelopen zo",
 	"field-mon-short-relative+-1": "afgelopen maan.",
+	"field-thu-narrow-relative+1": "volgende week do",
 	"field-thu-relative+0": "deze donderdag",
 	"field-thu-relative+1": "volgende week donderdag",
 	"field-fri-short-relative+-1": "afgelopen vrij.",
@@ -149,18 +172,26 @@ define(
 	"field-quarter-narrow-relative+-1": "vorig kwartaal",
 	"field-year-short-relative+0": "dit jaar",
 	"dateFormatItem-yyyyMMM": "MMM y G",
+	"field-dayperiod-short": "a.m./p.m.",
 	"field-year-short-relative+1": "volgend jaar",
 	"field-fri-short-relative+0": "deze vrij.",
 	"field-fri-short-relative+1": "volgende week vrij.",
 	"field-week-short-relative+-1": "vorige week",
+	"field-hour-narrow-relative+0": "binnen een uur",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
 	"field-hour-short": "uur",
+	"field-zone-short": "zone",
 	"field-month-narrow": "mnd",
-	"field-hour-narrow": "uur",
+	"field-hour-narrow": "u",
 	"field-fri-narrow-relative+-1": "afgelopen vr",
 	"field-year-relative+0": "dit jaar",
 	"field-year-relative+1": "volgend jaar",
+	"field-era-narrow": "tijdperk",
 	"field-fri-relative+-1": "afgelopen vrijdag",
+	"eraNarrow": [
+		"voor R.O.C.",
+		"Minguo"
+	],
 	"field-tue-short-relative+-1": "afgelopen dins.",
 	"field-minute-narrow": "min",
 	"field-mon-narrow-relative+0": "deze ma",
@@ -168,10 +199,13 @@ define(
 	"field-year-short-relative+-1": "vorig jaar",
 	"field-zone": "tijdzone",
 	"dateFormatItem-MMMEd": "E d MMM",
+	"field-weekOfMonth-narrow": "wk v.d. mnd",
+	"field-weekday-narrow": "dag v.d. wk",
 	"field-quarter-narrow": "kwartaal",
 	"field-sun-short-relative+-1": "afgelopen zon.",
 	"field-day-relative+-1": "gisteren",
 	"field-day-relative+-2": "eergisteren",
+	"field-weekday-short": "dag van de wk",
 	"field-sun-relative+0": "deze zondag",
 	"field-sun-relative+1": "volgende week zondag",
 	"dateFormatItem-Gy": "y G",
