@@ -1,6 +1,76 @@
 define(
 //begin v1.x content
 {
+	"field-quarter-short-relative+0": "w tym kwartale",
+	"field-quarter-short-relative+1": "w przyszłym kwartale",
+	"field-tue-relative+-1": "w zeszły wtorek",
+	"field-year": "rok",
+	"field-wed-relative+0": "w tę środę",
+	"field-wed-relative+1": "w przyszłą środę",
+	"field-minute": "minuta",
+	"field-month-narrow-relative+-1": "w zeszłym mies.",
+	"field-tue-narrow-relative+0": "w ten wtorek",
+	"field-tue-narrow-relative+1": "w przyszły wtorek",
+	"field-thu-short-relative+0": "w ten czwartek",
+	"field-thu-short-relative+1": "w przyszły czwartek",
+	"field-day-relative+0": "dzisiaj",
+	"field-day-short-relative+-2": "przedwczoraj",
+	"field-day-relative+1": "jutro",
+	"field-week-narrow-relative+0": "w tym tyg.",
+	"field-day-relative+2": "pojutrze",
+	"field-week-narrow-relative+1": "w przyszłym tyg.",
+	"field-wed-narrow-relative+-1": "w zeszłą środę",
+	"field-year-narrow": "r.",
+	"field-era-short": "era",
+	"field-year-narrow-relative+0": "w tym roku",
+	"field-tue-relative+0": "w ten wtorek",
+	"field-year-narrow-relative+1": "w przyszłym roku",
+	"field-tue-relative+1": "w przyszły wtorek",
+	"field-weekdayOfMonth": "dzień miesiąca",
+	"field-second-short": "sek.",
+	"field-weekdayOfMonth-narrow": "dz. mies.",
+	"field-week-relative+0": "w tym tygodniu",
+	"field-month-relative+0": "w tym miesiącu",
+	"field-week-relative+1": "w przyszłym tygodniu",
+	"field-month-relative+1": "w przyszłym miesiącu",
+	"field-sun-narrow-relative+0": "w tę niedzielę",
+	"field-mon-short-relative+0": "w ten poniedziałek",
+	"field-sun-narrow-relative+1": "w przyszłą niedzielę",
+	"field-mon-short-relative+1": "w przyszły poniedziałek",
+	"field-second-relative+0": "teraz",
+	"field-weekOfMonth": "tydzień miesiąca",
+	"field-month-short": "mies.",
+	"field-day": "dzień",
+	"field-dayOfYear-short": "dz. roku",
+	"field-year-relative+-1": "w zeszłym roku",
+	"field-sat-short-relative+-1": "w zeszłą sobotę",
+	"field-hour-relative+0": "ta godzina",
+	"field-wed-relative+-1": "w zeszłą środę",
+	"field-sat-narrow-relative+-1": "w zeszłą sobotę",
+	"field-second": "sekunda",
+	"dateFormat-long": "d MMMM U",
+	"field-quarter": "kwartał",
+	"field-week-short": "tydz.",
+	"field-day-narrow-relative+0": "dziś",
+	"field-day-narrow-relative+1": "jutro",
+	"field-day-narrow-relative+2": "pojutrze",
+	"field-tue-short-relative+0": "w ten wtorek",
+	"field-tue-short-relative+1": "w przyszły wtorek",
+	"field-month-short-relative+-1": "w zeszłym mies.",
+	"field-mon-relative+-1": "w zeszły poniedziałek",
+	"field-month": "miesiąc",
+	"field-day-narrow": "d.",
+	"field-minute-short": "min",
+	"field-dayperiod": "rano / po południu / wieczorem",
+	"field-sat-short-relative+0": "w tę sobotę",
+	"field-sat-short-relative+1": "w przyszłą sobotę",
+	"dateFormat-medium": "d MMM U",
+	"field-second-narrow": "s",
+	"field-mon-relative+0": "w ten poniedziałek",
+	"field-mon-relative+1": "w przyszły poniedziałek",
+	"field-day-narrow-relative+-1": "wcz.",
+	"field-year-short": "r.",
+	"field-day-narrow-relative+-2": "przedwczoraj",
 	"months-format-narrow": [
 		"1",
 		"2",
@@ -15,45 +85,25 @@ define(
 		"11",
 		"12"
 	],
-	"field-second-relative+0": "teraz",
 	"field-quarter-relative+-1": "w zeszłym kwartale",
-	"field-weekday": "dzień tygodnia",
-	"field-mon-narrow-relative+0": "w ten poniedziałek",
-	"field-mon-narrow-relative+1": "w przyszły poniedziałek",
-	"field-wed-relative+0": "w tę środę",
-	"field-wed-relative+1": "w przyszłą środę",
-	"field-week-short": "tydz.",
-	"field-tue-relative+-1": "w zeszły wtorek",
-	"field-year-short": "r.",
-	"field-thu-narrow-relative+-1": "w zeszły czwartek",
-	"field-hour-relative+0": "ta godzina",
-	"dateFormat-long": "d MMMM U",
-	"field-quarter-narrow": "kw.",
-	"field-fri-relative+-1": "w zeszły piątek",
-	"field-hour-short": "godz.",
-	"field-wed-relative+-1": "w zeszłą środę",
-	"dateFormat-full": "EEEE, d MMMM U",
-	"field-mon-short-relative+-1": "w zeszły poniedziałek",
-	"field-thu-relative+-1": "w zeszły czwartek",
-	"field-era": "era",
-	"months-standAlone-wide": [
-		"1",
-		"2",
-		"3",
-		"4",
-		"5",
-		"6",
-		"7",
-		"8",
-		"9",
-		"10",
-		"11",
-		"12"
-	],
-	"field-sat-narrow-relative+0": "w tę sobotę",
-	"field-sat-narrow-relative+1": "w przyszłą sobotę",
-	"field-year": "rok",
+	"field-dayperiod-narrow": "rano / po poł. / wiecz.",
+	"field-week-narrow-relative+-1": "w zeszłym tyg.",
+	"field-dayOfYear": "dzień roku",
+	"field-sat-relative+-1": "w zeszłą sobotę",
 	"field-hour": "godzina",
+	"dateFormat-full": "EEEE, d MMMM U",
+	"field-month-relative+-1": "w zeszłym miesiącu",
+	"field-quarter-short": "kw.",
+	"field-sat-narrow-relative+0": "w tę sobotę",
+	"field-fri-relative+0": "w ten piątek",
+	"field-sat-narrow-relative+1": "w przyszłą sobotę",
+	"field-fri-relative+1": "w przyszły piątek",
+	"field-month-narrow-relative+0": "w tym mies.",
+	"field-month-narrow-relative+1": "w przyszłym mies.",
+	"field-sun-short-relative+0": "w tę niedzielę",
+	"field-sun-short-relative+1": "w przyszłą niedzielę",
+	"field-week-relative+-1": "w zeszłym tygodniu",
+	"field-quarter-short-relative+-1": "w zeszłym kwartale",
 	"months-format-abbr": [
 		"1",
 		"2",
@@ -68,17 +118,42 @@ define(
 		"11",
 		"12"
 	],
-	"field-sat-relative+0": "w tę sobotę",
-	"field-sat-relative+1": "w przyszłą sobotę",
-	"field-sat-short-relative+-1": "w zeszłą sobotę",
-	"field-minute-narrow": "min",
-	"field-day-relative+0": "dzisiaj",
-	"field-day-relative+1": "jutro",
-	"field-thu-relative+0": "w ten czwartek",
+	"field-quarter-relative+0": "w tym kwartale",
+	"field-minute-relative+0": "ta minuta",
+	"field-quarter-relative+1": "w przyszłym kwartale",
+	"field-wed-short-relative+-1": "w zeszłą środę",
+	"dateFormat-short": "dd.MM.y",
+	"field-thu-short-relative+-1": "w zeszły czwartek",
+	"field-year-narrow-relative+-1": "w zeszłym roku",
 	"field-mon-narrow-relative+-1": "w zeszły poniedziałek",
-	"field-day-relative+2": "pojutrze",
-	"field-wed-narrow-relative+0": "w tę środę",
-	"field-thu-relative+1": "w przyszły czwartek",
+	"field-thu-narrow-relative+-1": "w zeszły czwartek",
+	"field-tue-narrow-relative+-1": "w zeszły wtorek",
+	"field-weekOfMonth-short": "tydz. mies.",
+	"field-wed-short-relative+0": "w tę środę",
+	"months-standAlone-wide": [
+		"1",
+		"2",
+		"3",
+		"4",
+		"5",
+		"6",
+		"7",
+		"8",
+		"9",
+		"10",
+		"11",
+		"12"
+	],
+	"field-wed-short-relative+1": "w przyszłą środę",
+	"field-sun-relative+-1": "w zeszłą niedzielę",
+	"field-weekday": "dzień tygodnia",
+	"field-quarter-narrow-relative+0": "w tym kwartale",
+	"field-sat-relative+0": "w tę sobotę",
+	"field-quarter-narrow-relative+1": "w przyszłym kwartale",
+	"field-sat-relative+1": "w przyszłą sobotę",
+	"field-day-short-relative+2": "pojutrze",
+	"field-week-short-relative+0": "w tym tyg.",
+	"field-week-short-relative+1": "w przyszłym tyg.",
 	"months-standAlone-abbr": [
 		"1",
 		"2",
@@ -93,91 +168,58 @@ define(
 		"11",
 		"12"
 	],
+	"field-dayOfYear-narrow": "dz. r.",
+	"field-month-short-relative+0": "w tym mies.",
+	"field-month-short-relative+1": "w przyszłym mies.",
+	"field-weekdayOfMonth-short": "dzień mies.",
+	"field-zone-narrow": "str. czas.",
+	"field-thu-narrow-relative+0": "w ten czwartek",
+	"field-thu-narrow-relative+1": "w przyszły czwartek",
+	"field-sun-narrow-relative+-1": "w zeszłą niedzielę",
+	"field-mon-short-relative+-1": "w zeszły poniedziałek",
+	"field-thu-relative+0": "w ten czwartek",
+	"field-thu-relative+1": "w przyszły czwartek",
+	"field-fri-short-relative+-1": "w zeszły piątek",
+	"field-thu-relative+-1": "w zeszły czwartek",
+	"field-week": "tydzień",
+	"field-wed-narrow-relative+0": "w tę środę",
 	"field-wed-narrow-relative+1": "w przyszłą środę",
-	"field-mon-short-relative+0": "w ten poniedziałek",
-	"field-mon-short-relative+1": "w przyszły poniedziałek",
-	"field-wed-short-relative+-1": "w zeszłą środę",
-	"field-fri-narrow-relative+-1": "w zeszły piątek",
+	"field-quarter-narrow-relative+-1": "w zeszłym kwartale",
+	"field-year-short-relative+0": "w tym roku",
+	"field-dayperiod-short": "rano / po południu / wieczorem",
+	"field-year-short-relative+1": "w przyszłym roku",
+	"field-fri-short-relative+0": "w ten piątek",
+	"field-fri-short-relative+1": "w przyszły piątek",
+	"field-week-short-relative+-1": "w zeszłym tyg.",
+	"field-hour-short": "godz.",
+	"field-zone-short": "str. czasowa",
+	"field-month-narrow": "mc",
 	"field-hour-narrow": "g.",
-	"field-tue-short-relative+0": "w ten wtorek",
-	"field-year-narrow": "r.",
-	"field-tue-short-relative+1": "w przyszły wtorek",
-	"field-minute-short": "min",
-	"field-day-narrow": "dzień",
-	"field-wed-short-relative+0": "w tę środę",
-	"field-wed-short-relative+1": "w przyszłą środę",
-	"field-sun-relative+0": "w tę niedzielę",
-	"field-sun-relative+1": "w przyszłą niedzielę",
-	"field-minute": "minuta",
-	"field-month-short": "mies.",
-	"field-dayperiod": "rano / po południu / wieczorem",
+	"field-fri-narrow-relative+-1": "w zeszły piątek",
+	"field-year-relative+0": "w tym roku",
+	"field-year-relative+1": "w przyszłym roku",
+	"field-era-narrow": "era",
+	"field-fri-relative+-1": "w zeszły piątek",
+	"field-tue-short-relative+-1": "w zeszły wtorek",
+	"field-minute-narrow": "min",
+	"field-mon-narrow-relative+0": "w ten poniedziałek",
+	"field-mon-narrow-relative+1": "w przyszły poniedziałek",
+	"field-year-short-relative+-1": "w zeszłym roku",
+	"field-zone": "strefa czasowa",
+	"field-weekOfMonth-narrow": "tydz. mies.",
+	"field-weekday-narrow": "dz. tyg.",
+	"field-quarter-narrow": "kw.",
+	"field-sun-short-relative+-1": "w zeszłą niedzielę",
 	"field-day-relative+-1": "wczoraj",
 	"field-day-relative+-2": "przedwczoraj",
-	"field-minute-relative+0": "ta minuta",
+	"field-weekday-short": "dzień tyg.",
+	"field-sun-relative+0": "w tę niedzielę",
+	"field-sun-relative+1": "w przyszłą niedzielę",
+	"field-day-short": "dz.",
 	"field-week-narrow": "tydz.",
-	"field-wed-narrow-relative+-1": "w zeszłą środę",
-	"field-day-short": "dzień",
-	"field-quarter-relative+0": "w tym kwartale",
-	"field-quarter-relative+1": "w przyszłym kwartale",
-	"field-fri-relative+0": "w ten piątek",
-	"field-fri-relative+1": "w przyszły piątek",
-	"field-day": "dzień",
-	"field-second-narrow": "s",
-	"field-zone": "strefa czasowa",
-	"field-year-relative+-1": "w zeszłym roku",
-	"field-month-relative+-1": "w zeszłym miesiącu",
-	"field-thu-short-relative+0": "w ten czwartek",
-	"field-thu-short-relative+1": "w przyszły czwartek",
-	"field-quarter-narrow-relative+0": "w tym kwartale",
-	"field-quarter-narrow-relative+1": "w przyszłym kwartale",
-	"field-quarter": "kwartał",
-	"field-month": "miesiąc",
-	"field-tue-relative+0": "w ten wtorek",
-	"field-quarter-short-relative+0": "w tym kwartale",
-	"field-tue-relative+1": "w przyszły wtorek",
-	"field-quarter-short-relative+1": "w przyszłym kwartale",
+	"field-era": "era",
 	"field-fri-narrow-relative+0": "w ten piątek",
-	"field-fri-narrow-relative+1": "w przyszły piątek",
-	"field-fri-short-relative+-1": "w zeszły piątek",
-	"field-sun-narrow-relative+-1": "w zeszłą niedzielę",
-	"field-quarter-short-relative+-1": "w zeszłym kwartale",
-	"field-sun-narrow-relative+0": "w tę niedzielę",
-	"field-thu-narrow-relative+0": "w ten czwartek",
-	"field-sun-narrow-relative+1": "w przyszłą niedzielę",
-	"field-thu-narrow-relative+1": "w przyszły czwartek",
-	"field-tue-narrow-relative+0": "w ten wtorek",
-	"field-mon-relative+0": "w ten poniedziałek",
-	"field-tue-narrow-relative+1": "w przyszły wtorek",
-	"field-mon-relative+1": "w przyszły poniedziałek",
-	"dateFormat-short": "dd.MM.y",
-	"field-tue-narrow-relative+-1": "w zeszły wtorek",
-	"field-second-short": "sek.",
-	"field-second": "sekunda",
-	"field-fri-short-relative+0": "w ten piątek",
-	"field-sat-relative+-1": "w zeszłą sobotę",
-	"field-fri-short-relative+1": "w przyszły piątek",
-	"field-sun-relative+-1": "w zeszłą niedzielę",
-	"field-month-relative+0": "w tym miesiącu",
-	"field-quarter-narrow-relative+-1": "w zeszłym kwartale",
-	"field-month-relative+1": "w przyszłym miesiącu",
-	"field-week": "tydzień",
-	"field-sat-short-relative+0": "w tę sobotę",
-	"dateFormat-medium": "d MMM U",
-	"field-sat-short-relative+1": "w przyszłą sobotę",
-	"field-year-relative+0": "w tym roku",
-	"field-week-relative+-1": "w zeszłym tygodniu",
-	"field-year-relative+1": "w przyszłym roku",
-	"field-quarter-short": "kw.",
-	"field-sun-short-relative+-1": "w zeszłą niedzielę",
-	"field-thu-short-relative+-1": "w zeszły czwartek",
-	"field-tue-short-relative+-1": "w zeszły wtorek",
-	"field-mon-relative+-1": "w zeszły poniedziałek",
-	"field-sat-narrow-relative+-1": "w zeszłą sobotę",
-	"field-month-narrow": "mc",
-	"field-week-relative+0": "w tym tygodniu",
-	"field-sun-short-relative+0": "w tę niedzielę",
-	"field-week-relative+1": "w przyszłym tygodniu",
-	"field-sun-short-relative+1": "w przyszłą niedzielę"
+	"field-fri-narrow-relative+1": "w przyszły piątek"
 }
 //end v1.x content
 );
\ No newline at end of file
