@@ -2,23 +2,22 @@ define(
 //begin v1.x content
 {
 	"HKD_displayName": "dolar hongkoński",
-	"CNY_displayName": "juan chiński",
-	"JPY_displayName": "jen japoński",
-	"JPY_symbol": "JPY",
-	"USD_displayName": "dolar amerykański",
-	"CAD_symbol": "CAD",
-	"GBP_displayName": "funt szterling",
 	"CHF_displayName": "frank szwajcarski",
-	"CNY_symbol": "CNY",
-	"EUR_displayName": "euro",
-	"GBP_symbol": "GBP",
-	"CAD_displayName": "dolar kanadyjski",
-	"USD_symbol": "USD",
-	"EUR_symbol": "€",
-	"AUD_displayName": "dolar australijski",
 	"CHF_symbol": "CHF",
+	"JPY_symbol": "JPY",
+	"CAD_displayName": "dolar kanadyjski",
 	"HKD_symbol": "HKD",
-	"AUD_symbol": "AUD"
+	"CNY_displayName": "juan chiński",
+	"USD_symbol": "USD",
+	"AUD_displayName": "dolar australijski",
+	"JPY_displayName": "jen japoński",
+	"CAD_symbol": "CAD",
+	"USD_displayName": "dolar amerykański",
+	"CNY_symbol": "CNY",
+	"GBP_displayName": "funt szterling",
+	"GBP_symbol": "GBP",
+	"AUD_symbol": "AUD",
+	"EUR_displayName": "euro"
 }
 //end v1.x content
 );
\ No newline at end of file
