@@ -2,13 +2,13 @@ define(
 //begin v1.x content
 {
 	"days-standAlone-short": [
-		"domingo",
-		"segunda",
-		"terça",
-		"quarta",
-		"quinta",
-		"sexta",
-		"sábado"
+		"dom.",
+		"seg.",
+		"ter.",
+		"qua.",
+		"qui.",
+		"sex.",
+		"sáb."
 	],
 	"months-format-narrow": [
 		"J",
@@ -25,17 +25,22 @@ define(
 		"D"
 	],
 	"field-quarter-relative+-1": "trimestre passado",
+	"field-day-narrow-relative+0": "hoje",
+	"field-day-narrow-relative+1": "amanhã",
+	"field-day-short-relative+0": "hoje",
+	"field-day-short-relative+1": "amanhã",
 	"dateFormatItem-GyMMMEd": "E, d 'de' MMM 'de' y G",
 	"dateFormatItem-MMMEd": "E, d 'de' MMM",
-	"field-thu-narrow-relative+-1": "qui. passada",
+	"field-dayperiod-short": "am/pm",
+	"eraNarrow": "BE",
 	"days-format-short": [
-		"domingo",
-		"segunda",
-		"terça",
-		"quarta",
-		"quinta",
-		"sexta",
-		"sábado"
+		"dom.",
+		"seg.",
+		"ter.",
+		"qua.",
+		"qui.",
+		"sex.",
+		"sáb."
 	],
 	"dateFormat-long": "d 'de' MMMM 'de' y G",
 	"months-format-wide": [
@@ -58,6 +63,7 @@ define(
 	"dateFormat-full": "EEEE, d 'de' MMMM 'de' y G",
 	"dateFormatItem-yyyyMEd": "E, dd/MM/y GGGGG",
 	"field-mon-short-relative+-1": "segunda passada",
+	"field-day-short-relative+-1": "ontem",
 	"dateFormatItem-Md": "d/M",
 	"dayPeriods-standAlone-wide-pm": "tarde",
 	"dayPeriods-format-abbr-am": "a.m.",
@@ -83,38 +89,25 @@ define(
 		"4.º trimestre"
 	],
 	"dateFormatItem-yyyyMMMM": "MMMM 'de' y G",
+	"field-day-narrow-relative+-1": "ontem",
 	"months-format-abbr": [
-		"jan",
-		"fev",
-		"mar",
-		"abr",
-		"mai",
-		"jun",
-		"jul",
-		"ago",
-		"set",
-		"out",
-		"nov",
-		"dez"
+		"jan.",
+		"fev.",
+		"mar.",
+		"abr.",
+		"mai.",
+		"jun.",
+		"jul.",
+		"ago.",
+		"set.",
+		"out.",
+		"nov.",
+		"dez."
 	],
 	"field-sat-short-relative+-1": "sábado passado",
 	"dayPeriods-standAlone-narrow-am": "a.m.",
 	"field-minute-narrow": "min",
 	"dateFormatItem-GyMMMd": "d 'de' MMM 'de' y G",
-	"months-standAlone-abbr": [
-		"jan",
-		"fev",
-		"mar",
-		"abr",
-		"mai",
-		"jun",
-		"jul",
-		"ago",
-		"set",
-		"out",
-		"nov",
-		"dez"
-	],
 	"quarters-format-abbr": [
 		"1.º trimestre",
 		"2.º trimestre",
@@ -155,6 +148,7 @@ define(
 		"3.º trimestre",
 		"4.º trimestre"
 	],
+	"field-dayperiod": "am/pm",
 	"days-standAlone-abbr": [
 		"domingo",
 		"segunda",
@@ -168,8 +162,10 @@ define(
 	"dayPeriods-format-narrow-am": "a.m.",
 	"dateFormatItem-MMMd": "d 'de' MMM",
 	"field-quarter-relative+0": "este trimestre",
+	"field-dayperiod-narrow": "am/pm",
 	"field-quarter-relative+1": "próximo trimestre",
 	"dateFormatItem-MEd": "E, dd/MM",
+	"field-zone-short": "fuso horário",
 	"dateTimeFormat-full": "{1} 'às' {0}",
 	"days-format-wide": [
 		"domingo",
@@ -180,6 +176,7 @@ define(
 		"sexta-feira",
 		"sábado"
 	],
+	"field-second-narrow": "s",
 	"dateFormatItem-y": "y G",
 	"months-standAlone-narrow": [
 		"J",
@@ -210,6 +207,9 @@ define(
 		"sábado"
 	],
 	"dayPeriods-standAlone-abbr-pm": "p.m.",
+	"eraNames": [
+		"BE"
+	],
 	"days-format-narrow": [
 		"D",
 		"S",
@@ -220,6 +220,7 @@ define(
 		"S"
 	],
 	"dateFormatItem-yyyyMd": "dd/MM/y GGGGG",
+	"field-zone-narrow": "fuso horário",
 	"days-standAlone-narrow": [
 		"D",
 		"S",
@@ -236,8 +237,6 @@ define(
 	"dayPeriods-standAlone-wide-am": "manhã",
 	"field-fri-short-relative+-1": "sexta passada",
 	"field-quarter-short-relative+-1": "trim. passado",
-	"field-thu-narrow-relative+0": "esta qui.",
-	"field-thu-narrow-relative+1": "próxima qui.",
 	"dateFormat-short": "d/M/y G",
 	"field-second-short": "s",
 	"field-fri-short-relative+0": "esta sexta",
@@ -245,8 +244,8 @@ define(
 	"field-quarter-narrow-relative+-1": "trim. passado",
 	"dateFormatItem-Ed": "E, d",
 	"field-sat-short-relative+0": "este sábado",
-	"dateFormat-medium": "dd/MM/y G",
 	"field-sat-short-relative+1": "próximo sábado",
+	"dateFormat-medium": "d MMM y G",
 	"dateFormatItem-yyyyM": "MM/y GGGGG",
 	"dayPeriods-format-narrow-pm": "p.m.",
 	"dateFormatItem-yyyyQQQQ": "QQQQ 'de' y G",
