@@ -1,24 +1,35 @@
 define(
 //begin v1.x content
 {
+	"field-quarter-short-relative+0": "este trimestre",
+	"field-quarter-short-relative+1": "próximo trimestre",
 	"field-tue-relative+-1": "terça-feira passada",
 	"field-year": "ano",
 	"field-wed-relative+0": "esta quarta-feira",
 	"field-wed-relative+1": "próxima quarta-feira",
 	"field-minute": "minuto",
+	"field-month-narrow-relative+-1": "mês passado",
 	"field-tue-narrow-relative+0": "esta ter.",
 	"field-tue-narrow-relative+1": "próxima ter.",
 	"field-thu-short-relative+0": "esta qui.",
-	"field-thu-short-relative+1": "próx. qui",
+	"field-thu-short-relative+1": "próxima qui.",
 	"field-day-relative+0": "hoje",
+	"field-day-short-relative+-2": "anteontem",
 	"field-day-relative+1": "amanhã",
+	"field-week-narrow-relative+0": "esta semana",
 	"field-day-relative+2": "depois de amanhã",
+	"field-week-narrow-relative+1": "próxima semana",
 	"field-wed-narrow-relative+-1": "qua. passada",
 	"field-year-narrow": "ano",
+	"field-era-short": "era",
+	"field-year-narrow-relative+0": "este ano",
 	"field-tue-relative+0": "esta terça-feira",
+	"field-year-narrow-relative+1": "próximo ano",
 	"field-tue-relative+1": "próxima terça-feira",
+	"field-weekdayOfMonth": "dia da semana do mês",
 	"field-second-short": "seg.",
 	"dateFormatItem-MMMd": "d 'de' MMM",
+	"field-weekdayOfMonth-narrow": "dia da sem. do mês",
 	"field-week-relative+0": "esta semana",
 	"field-month-relative+0": "este mês",
 	"field-week-relative+1": "próxima semana",
@@ -42,10 +53,15 @@ define(
 		"N",
 		"D"
 	],
+	"eraNames": [
+		"EB"
+	],
+	"field-weekOfMonth": "semana do mês",
 	"field-month-short": "mês",
 	"dateFormatItem-GyMMMEd": "E, d 'de' MMM 'de' y G",
 	"dateFormatItem-yyyyMd": "dd/MM/y GGGGG",
 	"field-day": "dia",
+	"field-dayOfYear-short": "dia do ano",
 	"field-year-relative+-1": "ano passado",
 	"field-sat-short-relative+-1": "sáb. passado",
 	"field-hour-relative+0": "esta hora",
@@ -66,6 +82,7 @@ define(
 	"dateFormatItem-GyMMMd": "d 'de' MMM 'de' y G",
 	"field-quarter": "trimestre",
 	"field-week-short": "sem.",
+	"field-day-narrow-relative+2": "depois de amanhã",
 	"quarters-standAlone-wide": [
 		"1º trimestre",
 		"2º trimestre",
@@ -83,6 +100,7 @@ define(
 	],
 	"field-tue-short-relative+0": "esta ter.",
 	"field-tue-short-relative+1": "próxima ter.",
+	"field-month-short-relative+-1": "mês passado",
 	"field-mon-relative+-1": "segunda-feira passada",
 	"dateFormatItem-GyMMM": "MMM 'de' y G",
 	"field-month": "mês",
@@ -91,7 +109,7 @@ define(
 	"field-dayperiod": "AM/PM",
 	"field-sat-short-relative+0": "este sáb.",
 	"field-sat-short-relative+1": "próximo sáb.",
-	"dateFormat-medium": "dd/MM/y G",
+	"dateFormat-medium": "d MMM y G",
 	"dateFormatItem-yyyyMMMM": "MMMM 'de' y G",
 	"eraAbbr": [
 		"BE"
@@ -103,10 +121,11 @@ define(
 		"T4"
 	],
 	"dateFormatItem-yyyyM": "MM/y GGGGG",
-	"field-second-narrow": "s",
+	"field-second-narrow": "seg.",
 	"field-mon-relative+0": "esta segunda-feira",
 	"field-mon-relative+1": "próxima segunda-feira",
 	"field-year-short": "ano",
+	"field-day-narrow-relative+-2": "anteontem",
 	"months-format-narrow": [
 		"J",
 		"F",
@@ -123,15 +142,18 @@ define(
 	],
 	"field-quarter-relative+-1": "último trimestre",
 	"dateFormatItem-yyyyMMMd": "d 'de' MMM 'de' y G",
+	"field-dayperiod-narrow": "AM/PM",
+	"field-week-narrow-relative+-1": "semana passada",
 	"days-format-short": [
-		"dom",
-		"seg",
-		"ter",
-		"qua",
-		"qui",
-		"sex",
-		"sáb"
+		"dom.",
+		"seg.",
+		"ter.",
+		"qua.",
+		"qui.",
+		"sex.",
+		"sáb."
 	],
+	"field-dayOfYear": "dia do ano",
 	"field-sat-relative+-1": "sábado passado",
 	"dateFormatItem-Md": "d/M",
 	"field-hour": "hora",
@@ -156,22 +178,25 @@ define(
 	"field-fri-relative+0": "esta sexta-feira",
 	"field-sat-narrow-relative+1": "próximo sáb.",
 	"field-fri-relative+1": "próxima sexta-feira",
+	"field-month-narrow-relative+0": "este mês",
+	"field-month-narrow-relative+1": "próximo mês",
 	"field-sun-short-relative+0": "este dom.",
 	"field-sun-short-relative+1": "próximo dom.",
 	"field-week-relative+-1": "semana passada",
+	"field-quarter-short-relative+-1": "último trimestre",
 	"months-format-abbr": [
-		"jan",
-		"fev",
-		"mar",
-		"abr",
-		"mai",
-		"jun",
-		"jul",
-		"ago",
-		"set",
-		"out",
-		"nov",
-		"dez"
+		"jan.",
+		"fev.",
+		"mar.",
+		"abr.",
+		"mai.",
+		"jun.",
+		"jul.",
+		"ago.",
+		"set.",
+		"out.",
+		"nov.",
+		"dez."
 	],
 	"field-quarter-relative+0": "este trimestre",
 	"field-minute-relative+0": "este minuto",
@@ -179,6 +204,7 @@ define(
 	"field-wed-short-relative+-1": "qua. passada",
 	"dateFormat-short": "dd/MM/y GGGGG",
 	"field-thu-short-relative+-1": "qui. passada",
+	"field-year-narrow-relative+-1": "ano passado",
 	"days-standAlone-wide": [
 		"domingo",
 		"segunda-feira",
@@ -193,6 +219,7 @@ define(
 	"dateFormatItem-MMMMd": "d 'de' MMMM",
 	"field-thu-narrow-relative+-1": "qui. passada",
 	"field-tue-narrow-relative+-1": "ter. passada",
+	"field-weekOfMonth-short": "sem. do mês",
 	"dateFormatItem-yyyy": "y G",
 	"field-wed-short-relative+0": "esta qua.",
 	"months-standAlone-wide": [
@@ -212,35 +239,45 @@ define(
 	"field-wed-short-relative+1": "próxima qua.",
 	"field-sun-relative+-1": "domingo passado",
 	"days-standAlone-abbr": [
-		"dom",
-		"seg",
-		"ter",
-		"qua",
-		"qui",
-		"sex",
-		"sáb"
+		"dom.",
+		"seg.",
+		"ter.",
+		"qua.",
+		"qui.",
+		"sex.",
+		"sáb."
 	],
 	"field-weekday": "dia da semana",
+	"field-quarter-narrow-relative+0": "este trimestre",
 	"field-sat-relative+0": "este sábado",
+	"field-quarter-narrow-relative+1": "próximo trimestre",
 	"field-sat-relative+1": "próximo sábado",
+	"field-day-short-relative+2": "depois de amanhã",
+	"field-week-short-relative+0": "esta semana",
+	"field-week-short-relative+1": "próxima semana",
 	"months-standAlone-abbr": [
-		"jan",
-		"fev",
-		"mar",
-		"abr",
-		"mai",
-		"jun",
-		"jul",
-		"ago",
-		"set",
-		"out",
-		"nov",
-		"dez"
+		"jan.",
+		"fev.",
+		"mar.",
+		"abr.",
+		"mai.",
+		"jun.",
+		"jul.",
+		"ago.",
+		"set.",
+		"out.",
+		"nov.",
+		"dez."
 	],
+	"field-dayOfYear-narrow": "dia do ano",
+	"field-month-short-relative+0": "este mês",
+	"field-month-short-relative+1": "próximo mês",
+	"field-weekdayOfMonth-short": "dia da sem. do mês",
 	"dateFormatItem-MEd": "E, dd/MM",
+	"field-zone-narrow": "fuso",
 	"dateFormatItem-y": "y G",
 	"field-thu-narrow-relative+0": "esta qui.",
-	"field-thu-narrow-relative+1": "próx. qui",
+	"field-thu-narrow-relative+1": "próxima qui.",
 	"field-sun-narrow-relative+-1": "dom. passado",
 	"field-mon-short-relative+-1": "seg. passada",
 	"field-thu-relative+0": "esta quinta-feira",
@@ -257,19 +294,25 @@ define(
 	"dateFormatItem-Ed": "E, d",
 	"field-wed-narrow-relative+0": "esta qua.",
 	"field-wed-narrow-relative+1": "próxima qua.",
+	"field-quarter-narrow-relative+-1": "último trimestre",
+	"field-year-short-relative+0": "este ano",
+	"field-dayperiod-short": "AM/PM",
 	"dateFormatItem-yyyyMMM": "MMM 'de' y G",
+	"field-year-short-relative+1": "próximo ano",
 	"field-fri-short-relative+0": "esta sex.",
 	"field-fri-short-relative+1": "próxima sex.",
 	"days-standAlone-short": [
-		"dom",
-		"seg",
-		"ter",
-		"qua",
-		"qui",
-		"sex",
-		"sáb"
+		"dom.",
+		"seg.",
+		"ter.",
+		"qua.",
+		"qui.",
+		"sex.",
+		"sáb."
 	],
+	"field-week-short-relative+-1": "semana passada",
 	"field-hour-short": "h",
+	"field-zone-short": "fuso",
 	"quarters-format-abbr": [
 		"T1",
 		"T2",
@@ -281,9 +324,11 @@ define(
 	"field-fri-narrow-relative+-1": "sex. passada",
 	"field-year-relative+0": "este ano",
 	"field-year-relative+1": "próximo ano",
+	"field-era-narrow": "era",
 	"field-fri-relative+-1": "sexta-feira passada",
+	"eraNarrow": "EB",
 	"field-tue-short-relative+-1": "ter. passada",
-	"field-minute-narrow": "m",
+	"field-minute-narrow": "min.",
 	"days-format-wide": [
 		"domingo",
 		"segunda-feira",
@@ -295,20 +340,24 @@ define(
 	],
 	"field-mon-narrow-relative+0": "esta seg.",
 	"field-mon-narrow-relative+1": "próxima seg.",
+	"field-year-short-relative+-1": "ano passado",
 	"field-zone": "fuso horário",
 	"dateFormatItem-MMMEd": "E, d 'de' MMM",
+	"field-weekOfMonth-narrow": "sem. do mês",
+	"field-weekday-narrow": "dia da sem.",
 	"field-quarter-narrow": "trim.",
 	"field-sun-short-relative+-1": "dom. passado",
 	"field-day-relative+-1": "ontem",
 	"field-day-relative+-2": "anteontem",
+	"field-weekday-short": "dia da sem.",
 	"days-format-abbr": [
-		"dom",
-		"seg",
-		"ter",
-		"qua",
-		"qui",
-		"sex",
-		"sáb"
+		"dom.",
+		"seg.",
+		"ter.",
+		"qua.",
+		"qui.",
+		"sex.",
+		"sáb."
 	],
 	"field-sun-relative+0": "este domingo",
 	"field-sun-relative+1": "próximo domingo",
