@@ -1,186 +1,11 @@
 define(
 //begin v1.x content
 {
-	"field-quarter-short-relative+0": "trim. acesta",
-	"field-quarter-short-relative+1": "trim. viitor",
-	"dayPeriods-standAlone-abbr-noon": "amiază",
-	"field-tue-relative+-1": "marțea trecută",
-	"field-year": "an",
-	"dateFormatItem-yw": "'săptămâna' w 'din' y",
-	"dayPeriods-format-abbr-afternoon1": "după-amiaza",
-	"dateFormatItem-Hm": "HH:mm",
-	"field-wed-relative+0": "miercurea aceasta",
-	"field-wed-relative+1": "miercurea viitoare",
-	"dateFormatItem-ms": "mm:ss",
-	"timeFormat-short": "HH:mm",
-	"field-minute": "minut",
-	"field-tue-narrow-relative+0": "ma. aceasta",
-	"field-tue-narrow-relative+1": "ma. viitoare",
-	"field-thu-short-relative+0": "joi aceasta",
-	"dateTimeFormat-short": "{1}, {0}",
-	"field-thu-short-relative+1": "joia viitoare",
-	"field-day-relative+0": "azi",
-	"field-day-relative+1": "mâine",
-	"field-day-relative+2": "poimâine",
-	"field-wed-narrow-relative+-1": "mi. trecută",
-	"field-year-narrow": "an",
-	"field-tue-relative+0": "marțea aceasta",
-	"field-tue-relative+1": "marțea viitoare",
-	"field-second-short": "sec.",
-	"dayPeriods-format-narrow-am": "a.m.",
-	"dayPeriods-standAlone-abbr-morning1": "dimineața",
-	"dateFormatItem-MMMd": "d MMM",
-	"dayPeriods-format-narrow-morning1": "dimineață",
-	"dayPeriods-format-abbr-am": "a.m.",
-	"field-week-relative+0": "săptămâna aceasta",
-	"field-month-relative+0": "luna aceasta",
-	"field-week-relative+1": "săptămâna viitoare",
-	"field-month-relative+1": "luna viitoare",
+	"dateFormatItem-yMMMM": "MMMM y",
+	"field-thu-narrow-relative+0": "jo. aceasta",
+	"field-thu-narrow-relative+1": "jo. viitoare",
 	"field-sun-narrow-relative+0": "du. aceasta",
-	"timeFormat-medium": "HH:mm:ss",
-	"field-mon-short-relative+0": "lun. aceasta",
 	"field-sun-narrow-relative+1": "du. viitoare",
-	"field-mon-short-relative+1": "lun. viitoare",
-	"field-second-relative+0": "acum",
-	"months-standAlone-narrow": [
-		"I",
-		"F",
-		"M",
-		"A",
-		"M",
-		"I",
-		"I",
-		"A",
-		"S",
-		"O",
-		"N",
-		"D"
-	],
-	"dayPeriods-standAlone-wide-noon": "la amiază",
-	"eraNames": [
-		"înainte de Hristos",
-		"după Hristos"
-	],
-	"dayPeriods-standAlone-abbr-pm": "p.m.",
-	"field-month-short": "lună",
-	"dateFormatItem-GyMMMEd": "E, d MMM y G",
-	"field-day": "zi",
-	"dayPeriods-standAlone-wide-night1": "noaptea",
-	"field-year-relative+-1": "anul trecut",
-	"dayPeriods-format-wide-am": "a.m.",
-	"field-sat-short-relative+-1": "sâm. trecută",
-	"dayPeriods-format-narrow-afternoon1": "după-amiază",
-	"dayPeriods-format-wide-afternoon1": "după-amiaza",
-	"field-hour-relative+0": "ora aceasta",
-	"field-wed-relative+-1": "miercurea trecută",
-	"dateTimeFormat-medium": "{1}, {0}",
-	"field-sat-narrow-relative+-1": "sâ. trecută",
-	"field-second": "secundă",
-	"days-standAlone-narrow": [
-		"D",
-		"L",
-		"M",
-		"M",
-		"J",
-		"V",
-		"S"
-	],
-	"dayPeriods-standAlone-narrow-noon": "amiază",
-	"dayPeriods-standAlone-wide-pm": "p.m.",
-	"dateFormatItem-Ehms": "E h:mm:ss a",
-	"dateFormat-long": "d MMMM y",
-	"dateFormatItem-GyMMMd": "d MMM y G",
-	"dayPeriods-standAlone-abbr-midnight": "miezul nopții",
-	"field-quarter": "trimestru",
-	"field-week-short": "săpt.",
-	"dayPeriods-format-narrow-midnight": "miezul nopții",
-	"dateFormatItem-yMMMEd": "E, d MMM y",
-	"quarters-standAlone-wide": [
-		"trimestrul I",
-		"trimestrul al II-lea",
-		"trimestrul al III-lea",
-		"trimestrul al IV-lea"
-	],
-	"days-format-narrow": [
-		"D",
-		"L",
-		"M",
-		"M",
-		"J",
-		"V",
-		"S"
-	],
-	"dayPeriods-format-wide-evening1": "seara",
-	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
-	"field-tue-short-relative+0": "mar. aceasta",
-	"field-tue-short-relative+1": "mar. viitoare",
-	"field-mon-relative+-1": "lunea trecută",
-	"dateFormatItem-GyMMM": "MMM y G",
-	"field-month": "lună",
-	"field-day-narrow": "zi",
-	"dayPeriods-standAlone-abbr-night1": "noaptea",
-	"dayPeriods-standAlone-narrow-afternoon1": "după-amiaza",
-	"dateFormatItem-MMM": "LLL",
-	"field-minute-short": "min.",
-	"field-dayperiod": "a.m/p.m.",
-	"field-sat-short-relative+0": "sâm. aceasta",
-	"field-sat-short-relative+1": "sâm. viitoare",
-	"dayPeriods-format-narrow-pm": "p.m.",
-	"dateFormat-medium": "d MMM y",
-	"eraAbbr": [
-		"î.Hr.",
-		"d.Hr."
-	],
-	"quarters-standAlone-abbr": [
-		"trim. I",
-		"trim. II",
-		"trim. III",
-		"trim. IV"
-	],
-	"dayPeriods-format-abbr-pm": "p.m.",
-	"field-second-narrow": "s",
-	"field-mon-relative+0": "lunea aceasta",
-	"dayPeriods-standAlone-narrow-night1": "noaptea",
-	"field-mon-relative+1": "lunea viitoare",
-	"field-year-short": "an",
-	"months-format-narrow": [
-		"I",
-		"F",
-		"M",
-		"A",
-		"M",
-		"I",
-		"I",
-		"A",
-		"S",
-		"O",
-		"N",
-		"D"
-	],
-	"dayPeriods-format-wide-morning1": "dimineața",
-	"field-quarter-relative+-1": "trimestrul trecut",
-	"dayPeriods-standAlone-narrow-am": "a.m.",
-	"days-format-short": [
-		"du.",
-		"lu.",
-		"ma.",
-		"mi.",
-		"joi",
-		"vi.",
-		"sâ."
-	],
-	"quarters-format-narrow": [
-		"I",
-		"II",
-		"III",
-		"IV"
-	],
-	"dayPeriods-format-wide-pm": "p.m.",
-	"field-sat-relative+-1": "sâmbăta trecută",
-	"dateTimeFormat-long": "{1}, {0}",
-	"dateFormatItem-Md": "dd.MM",
-	"field-hour": "oră",
-	"dateFormatItem-yQQQQ": "QQQQ y",
 	"months-format-wide": [
 		"ianuarie",
 		"februarie",
@@ -195,47 +20,28 @@ define(
 		"noiembrie",
 		"decembrie"
 	],
-	"dayPeriods-format-wide-night1": "noaptea",
-	"dateFormat-full": "EEEE, d MMMM y",
-	"field-month-relative+-1": "luna trecută",
+	"dayPeriods-standAlone-abbr-pm": "p.m.",
 	"dateFormatItem-Hms": "HH:mm:ss",
-	"field-quarter-short": "trim.",
-	"field-sat-narrow-relative+0": "sâ. aceasta",
-	"dateFormatItem-Hmv": "HH:mm v",
-	"field-fri-relative+0": "vinerea aceasta",
-	"field-sat-narrow-relative+1": "sâ. viitoare",
-	"field-fri-relative+1": "vinerea viitoare",
-	"dayPeriods-format-narrow-noon": "amiază",
-	"field-sun-short-relative+0": "dum. aceasta",
-	"field-sun-short-relative+1": "dum. viitoare",
-	"field-week-relative+-1": "săptămâna trecută",
-	"field-quarter-short-relative+-1": "trim. trecut",
-	"dateFormatItem-Ehm": "E h:mm a",
-	"months-format-abbr": [
-		"ian.",
-		"feb.",
-		"mar.",
-		"apr.",
-		"mai",
-		"iun.",
-		"iul.",
-		"aug.",
-		"sept.",
-		"oct.",
-		"nov.",
-		"dec."
+	"field-fri-narrow-relative+0": "vi. aceasta",
+	"field-fri-narrow-relative+1": "vi. viitoare",
+	"eraNarrow": [
+		"î.Hr.",
+		"d.Hr."
 	],
-	"dayPeriods-format-wide-midnight": "la miezul nopții",
-	"field-quarter-relative+0": "trimestrul acesta",
-	"field-minute-relative+0": "minutul acesta",
-	"timeFormat-long": "HH:mm:ss z",
-	"field-quarter-relative+1": "trimestrul viitor",
-	"field-wed-short-relative+-1": "mie. trecută",
-	"dateFormatItem-yMMM": "MMM y",
-	"dateFormat-short": "dd.MM.y",
-	"field-thu-short-relative+-1": "joi trecută",
+	"dateFormatItem-Hmv": "HH:mm v",
+	"dateFormatItem-hmsv": "h:mm:ss a v",
+	"dateFormatItem-yMMMd": "d MMM y",
 	"dayPeriods-format-abbr-night1": "noaptea",
-	"dateFormatItem-MMMMW": "'săptămâna' W 'din' MMM",
+	"dayPeriods-format-narrow-evening1": "seara",
+	"days-standAlone-narrow": [
+		"D",
+		"L",
+		"M",
+		"M",
+		"J",
+		"V",
+		"S"
+	],
 	"days-standAlone-wide": [
 		"duminică",
 		"luni",
@@ -245,15 +51,70 @@ define(
 		"vineri",
 		"sâmbătă"
 	],
-	"field-mon-narrow-relative+-1": "lu. trecută",
-	"dateFormatItem-MMMMd": "d MMMM",
+	"dayPeriods-format-abbr-afternoon1": "după-amiaza",
+	"dayPeriods-format-wide-evening1": "seara",
+	"dateFormatItem-Ehm": "E h:mm a",
+	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
+	"field-wed-narrow-relative+-1": "mi. trecută",
+	"dayPeriods-standAlone-wide-evening1": "seara",
+	"field-minute-narrow-relative+0": "minutul acesta",
+	"days-format-wide": [
+		"duminică",
+		"luni",
+		"marți",
+		"miercuri",
+		"joi",
+		"vineri",
+		"sâmbătă"
+	],
+	"dateFormatItem-yMM": "MM.y",
+	"field-month-short-relative+0": "luna aceasta",
+	"field-month-short-relative+1": "luna viitoare",
+	"dateFormatItem-Ehms": "E h:mm:ss a",
+	"dayPeriods-standAlone-narrow-evening1": "seara",
+	"dayPeriods-standAlone-abbr-afternoon1": "după-amiaza",
+	"field-thu-relative+0": "joia aceasta",
+	"dayPeriods-standAlone-abbr-night1": "noaptea",
+	"field-thu-relative+1": "joia viitoare",
+	"dayPeriods-format-wide-am": "a.m.",
+	"field-fri-relative+0": "vinerea aceasta",
+	"field-fri-relative+1": "vinerea viitoare",
+	"dateFormatItem-yMd": "dd.MM.y",
 	"field-thu-narrow-relative+-1": "jo. trecută",
-	"dateFormatItem-E": "ccc",
-	"dateFormatItem-H": "HH",
-	"field-tue-narrow-relative+-1": "ma. trecută",
-	"dayPeriods-format-abbr-evening1": "seara",
-	"dayPeriods-standAlone-narrow-pm": "p.m.",
-	"dateFormatItem-M": "L",
+	"field-quarter-relative+0": "trimestrul acesta",
+	"field-quarter-relative+1": "trimestrul viitor",
+	"field-sun-short-relative+0": "dum. aceasta",
+	"timeFormat-short": "HH:mm",
+	"field-sun-short-relative+1": "dum. viitoare",
+	"dateFormatItem-hms": "h:mm:ss a",
+	"dayPeriods-format-narrow-afternoon1": "după-amiaza",
+	"dateFormatItem-Md": "dd.MM",
+	"dateFormatItem-Hmsv": "HH:mm:ss v",
+	"dateFormatItem-hmv": "h:mm a v",
+	"field-week-narrow": "săpt.",
+	"field-hour-relative+0": "ora aceasta",
+	"field-day-relative+-1": "ieri",
+	"field-day-relative+-2": "alaltăieri",
+	"field-mon-narrow-relative+-1": "lu. trecută",
+	"field-minute-narrow": "m",
+	"dateFormatItem-MMMMEd": "E, d MMMM",
+	"field-thu-short-relative+0": "joia aceasta",
+	"field-mon-relative+0": "lunea aceasta",
+	"field-thu-short-relative+1": "joia viitoare",
+	"field-mon-relative+1": "lunea viitoare",
+	"field-day-narrow-relative+0": "azi",
+	"field-era-short": "eră",
+	"field-day-narrow-relative+1": "mâine",
+	"field-sat-narrow-relative+0": "sâ. aceasta",
+	"field-day-narrow-relative+2": "poimâine",
+	"timeFormat-long": "HH:mm:ss z",
+	"field-sat-narrow-relative+1": "sâ. viitoare",
+	"field-week-narrow-relative+0": "săpt. aceasta",
+	"field-week-narrow-relative+1": "săpt. viitoare",
+	"field-hour-short-relative+0": "ora aceasta",
+	"field-wed-narrow-relative+0": "mi. aceasta",
+	"field-wed-narrow-relative+1": "mi. viitoare",
+	"field-month": "lună",
 	"months-standAlone-wide": [
 		"ianuarie",
 		"februarie",
@@ -268,11 +129,200 @@ define(
 		"noiembrie",
 		"decembrie"
 	],
+	"field-weekday-narrow": "ziua din săpt.",
+	"dayPeriods-standAlone-narrow-afternoon1": "după-amiaza",
+	"field-year-relative+0": "anul acesta",
+	"field-year-relative+1": "anul viitor",
+	"dayPeriods-format-abbr-evening1": "seara",
+	"dayPeriods-format-abbr-noon": "amiază",
+	"dayPeriods-format-narrow-midnight": "miezul nopții",
+	"dayPeriods-format-wide-midnight": "la miezul nopții",
+	"field-tue-relative+0": "marțea aceasta",
+	"field-tue-relative+1": "marțea viitoare",
+	"dayPeriods-standAlone-abbr-evening1": "seara",
+	"field-minute-short-relative+0": "minutul acesta",
+	"dateFormatItem-hm": "h:mm a",
+	"dayPeriods-standAlone-wide-midnight": "la miezul nopții",
+	"field-year-narrow": "an",
+	"dayPeriods-standAlone-abbr-noon": "amiază",
+	"field-tue-short-relative+0": "mar. aceasta",
+	"dayPeriods-standAlone-narrow-midnight": "miezul nopții",
+	"field-tue-short-relative+1": "mar. viitoare",
+	"field-tue-narrow-relative+0": "ma. aceasta",
+	"field-tue-narrow-relative+1": "ma. viitoare",
+	"dateTimeFormat-full": "{1}, {0}",
+	"dateFormatItem-E": "ccc",
+	"dateFormatItem-EBhm": "E h:mm B",
+	"dateFormatItem-H": "HH",
+	"field-wed-relative+0": "miercurea aceasta",
+	"field-wed-relative+1": "miercurea viitoare",
+	"dateFormatItem-M": "L",
 	"field-wed-short-relative+0": "mie. aceasta",
+	"field-fri-short-relative+0": "vin. aceasta",
 	"field-wed-short-relative+1": "mie. viitoare",
-	"dateFormatItem-Hmsv": "HH:mm:ss v",
-	"field-sun-relative+-1": "duminica trecută",
-	"dateFormatItem-MMMMEd": "E, d MMMM",
+	"field-fri-short-relative+1": "vin. viitoare",
+	"field-weekOfMonth-short": "săpt. din lună",
+	"field-quarter-short-relative+-1": "trim. trecut",
+	"field-year-short-relative+-1": "anul trecut",
+	"dateFormatItem-Bhm": "h:mm B",
+	"dayPeriods-format-wide-night1": "noaptea",
+	"dateTimeFormat-medium": "{1}, {0}",
+	"field-quarter-narrow-relative+-1": "trim. trecut",
+	"dateFormatItem-d": "d",
+	"dayPeriods-format-abbr-pm": "p.m.",
+	"dateFormatItem-h": "h a",
+	"quarters-standAlone-wide": [
+		"trimestrul I",
+		"trimestrul al II-lea",
+		"trimestrul al III-lea",
+		"trimestrul al IV-lea"
+	],
+	"field-weekOfMonth-narrow": "săpt. din lună",
+	"dateFormatItem-y": "y",
+	"field-minute-relative+0": "minutul acesta",
+	"field-year-short-relative+0": "anul acesta",
+	"dateFormatItem-EBhms": "E h:mm:ss B",
+	"field-year-short-relative+1": "anul viitor",
+	"field-weekday": "ziua din săptămână",
+	"dayPeriods-format-narrow-pm": "p.m.",
+	"field-tue-narrow-relative+-1": "ma. trecută",
+	"dateFormatItem-yMEd": "E, dd.MM.y",
+	"dayPeriods-standAlone-wide-night1": "noaptea",
+	"field-year-narrow-relative+-1": "anul trecut",
+	"field-sat-relative+-1": "sâmbăta trecută",
+	"dayPeriods-format-abbr-midnight": "miezul nopții",
+	"dayPeriods-format-narrow-morning1": "dimineața",
+	"dayPeriods-format-wide-morning1": "dimineața",
+	"dayPeriods-standAlone-abbr-midnight": "miezul nopții",
+	"dayPeriods-standAlone-narrow-pm": "p.m.",
+	"dayPeriods-standAlone-wide-morning1": "dimineața",
+	"field-mon-narrow-relative+0": "lu. aceasta",
+	"field-mon-narrow-relative+1": "lu. viitoare",
+	"field-second": "secundă",
+	"dateFormatItem-yMMMEd": "E, d MMM y",
+	"field-year-relative+-1": "anul trecut",
+	"field-weekdayOfMonth-short": "ziua săpt. din lună",
+	"dateFormat-short": "dd.MM.y",
+	"eraNames": [
+		"înainte de Hristos",
+		"după Hristos"
+	],
+	"field-second-short": "sec.",
+	"field-thu-short-relative+-1": "joia trecută",
+	"field-zone": "fus orar",
+	"field-dayperiod-narrow": "a.m/p.m.",
+	"field-sun-short-relative+-1": "dum. trecută",
+	"dayPeriods-standAlone-narrow-morning1": "dimineața",
+	"eraAbbr": [
+		"î.Hr.",
+		"d.Hr."
+	],
+	"field-week-short": "săpt.",
+	"dayPeriods-standAlone-abbr-am": "a.m.",
+	"dayPeriods-standAlone-wide-pm": "p.m.",
+	"dateFormatItem-ms": "mm:ss",
+	"field-day-relative+0": "azi",
+	"field-day-relative+1": "mâine",
+	"field-day-relative+2": "poimâine",
+	"field-day-short-relative+0": "azi",
+	"field-dayOfYear-short": "ziua din an",
+	"field-day-short-relative+1": "mâine",
+	"dateFormat-long": "d MMMM y",
+	"field-day-short-relative+2": "poimâine",
+	"field-sun-narrow-relative+-1": "du. trecută",
+	"dayPeriods-format-wide-noon": "la amiază",
+	"field-second-relative+0": "acum",
+	"field-quarter-relative+-1": "trimestrul trecut",
+	"dayPeriods-format-narrow-night1": "noaptea",
+	"quarters-format-abbr": [
+		"trim. I",
+		"trim. II",
+		"trim. III",
+		"trim. IV"
+	],
+	"dayPeriods-standAlone-wide-noon": "la amiază",
+	"dayPeriods-standAlone-narrow-night1": "noaptea",
+	"field-week-relative+-1": "săptămâna trecută",
+	"dayPeriods-format-abbr-morning1": "dimineața",
+	"field-month-relative+-1": "luna trecută",
+	"months-format-narrow": [
+		"I",
+		"F",
+		"M",
+		"A",
+		"M",
+		"I",
+		"I",
+		"A",
+		"S",
+		"O",
+		"N",
+		"D"
+	],
+	"field-year": "an",
+	"field-era": "eră",
+	"dayPeriods-standAlone-abbr-morning1": "dimineața",
+	"days-standAlone-short": [
+		"du.",
+		"lu.",
+		"ma.",
+		"mi.",
+		"joi",
+		"vi.",
+		"sâ."
+	],
+	"quarters-format-narrow": [
+		"I",
+		"II",
+		"III",
+		"IV"
+	],
+	"dateFormatItem-yQQQQ": "QQQQ y",
+	"field-day-short-relative+-1": "ieri",
+	"field-day-short-relative+-2": "alaltăieri",
+	"dateFormatItem-GyMMM": "MMM y G",
+	"timeFormat-full": "HH:mm:ss zzzz",
+	"dateFormatItem-Bhms": "h:mm:ss B",
+	"field-hour": "oră",
+	"field-dayOfYear-narrow": "ziua din an",
+	"field-second-narrow-relative+0": "acum",
+	"field-quarter": "trimestru",
+	"field-month-narrow-relative+0": "luna aceasta",
+	"field-month-narrow-relative+1": "luna viitoare",
+	"dateFormatItem-MMdd": "dd.MM",
+	"field-day": "zi",
+	"field-mon-relative+-1": "lunea trecută",
+	"field-dayOfYear": "ziua din an",
+	"dateFormat-medium": "d MMM y",
+	"dateTimeFormat-short": "{1}, {0}",
+	"dateFormatItem-yMMM": "MMM y",
+	"dateFormatItem-GyMMMd": "d MMM y G",
+	"dateFormatItem-MEd": "E, dd.MM",
+	"field-tue-short-relative+-1": "mar. trecută",
+	"field-year-short": "an",
+	"field-month-short": "lună",
+	"dateFormatItem-MMMEd": "E, d MMM",
+	"dayPeriods-format-wide-afternoon1": "după-amiaza",
+	"dateFormatItem-MMMd": "d MMM",
+	"dateFormatItem-Bh": "h B",
+	"months-format-abbr": [
+		"ian.",
+		"feb.",
+		"mar.",
+		"apr.",
+		"mai",
+		"iun.",
+		"iul.",
+		"aug.",
+		"sept.",
+		"oct.",
+		"nov.",
+		"dec."
+	],
+	"dayPeriods-format-abbr-am": "a.m.",
+	"field-sat-relative+0": "sâmbăta aceasta",
+	"field-sat-relative+1": "sâmbăta viitoare",
+	"dayPeriods-format-wide-pm": "p.m.",
 	"days-standAlone-abbr": [
 		"dum.",
 		"lun.",
@@ -282,16 +332,96 @@ define(
 		"vin.",
 		"sâm."
 	],
-	"dateTimeFormat-full": "{1}, {0}",
-	"dateFormatItem-hm": "h:mm a",
-	"dateFormatItem-d": "d",
-	"field-weekday": "Zi a săptămânii",
-	"dayPeriods-standAlone-wide-evening1": "seara",
-	"field-quarter-narrow-relative+0": "trim. acesta",
-	"field-sat-relative+0": "sâmbăta aceasta",
-	"dateFormatItem-h": "h a",
-	"field-quarter-narrow-relative+1": "trim. viitor",
-	"field-sat-relative+1": "sâmbăta viitoare",
+	"field-zone-short": "fus",
+	"field-week-short-relative+0": "săpt. aceasta",
+	"field-week-short-relative+1": "săpt. viitoare",
+	"dayPeriods-standAlone-wide-afternoon1": "după-amiaza",
+	"field-fri-short-relative+-1": "vin. trecută",
+	"field-month-narrow": "lună",
+	"dayPeriods-format-narrow-am": "a.m.",
+	"field-month-narrow-relative+-1": "luna trecută",
+	"days-format-abbr": [
+		"dum.",
+		"lun.",
+		"mar.",
+		"mie.",
+		"joi",
+		"vin.",
+		"sâm."
+	],
+	"field-weekday-short": "ziua din săpt.",
+	"field-day-narrow-relative+-1": "ieri",
+	"field-day-narrow-relative+-2": "alaltăieri",
+	"field-quarter-short": "trim.",
+	"days-format-short": [
+		"du.",
+		"lu.",
+		"ma.",
+		"mi.",
+		"joi",
+		"vi.",
+		"sâ."
+	],
+	"months-standAlone-narrow": [
+		"I",
+		"F",
+		"M",
+		"A",
+		"M",
+		"I",
+		"I",
+		"A",
+		"S",
+		"O",
+		"N",
+		"D"
+	],
+	"days-format-narrow": [
+		"D",
+		"L",
+		"M",
+		"M",
+		"J",
+		"V",
+		"S"
+	],
+	"dateFormatItem-EHm": "E HH:mm",
+	"field-quarter-narrow": "trim.",
+	"field-mon-short-relative+0": "lun. aceasta",
+	"field-mon-short-relative+1": "lun. viitoare",
+	"field-dayperiod-short": "a.m/p.m.",
+	"dayPeriods-standAlone-narrow-am": "a.m.",
+	"field-week-narrow-relative+-1": "săpt. trecută",
+	"field-thu-relative+-1": "joia trecută",
+	"field-fri-narrow-relative+-1": "vi. trecută",
+	"field-mon-short-relative+-1": "lun. trecută",
+	"timeFormat-medium": "HH:mm:ss",
+	"field-quarter-short-relative+0": "trim. acesta",
+	"field-quarter-short-relative+1": "trim. viitor",
+	"dateFormatItem-Ed": "E d",
+	"field-wed-relative+-1": "miercurea trecută",
+	"field-weekOfMonth": "săptămâna din lună",
+	"field-weekdayOfMonth-narrow": "ziua săpt. din lună",
+	"dayPeriods-standAlone-wide-am": "a.m.",
+	"dateFormatItem-yQQQ": "QQQ y",
+	"field-fri-relative+-1": "vinerea trecută",
+	"field-minute": "minut",
+	"quarters-standAlone-narrow": [
+		"I",
+		"II",
+		"III",
+		"IV"
+	],
+	"field-second-short-relative+0": "acum",
+	"quarters-format-wide": [
+		"trimestrul I",
+		"trimestrul al II-lea",
+		"trimestrul al III-lea",
+		"trimestrul al IV-lea"
+	],
+	"field-day-short": "zi",
+	"field-dayperiod": "a.m/p.m.",
+	"field-hour-short": "h",
 	"months-standAlone-abbr": [
 		"ian.",
 		"feb.",
@@ -306,127 +436,53 @@ define(
 		"nov.",
 		"dec."
 	],
-	"dateFormatItem-hmsv": "h:mm:ss a v",
-	"dayPeriods-format-abbr-morning1": "dimineața",
-	"dayPeriods-standAlone-narrow-evening1": "seara",
-	"dateFormatItem-yMM": "MM.y",
-	"timeFormat-full": "HH:mm:ss zzzz",
-	"dateFormatItem-MEd": "E, dd.MM",
-	"dateFormatItem-y": "y",
-	"field-thu-narrow-relative+0": "jo. aceasta",
-	"field-sun-narrow-relative+-1": "du. trecută",
-	"field-mon-short-relative+-1": "lun. trecută",
-	"field-thu-narrow-relative+1": "jo. viitoare",
-	"field-thu-relative+0": "joia aceasta",
-	"dayPeriods-standAlone-abbr-afternoon1": "după-amiaza",
-	"field-thu-relative+1": "joia viitoare",
-	"dateFormatItem-hms": "h:mm:ss a",
-	"field-fri-short-relative+-1": "vin. trecută",
-	"dateFormatItem-hmv": "h:mm a v",
-	"dayPeriods-format-abbr-noon": "amiază",
-	"field-thu-relative+-1": "joia trecută",
-	"dateFormatItem-yMd": "dd.MM.y",
-	"quarters-standAlone-narrow": [
-		"I",
-		"II",
-		"III",
-		"IV"
-	],
-	"field-week": "săptămână",
-	"quarters-format-wide": [
-		"trimestrul I",
-		"trimestrul al II-lea",
-		"trimestrul al III-lea",
-		"trimestrul al IV-lea"
-	],
-	"dateFormatItem-Ed": "E d",
-	"field-wed-narrow-relative+0": "mi. aceasta",
-	"field-wed-narrow-relative+1": "mi. viitoare",
-	"dayPeriods-standAlone-wide-morning1": "dimineața",
-	"field-quarter-narrow-relative+-1": "trim. trecut",
-	"field-fri-short-relative+0": "vin. aceasta",
-	"field-fri-short-relative+1": "vin. viitoare",
-	"days-standAlone-short": [
-		"du.",
-		"lu.",
-		"ma.",
-		"mi.",
-		"joi",
-		"vi.",
-		"sâ."
-	],
-	"dayPeriods-standAlone-narrow-morning1": "dimineața",
-	"dayPeriods-format-abbr-midnight": "miezul nopții",
-	"field-hour-short": "h",
-	"quarters-format-abbr": [
+	"field-month-relative+0": "luna aceasta",
+	"field-second-narrow": "s",
+	"field-month-relative+1": "luna viitoare",
+	"dateFormat-full": "EEEE, d MMMM y",
+	"field-era-narrow": "eră",
+	"field-sat-short-relative+-1": "sâm. trecută",
+	"dayPeriods-format-narrow-noon": "la amiază",
+	"field-week-short-relative+-1": "săpt. trecută",
+	"dateTimeFormat-long": "{1}, {0}",
+	"dateFormatItem-yM": "MM.y",
+	"field-sun-relative+-1": "duminica trecută",
+	"field-wed-short-relative+-1": "mie. trecută",
+	"field-weekdayOfMonth": "ziua săptămânii din lună",
+	"field-quarter-narrow-relative+0": "trim. acesta",
+	"dateFormatItem-GyMMMEd": "E, d MMM y G",
+	"field-quarter-narrow-relative+1": "trim. viitor",
+	"field-sat-short-relative+0": "sâm. aceasta",
+	"field-hour-narrow": "h",
+	"field-sat-short-relative+1": "sâm. viitoare",
+	"field-year-narrow-relative+0": "anul acesta",
+	"field-year-narrow-relative+1": "anul viitor",
+	"dateFormatItem-Gy": "y G",
+	"field-zone-narrow": "fus",
+	"dayPeriods-standAlone-narrow-noon": "amiază",
+	"field-tue-relative+-1": "marțea trecută",
+	"field-minute-short": "min.",
+	"dateFormatItem-yw": "'săptămâna' w 'din' Y",
+	"dateFormatItem-Hm": "HH:mm",
+	"field-week-relative+0": "săptămâna aceasta",
+	"field-week-relative+1": "săptămâna viitoare",
+	"dateFormatItem-MMM": "LLL",
+	"field-sun-relative+0": "duminica aceasta",
+	"field-sun-relative+1": "duminica viitoare",
+	"field-sat-narrow-relative+-1": "sâ. trecută",
+	"quarters-standAlone-abbr": [
 		"trim. I",
 		"trim. II",
 		"trim. III",
 		"trim. IV"
 	],
-	"field-month-narrow": "lună",
-	"field-hour-narrow": "h",
-	"field-fri-narrow-relative+-1": "vi. trecută",
-	"field-year-relative+0": "anul acesta",
-	"field-year-relative+1": "anul viitor",
-	"field-fri-relative+-1": "vinerea trecută",
-	"eraNarrow": [
-		"î.Hr.",
-		"d.Hr."
-	],
-	"dayPeriods-format-wide-noon": "la amiază",
-	"field-tue-short-relative+-1": "mar. trecută",
-	"field-minute-narrow": "m",
-	"dayPeriods-standAlone-wide-afternoon1": "după-amiaza",
-	"dateFormatItem-yQQQ": "QQQ y",
-	"days-format-wide": [
-		"duminică",
-		"luni",
-		"marți",
-		"miercuri",
-		"joi",
-		"vineri",
-		"sâmbătă"
-	],
-	"field-mon-narrow-relative+0": "lu. aceasta",
-	"dateFormatItem-EHm": "E HH:mm",
-	"field-mon-narrow-relative+1": "lu. viitoare",
-	"dayPeriods-standAlone-wide-midnight": "la miezul nopții",
-	"dateFormatItem-yM": "MM.y",
-	"field-zone": "fus orar",
-	"dateFormatItem-yMMMM": "MMMM y",
-	"dateFormatItem-MMMEd": "E, d MMM",
+	"dateFormatItem-MMMMW": "'săptămâna' W 'din' MMMM",
+	"field-month-short-relative+-1": "luna trecută",
 	"dateFormatItem-EHms": "E HH:mm:ss",
-	"dateFormatItem-yMEd": "E, dd.MM.y",
-	"dayPeriods-standAlone-narrow-midnight": "miezul nopții",
-	"field-quarter-narrow": "trim.",
-	"dayPeriods-standAlone-abbr-am": "a.m.",
-	"field-day-relative+-1": "ieri",
-	"field-sun-short-relative+-1": "dum. trecută",
-	"field-day-relative+-2": "alaltăieri",
-	"dayPeriods-format-narrow-night1": "noaptea",
-	"days-format-abbr": [
-		"dum.",
-		"lun.",
-		"mar.",
-		"mie.",
-		"joi",
-		"vin.",
-		"sâm."
-	],
-	"dateFormatItem-MMdd": "dd.MM",
-	"field-sun-relative+0": "duminica aceasta",
-	"field-sun-relative+1": "duminica viitoare",
-	"dateFormatItem-yMMMd": "d MMM y",
-	"dateFormatItem-Gy": "y G",
-	"field-era": "eră",
-	"field-week-narrow": "săpt.",
-	"field-day-short": "zi",
-	"dayPeriods-standAlone-abbr-evening1": "seara",
-	"field-fri-narrow-relative+0": "vi. aceasta",
-	"dayPeriods-format-narrow-evening1": "seara",
-	"field-fri-narrow-relative+1": "vi. viitoare",
-	"dayPeriods-standAlone-wide-am": "a.m."
+	"dateFormatItem-MMMMd": "d MMMM",
+	"field-hour-narrow-relative+0": "ora aceasta",
+	"field-week": "săptămână",
+	"field-day-narrow": "zi"
 }
 //end v1.x content
 );
\ No newline at end of file
