@@ -5,47 +5,71 @@ define(
 	"field-quarter-short-relative+1": "следующий кв.",
 	"field-tue-relative+-1": "в прошлый вторник",
 	"field-year": "год",
-	"dateFormatItem-Hm": "H:mm",
 	"field-wed-relative+0": "в эту среду",
 	"field-wed-relative+1": "в следующую среду",
-	"timeFormat-short": "H:mm",
 	"field-minute": "минута",
+	"field-month-narrow-relative+-1": "в пр. мес.",
 	"field-tue-narrow-relative+0": "в этот вт.",
 	"field-tue-narrow-relative+1": "в след. вт.",
 	"field-thu-short-relative+0": "в этот чт.",
+	"field-day-short-relative+-1": "вчера",
 	"dateTimeFormat-short": "{1}, {0}",
 	"field-thu-short-relative+1": "в след. чт.",
 	"field-day-relative+0": "сегодня",
+	"field-day-short-relative+-2": "позавчера",
 	"field-day-relative+1": "завтра",
+	"field-week-narrow-relative+0": "на эт. нед.",
 	"field-day-relative+2": "послезавтра",
+	"field-week-narrow-relative+1": "на след. нед.",
 	"field-wed-narrow-relative+-1": "в прош. ср.",
+	"dateFormatItem-EBhms": "ccc, h:mm:ss B",
 	"field-year-narrow": "г.",
+	"field-era-short": "эра",
+	"field-year-narrow-relative+0": "в эт. г.",
 	"field-tue-relative+0": "в этот вторник",
+	"field-year-narrow-relative+1": "в сл. г.",
 	"field-tue-relative+1": "в следующий вторник",
+	"field-weekdayOfMonth": "день недели в месяце",
 	"field-second-short": "сек.",
-	"dayPeriods-format-narrow-am": "ДП",
 	"dateFormatItem-MMMd": "d MMM",
-	"dayPeriods-format-abbr-am": "ДП",
+	"field-weekdayOfMonth-narrow": "дн. нед. в мес.",
 	"field-week-relative+0": "на этой неделе",
 	"field-month-relative+0": "в этом месяце",
 	"field-week-relative+1": "на следующей неделе",
 	"field-month-relative+1": "в следующем месяце",
 	"field-sun-narrow-relative+0": "в это вс.",
-	"timeFormat-medium": "H:mm:ss",
 	"field-mon-short-relative+0": "в этот пн.",
 	"field-sun-narrow-relative+1": "в след. вс.",
 	"field-mon-short-relative+1": "в след. пн.",
 	"field-second-relative+0": "сейчас",
-	"dateFormatItem-yyyyQQQ": "QQQ y G",
-	"dayPeriods-standAlone-abbr-pm": "ПП",
+	"dateFormatItem-yyyyQQQ": "QQQ y 'г'. G",
+	"months-standAlone-narrow": [
+		"1",
+		"2",
+		"3",
+		"4",
+		"5",
+		"6",
+		"7",
+		"8",
+		"9",
+		"10",
+		"11",
+		"12",
+		"13"
+	],
+	"eraNames": [
+		"от сотворения мира"
+	],
+	"field-weekOfMonth": "неделя месяца",
 	"field-month-short": "мес.",
 	"dateFormatItem-GyMMMEd": "E, d MMM y 'г'. G",
 	"dateFormatItem-yyyyMd": "dd.MM.y G",
 	"field-day": "день",
+	"field-dayOfYear-short": "дн. года",
 	"field-year-relative+-1": "в прошлом году",
-	"dayPeriods-format-wide-am": "ДП",
 	"field-sat-short-relative+-1": "в прош. сб.",
-	"field-hour-relative+0": "в этом часе",
+	"field-hour-relative+0": "в этот час",
 	"dateFormatItem-yyyyMEd": "E, dd.MM.y G",
 	"field-wed-relative+-1": "в прошлую среду",
 	"dateTimeFormat-medium": "{1}, {0}",
@@ -60,11 +84,15 @@ define(
 		"П",
 		"С"
 	],
-	"dayPeriods-standAlone-wide-pm": "ПП",
+	"dateFormatItem-Ehms": "ccc, h:mm:ss a",
 	"dateFormat-long": "d MMMM y 'г'. G",
 	"dateFormatItem-GyMMMd": "d MMM y 'г'. G",
+	"field-hour-short-relative+0": "в этот час",
 	"field-quarter": "квартал",
 	"field-week-short": "нед.",
+	"field-day-narrow-relative+0": "сегодня",
+	"field-day-narrow-relative+1": "завтра",
+	"field-day-narrow-relative+2": "послезавтра",
 	"quarters-standAlone-wide": [
 		"1-й квартал",
 		"2-й квартал",
@@ -82,32 +110,52 @@ define(
 	],
 	"field-tue-short-relative+0": "в этот вт.",
 	"field-tue-short-relative+1": "в след. вт.",
+	"field-month-short-relative+-1": "в прошлом мес.",
 	"field-mon-relative+-1": "в прошлый понедельник",
-	"dateFormatItem-GyMMM": "LLL y G",
+	"dateFormatItem-GyMMM": "LLL y 'г'. G",
 	"field-month": "месяц",
 	"field-day-narrow": "дн.",
 	"field-minute-short": "мин.",
-	"field-dayperiod": "ДП/ПП",
+	"field-dayperiod": "AM/PM",
 	"field-sat-short-relative+0": "в эту сб.",
 	"field-sat-short-relative+1": "в след. сб.",
-	"dayPeriods-format-narrow-pm": "ПП",
 	"dateFormat-medium": "d MMM y 'г'. G",
-	"dateFormatItem-yyyyMMMM": "LLLL y G",
+	"dateFormatItem-yyyyMMMM": "LLLL y 'г'. G",
+	"eraAbbr": [
+		"AM"
+	],
 	"quarters-standAlone-abbr": [
 		"1-й кв.",
 		"2-й кв.",
 		"3-й кв.",
 		"4-й кв."
 	],
-	"dayPeriods-format-abbr-pm": "ПП",
 	"dateFormatItem-yyyyM": "MM.y G",
 	"field-second-narrow": "с",
 	"field-mon-relative+0": "в этот понедельник",
 	"field-mon-relative+1": "в следующий понедельник",
+	"field-day-narrow-relative+-1": "вчера",
 	"field-year-short": "г.",
+	"field-day-narrow-relative+-2": "позавчера",
+	"months-format-narrow": [
+		"1",
+		"2",
+		"3",
+		"4",
+		"5",
+		"6",
+		"7",
+		"8",
+		"9",
+		"10",
+		"11",
+		"12",
+		"13"
+	],
 	"field-quarter-relative+-1": "в прошлом квартале",
 	"dateFormatItem-yyyyMMMd": "d MMM y 'г'. G",
-	"dayPeriods-standAlone-narrow-am": "ДП",
+	"field-dayperiod-narrow": "AM/PM",
+	"field-week-narrow-relative+-1": "на пр. нед.",
 	"days-format-short": [
 		"вс",
 		"пн",
@@ -117,60 +165,63 @@ define(
 		"пт",
 		"сб"
 	],
-	"dayPeriods-format-wide-pm": "ПП",
+	"field-dayOfYear": "день года",
 	"field-sat-relative+-1": "в прошлую субботу",
 	"dateTimeFormat-long": "{1}, {0}",
 	"dateFormatItem-Md": "dd.MM",
 	"field-hour": "час",
 	"months-format-wide": [
-		"Тишрей",
-		"Хешван",
-		"Кислев",
-		"Тевет",
-		"Шеват",
-		"Адар I",
-		"Адар",
-		"Нисан",
-		"Ияр",
-		"Сиван",
-		"Таммуз",
-		"Ав",
-		"Элул"
+		"тишрей",
+		"хешван",
+		"кислев",
+		"тевет",
+		"шеват",
+		"адар I",
+		"адар",
+		"нисан",
+		"ияр",
+		"сиван",
+		"таммуз",
+		"ав",
+		"элул"
 	],
 	"dateFormat-full": "EEEE, d MMMM y 'г'. G",
 	"field-month-relative+-1": "в прошлом месяце",
-	"dateFormatItem-Hms": "H:mm:ss",
 	"field-quarter-short": "кв.",
 	"field-sat-narrow-relative+0": "в эту сб.",
 	"field-fri-relative+0": "в эту пятницу",
 	"field-sat-narrow-relative+1": "в след. сб.",
 	"field-fri-relative+1": "в следующую пятницу",
+	"dateFormatItem-EBhm": "ccc, h:mm B",
+	"field-month-narrow-relative+0": "в эт. мес.",
+	"field-month-narrow-relative+1": "в след. мес.",
 	"field-sun-short-relative+0": "в это вс.",
 	"field-sun-short-relative+1": "в след. вс.",
 	"field-week-relative+-1": "на прошлой неделе",
 	"field-quarter-short-relative+-1": "последний кв.",
+	"dateFormatItem-Ehm": "ccc, h:mm a",
 	"months-format-abbr": [
-		"Тишрей",
-		"Хешван",
-		"Кислев",
-		"Тевет",
-		"Шеват",
-		"Адар I",
-		"Адар",
-		"Нисан",
-		"Ияр",
-		"Сиван",
-		"Таммуз",
-		"Ав",
-		"Элул"
+		"тишрей",
+		"хешван",
+		"кислев",
+		"тевет",
+		"шеват",
+		"адар I",
+		"адар",
+		"нисан",
+		"ияр",
+		"сиван",
+		"таммуз",
+		"ав",
+		"элул"
 	],
 	"field-quarter-relative+0": "в текущем квартале",
 	"field-minute-relative+0": "в эту минуту",
-	"timeFormat-long": "H:mm:ss z",
 	"field-quarter-relative+1": "в следующем квартале",
 	"field-wed-short-relative+-1": "в прош. ср.",
 	"dateFormat-short": "dd.MM.y G",
 	"field-thu-short-relative+-1": "в прош. чт.",
+	"field-year-narrow-relative+-1": "в пр. г.",
 	"days-standAlone-wide": [
 		"воскресенье",
 		"понедельник",
@@ -185,24 +236,23 @@ define(
 	"dateFormatItem-MMMMd": "d MMMM",
 	"field-thu-narrow-relative+-1": "в прош. чт.",
 	"field-tue-narrow-relative+-1": "в прош. вт.",
-	"dateFormatItem-H": "H",
-	"dateFormatItem-yyyy": "y G",
-	"dayPeriods-standAlone-narrow-pm": "ПП",
+	"field-weekOfMonth-short": "нед. месяца",
+	"dateFormatItem-yyyy": "y 'г'. G",
 	"field-wed-short-relative+0": "в эту ср.",
 	"months-standAlone-wide": [
-		"Тишрей",
-		"Хешван",
-		"Кислев",
-		"Тевет",
-		"Шеват",
-		"Адар I",
-		"Адар",
-		"Нисан",
-		"Ияр",
-		"Сиван",
-		"Таммуз",
-		"Ав",
-		"Элул"
+		"тишрей",
+		"хешван",
+		"кислев",
+		"тевет",
+		"шеват",
+		"адар I",
+		"адар",
+		"нисан",
+		"ияр",
+		"сиван",
+		"таммуз",
+		"ав",
+		"элул"
 	],
 	"field-wed-short-relative+1": "в след. ср.",
 	"field-sun-relative+-1": "в прошлое воскресенье",
@@ -216,31 +266,42 @@ define(
 		"сб"
 	],
 	"dateTimeFormat-full": "{1}, {0}",
-	"months-format-abbr-leap": "Адар II",
+	"months-format-abbr-leap": "адар II",
 	"field-weekday": "день недели",
+	"months-standAlone-narrow-leap": "7",
+	"field-day-short-relative+0": "сегодня",
 	"field-quarter-narrow-relative+0": "тек. кв.",
+	"field-day-short-relative+1": "завтра",
 	"field-sat-relative+0": "в эту субботу",
 	"field-quarter-narrow-relative+1": "след. кв.",
+	"field-day-short-relative+2": "послезавтра",
 	"field-sat-relative+1": "в следующую субботу",
+	"field-week-short-relative+0": "на этой нед.",
+	"field-week-short-relative+1": "на следующей нед.",
 	"months-standAlone-abbr": [
-		"Тишрей",
-		"Хешван",
-		"Кислев",
-		"Тевет",
-		"Шеват",
-		"Адар I",
-		"Адар",
-		"Нисан",
-		"Ияр",
-		"Сиван",
-		"Таммуз",
-		"Ав",
-		"Элул"
+		"тишрей",
+		"хешван",
+		"кислев",
+		"тевет",
+		"шеват",
+		"адар I",
+		"адар",
+		"нисан",
+		"ияр",
+		"сиван",
+		"таммуз",
+		"ав",
+		"элул"
 	],
-	"months-format-wide-leap": "Адар II",
-	"timeFormat-full": "H:mm:ss zzzz",
+	"months-format-wide-leap": "адар II",
+	"months-format-narrow-leap": "7",
+	"field-dayOfYear-narrow": "дн. года",
+	"field-month-short-relative+0": "в этом мес.",
+	"field-month-short-relative+1": "в следующем мес.",
+	"field-weekdayOfMonth-short": "дн. нед. в месяце",
 	"dateFormatItem-MEd": "E, dd.MM",
-	"dateFormatItem-y": "y G",
+	"field-zone-narrow": "час. пояс",
+	"dateFormatItem-y": "y 'г'. G",
 	"field-thu-narrow-relative+0": "в этот чт.",
 	"field-thu-narrow-relative+1": "в след. чт.",
 	"field-sun-narrow-relative+-1": "в прош. вс.",
@@ -260,7 +321,10 @@ define(
 	"field-wed-narrow-relative+0": "в эту ср.",
 	"field-wed-narrow-relative+1": "в след. ср.",
 	"field-quarter-narrow-relative+-1": "посл. кв.",
-	"dateFormatItem-yyyyMMM": "LLL y G",
+	"field-year-short-relative+0": "в этом г.",
+	"field-dayperiod-short": "AM/PM",
+	"dateFormatItem-yyyyMMM": "LLL y 'г'. G",
+	"field-year-short-relative+1": "в след. г.",
 	"field-fri-short-relative+0": "в эту пт.",
 	"field-fri-short-relative+1": "в след. пт.",
 	"days-standAlone-short": [
@@ -272,9 +336,12 @@ define(
 		"пт",
 		"сб"
 	],
-	"months-standAlone-abbr-leap": "Адар II",
+	"field-week-short-relative+-1": "на прошлой нед.",
+	"months-standAlone-abbr-leap": "адар II",
+	"field-hour-narrow-relative+0": "в этот час",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y 'г'. G",
-	"field-hour-short": "ч.",
+	"field-hour-short": "ч",
+	"field-zone-short": "час. пояс",
 	"quarters-format-abbr": [
 		"1-й кв.",
 		"2-й кв.",
@@ -286,7 +353,9 @@ define(
 	"field-fri-narrow-relative+-1": "в прош. пт.",
 	"field-year-relative+0": "в этом году",
 	"field-year-relative+1": "в следующем году",
+	"field-era-narrow": "эра",
 	"field-fri-relative+-1": "в прошлую пятницу",
+	"eraNarrow": "AM",
 	"field-tue-short-relative+-1": "в прош. вт.",
 	"field-minute-narrow": "мин",
 	"days-format-wide": [
@@ -300,14 +369,19 @@ define(
 	],
 	"field-mon-narrow-relative+0": "в этот пн.",
 	"field-mon-narrow-relative+1": "в след. пн.",
+	"dateFormatItem-EHm": "ccc HH:mm",
+	"field-year-short-relative+-1": "в прошлом г.",
 	"field-zone": "часовой пояс",
 	"dateFormatItem-MMMEd": "ccc, d MMM",
-	"months-standAlone-wide-leap": "Адар II",
+	"field-weekOfMonth-narrow": "нед. мес.",
+	"dateFormatItem-EHms": "ccc HH:mm:ss",
+	"field-weekday-narrow": "дн. нед.",
+	"months-standAlone-wide-leap": "адар II",
 	"field-quarter-narrow": "кв.",
 	"field-sun-short-relative+-1": "в прош. вс.",
 	"field-day-relative+-1": "вчера",
-	"dayPeriods-standAlone-abbr-am": "ДП",
 	"field-day-relative+-2": "позавчера",
+	"field-weekday-short": "дн. недели",
 	"days-format-abbr": [
 		"вс",
 		"пн",
@@ -319,13 +393,12 @@ define(
 	],
 	"field-sun-relative+0": "в это воскресенье",
 	"field-sun-relative+1": "в следующее воскресенье",
-	"dateFormatItem-Gy": "y G",
+	"dateFormatItem-Gy": "y 'г'. G",
 	"field-day-short": "дн.",
 	"field-week-narrow": "нед.",
 	"field-era": "эра",
 	"field-fri-narrow-relative+0": "в эту пт.",
-	"field-fri-narrow-relative+1": "в след. пт.",
-	"dayPeriods-standAlone-wide-am": "ДП"
+	"field-fri-narrow-relative+1": "в след. пт."
 }
 //end v1.x content
 );
\ No newline at end of file
