@@ -1,6 +1,8 @@
 define(
 //begin v1.x content
 {
+	"field-quarter-short-relative+0": "ไตรมาสนี้",
+	"field-quarter-short-relative+1": "ไตรมาสหน้า",
 	"field-tue-relative+-1": "อังคารที่แล้ว",
 	"field-year": "ปี",
 	"field-wed-relative+0": "พุธนี้",
@@ -18,13 +20,16 @@ define(
 	"field-week-narrow-relative+0": "สัปดาห์นี้",
 	"field-day-relative+2": "มะรืนนี้",
 	"field-week-narrow-relative+1": "สัปดาห์หน้า",
-	"field-wed-narrow-relative+-1": "พุธที่ผ่านมา",
+	"field-wed-narrow-relative+-1": "พุธที่แล้ว",
 	"field-year-narrow": "ปี",
+	"field-era-short": "สมัย",
 	"field-year-narrow-relative+0": "ปีนี้",
 	"field-tue-relative+0": "อังคารนี้",
 	"field-year-narrow-relative+1": "ปีหน้า",
 	"field-tue-relative+1": "อังคารหน้า",
+	"field-weekdayOfMonth": "วันของเดือน",
 	"field-second-short": "วิ",
+	"field-weekdayOfMonth-narrow": "วันของเดือน",
 	"field-week-relative+0": "สัปดาห์นี้",
 	"field-month-relative+0": "เดือนนี้",
 	"field-week-relative+1": "สัปดาห์หน้า",
@@ -49,13 +54,15 @@ define(
 		"12",
 		"13"
 	],
+	"field-weekOfMonth": "สัปดาห์ของเดือน",
 	"field-month-short": "เดือน",
 	"field-day": "วัน",
+	"field-dayOfYear-short": "วันของปี",
 	"field-year-relative+-1": "ปีที่แล้ว",
 	"field-sat-short-relative+-1": "เสาร์ที่แล้ว",
 	"field-hour-relative+0": "ชั่วโมงนี้",
 	"field-wed-relative+-1": "พุธที่แล้ว",
-	"field-sat-narrow-relative+-1": "เสาร์ที่ผ่านมา",
+	"field-sat-narrow-relative+-1": "เสาร์ที่แล้ว",
 	"field-second": "วินาที",
 	"field-quarter": "ไตรมาส",
 	"field-week-short": "สัปดาห์",
@@ -68,7 +75,6 @@ define(
 	"field-mon-relative+-1": "จันทร์ที่แล้ว",
 	"field-month": "เดือน",
 	"field-day-narrow": "วัน",
-	"field-minute-short": "น.",
 	"field-dayperiod": "ช่วงวัน",
 	"field-sat-short-relative+0": "เสาร์นี้",
 	"field-sat-short-relative+1": "เสาร์หน้า",
@@ -94,7 +100,9 @@ define(
 		"13"
 	],
 	"field-quarter-relative+-1": "ไตรมาสที่แล้ว",
+	"field-dayperiod-narrow": "ช่วงวัน",
 	"field-week-narrow-relative+-1": "สัปดาห์ที่แล้ว",
+	"field-dayOfYear": "วันของปี",
 	"field-sat-relative+-1": "เสาร์ที่แล้ว",
 	"field-hour": "ชั่วโมง",
 	"months-format-wide": [
@@ -123,6 +131,7 @@ define(
 	"field-sun-short-relative+0": "วันอาทิตย์นี้",
 	"field-sun-short-relative+1": "วันอาทิตย์หน้า",
 	"field-week-relative+-1": "สัปดาห์ที่แล้ว",
+	"field-quarter-short-relative+-1": "ไตรมาสที่แล้ว",
 	"months-format-abbr": [
 		"เมสเคอเรม",
 		"เตเกมท",
@@ -144,9 +153,10 @@ define(
 	"field-wed-short-relative+-1": "พุธที่แล้ว",
 	"field-thu-short-relative+-1": "พฤหัสที่แล้ว",
 	"field-year-narrow-relative+-1": "ปีที่แล้ว",
-	"field-mon-narrow-relative+-1": "จันทร์ที่ผ่านมา",
-	"field-thu-narrow-relative+-1": "พฤหัสที่ผ่านมา",
-	"field-tue-narrow-relative+-1": "อังคารที่ผ่านมา",
+	"field-mon-narrow-relative+-1": "จันทร์ที่แล้ว",
+	"field-thu-narrow-relative+-1": "พฤหัสที่แล้ว",
+	"field-tue-narrow-relative+-1": "อังคารที่แล้ว",
+	"field-weekOfMonth-short": "สัปดาห์ของเดือน",
 	"field-wed-short-relative+0": "พุธนี้",
 	"months-standAlone-wide": [
 		"เมสเคอเรม",
@@ -165,12 +175,14 @@ define(
 	],
 	"field-wed-short-relative+1": "พุธหน้า",
 	"field-sun-relative+-1": "วันอาทิตย์ที่แล้ว",
-	"field-weekday": "วันในสัปดาห์",
+	"field-weekday": "วันของสัปดาห์",
 	"field-day-short-relative+0": "วันนี้",
+	"field-quarter-narrow-relative+0": "ไตรมาสนี้",
 	"field-sat-relative+0": "เสาร์นี้",
 	"field-day-short-relative+1": "พรุ่งนี้",
-	"field-sat-relative+1": "เสาร์หน้า",
+	"field-quarter-narrow-relative+1": "ไตรมาสหน้า",
 	"field-day-short-relative+2": "มะรืนนี้",
+	"field-sat-relative+1": "เสาร์หน้า",
 	"field-week-short-relative+0": "สัปดาห์นี้",
 	"field-week-short-relative+1": "สัปดาห์หน้า",
 	"months-standAlone-abbr": [
@@ -188,8 +200,11 @@ define(
 		"เนแฮซ",
 		"พากูเมน"
 	],
+	"field-dayOfYear-narrow": "วันของปี",
 	"field-month-short-relative+0": "เดือนนี้",
 	"field-month-short-relative+1": "เดือนหน้า",
+	"field-weekdayOfMonth-short": "วันของเดือน",
+	"field-zone-narrow": "เขตเวลา",
 	"field-thu-narrow-relative+0": "พฤหัสนี้",
 	"field-thu-narrow-relative+1": "พฤหัสหน้า",
 	"field-sun-narrow-relative+-1": "วันอาทิตย์ที่แล้ว",
@@ -201,28 +216,35 @@ define(
 	"field-week": "สัปดาห์",
 	"field-wed-narrow-relative+0": "พุธนี้",
 	"field-wed-narrow-relative+1": "พุธหน้า",
+	"field-quarter-narrow-relative+-1": "ไตรมาสที่แล้ว",
 	"field-year-short-relative+0": "ปีนี้",
+	"field-dayperiod-short": "ช่วงวัน",
 	"field-year-short-relative+1": "ปีหน้า",
 	"field-fri-short-relative+0": "ศุกร์นี้",
 	"field-fri-short-relative+1": "ศุกร์หน้า",
 	"field-week-short-relative+-1": "สัปดาห์ที่แล้ว",
 	"field-hour-short": "ชม.",
+	"field-zone-short": "โซน",
 	"field-month-narrow": "เดือน",
 	"field-hour-narrow": "ชม.",
-	"field-fri-narrow-relative+-1": "ศุกร์ที่ผ่านมา",
+	"field-fri-narrow-relative+-1": "ศุกร์ที่แล้ว",
 	"field-year-relative+0": "ปีนี้",
 	"field-year-relative+1": "ปีหน้า",
+	"field-era-narrow": "สมัย",
 	"field-fri-relative+-1": "ศุกร์ที่แล้ว",
 	"field-tue-short-relative+-1": "อังคารที่แล้ว",
-	"field-minute-narrow": "น.",
+	"field-minute-narrow": "นาที",
 	"field-mon-narrow-relative+0": "จันทร์นี้",
 	"field-mon-narrow-relative+1": "จันทร์หน้า",
 	"field-year-short-relative+-1": "ปีที่แล้ว",
 	"field-zone": "เขตเวลา",
+	"field-weekOfMonth-narrow": "สัปดาห์ของเดือน",
+	"field-weekday-narrow": "วันของสัปดาห์",
 	"field-quarter-narrow": "ไตรมาส",
 	"field-sun-short-relative+-1": "วันอาทิตย์ที่แล้ว",
 	"field-day-relative+-1": "เมื่อวาน",
 	"field-day-relative+-2": "เมื่อวานซืน",
+	"field-weekday-short": "วันของสัปดาห์",
 	"field-sun-relative+0": "วันอาทิตย์นี้",
 	"field-sun-relative+1": "วันอาทิตย์หน้า",
 	"field-day-short": "วัน",
