@@ -1,6 +1,8 @@
 define(
 //begin v1.x content
 {
+	"field-quarter-short-relative+0": "ไตรมาสนี้",
+	"field-quarter-short-relative+1": "ไตรมาสหน้า",
 	"field-tue-relative+-1": "อังคารที่แล้ว",
 	"field-year": "ปี",
 	"dateFormatItem-Hm": "HH:mm",
@@ -11,24 +13,27 @@ define(
 	"field-month-narrow-relative+-1": "เดือนที่แล้ว",
 	"field-tue-narrow-relative+0": "อังคารนี้",
 	"field-tue-narrow-relative+1": "อังคารหน้า",
-	"field-thu-short-relative+0": "พฤหัสนี้",
 	"field-day-short-relative+-1": "เมื่อวาน",
+	"field-thu-short-relative+0": "พฤหัสนี้",
 	"dateTimeFormat-short": "{1} {0}",
-	"field-thu-short-relative+1": "พฤหัสหน้า",
 	"field-day-relative+0": "วันนี้",
 	"field-day-short-relative+-2": "เมื่อวานซืน",
+	"field-thu-short-relative+1": "พฤหัสหน้า",
 	"field-day-relative+1": "พรุ่งนี้",
 	"field-week-narrow-relative+0": "สัปดาห์นี้",
 	"field-day-relative+2": "มะรืนนี้",
 	"field-week-narrow-relative+1": "สัปดาห์หน้า",
-	"field-wed-narrow-relative+-1": "พุธที่ผ่านมา",
+	"field-wed-narrow-relative+-1": "พุธที่แล้ว",
 	"field-year-narrow": "ปี",
+	"field-era-short": "สมัย",
 	"field-year-narrow-relative+0": "ปีนี้",
 	"field-tue-relative+0": "อังคารนี้",
 	"field-year-narrow-relative+1": "ปีหน้า",
 	"field-tue-relative+1": "อังคารหน้า",
+	"field-weekdayOfMonth": "วันของเดือน",
 	"field-second-short": "วิ",
 	"dateFormatItem-MMMd": "d MMM",
+	"field-weekdayOfMonth-narrow": "วันของเดือน",
 	"field-week-relative+0": "สัปดาห์นี้",
 	"field-month-relative+0": "เดือนนี้",
 	"field-week-relative+1": "สัปดาห์หน้า",
@@ -39,17 +44,19 @@ define(
 	"field-mon-short-relative+1": "จันทร์หน้า",
 	"field-second-relative+0": "ขณะนี้",
 	"dateFormatItem-yyyyQQQ": "QQQ G y",
+	"field-weekOfMonth": "สัปดาห์ของเดือน",
 	"field-month-short": "เดือน",
 	"dateFormatItem-GyMMMEd": "E d MMM G y",
 	"dateFormatItem-yyyyMd": "d/M/GGGGG y",
 	"field-day": "วัน",
+	"field-dayOfYear-short": "วันของปี",
 	"field-year-relative+-1": "ปีที่แล้ว",
 	"field-sat-short-relative+-1": "เสาร์ที่แล้ว",
 	"field-hour-relative+0": "ชั่วโมงนี้",
 	"dateFormatItem-yyyyMEd": "E d/M/GGGGG y",
 	"field-wed-relative+-1": "พุธที่แล้ว",
 	"dateTimeFormat-medium": "{1} {0}",
-	"field-sat-narrow-relative+-1": "เสาร์ที่ผ่านมา",
+	"field-sat-narrow-relative+-1": "เสาร์ที่แล้ว",
 	"field-second": "วินาที",
 	"dateFormat-long": "d MMMM ปีG y",
 	"dateFormatItem-GyMMMd": "d MMM G y",
@@ -66,7 +73,6 @@ define(
 	"field-month": "เดือน",
 	"field-day-narrow": "วัน",
 	"dateFormatItem-MMM": "LLL",
-	"field-minute-short": "น.",
 	"field-dayperiod": "ช่วงวัน",
 	"field-sat-short-relative+0": "เสาร์นี้",
 	"field-sat-short-relative+1": "เสาร์หน้า",
@@ -307,7 +313,8 @@ define(
 		"เมจิ",
 		"ทะอิโช",
 		"โชวะ",
-		"เฮเซ"
+		"เฮเซ",
+		"เรวะ"
 	],
 	"dateFormatItem-yyyyM": "M/GGGGG y",
 	"field-second-narrow": "วิ",
@@ -318,7 +325,9 @@ define(
 	"field-day-narrow-relative+-2": "เมื่อวานซืน",
 	"field-quarter-relative+-1": "ไตรมาสที่แล้ว",
 	"dateFormatItem-yyyyMMMd": "d MMM G y",
+	"field-dayperiod-narrow": "ช่วงวัน",
 	"field-week-narrow-relative+-1": "สัปดาห์ที่แล้ว",
+	"field-dayOfYear": "วันของปี",
 	"field-sat-relative+-1": "เสาร์ที่แล้ว",
 	"dateTimeFormat-long": "{1} {0}",
 	"dateFormatItem-Md": "d/M",
@@ -336,38 +345,45 @@ define(
 	"field-sun-short-relative+0": "วันอาทิตย์นี้",
 	"field-sun-short-relative+1": "วันอาทิตย์หน้า",
 	"field-week-relative+-1": "สัปดาห์ที่แล้ว",
+	"field-quarter-short-relative+-1": "ไตรมาสที่แล้ว",
 	"field-quarter-relative+0": "ไตรมาสนี้",
 	"field-minute-relative+0": "นาทีนี้",
 	"field-quarter-relative+1": "ไตรมาสหน้า",
 	"field-wed-short-relative+-1": "พุธที่แล้ว",
 	"dateFormat-short": "d/M/yy G",
-	"field-thu-short-relative+-1": "พฤหัสที่แล้ว",
 	"field-year-narrow-relative+-1": "ปีที่แล้ว",
+	"field-thu-short-relative+-1": "พฤหัสที่แล้ว",
 	"dateFormatItem-yyyyMMMEd": "E d MMM G y",
-	"field-mon-narrow-relative+-1": "จันทร์ที่ผ่านมา",
-	"field-thu-narrow-relative+-1": "พฤหัสที่ผ่านมา",
-	"field-tue-narrow-relative+-1": "อังคารที่ผ่านมา",
+	"field-mon-narrow-relative+-1": "จันทร์ที่แล้ว",
+	"field-thu-narrow-relative+-1": "พฤหัสที่แล้ว",
 	"dateFormatItem-H": "HH",
+	"field-weekOfMonth-short": "สัปดาห์ของเดือน",
+	"field-tue-narrow-relative+-1": "อังคารที่แล้ว",
 	"dateFormatItem-yyyy": "G y",
-	"field-wed-short-relative+0": "พุธนี้",
 	"dateFormatItem-M": "L",
+	"field-wed-short-relative+0": "พุธนี้",
 	"field-wed-short-relative+1": "พุธหน้า",
 	"field-sun-relative+-1": "วันอาทิตย์ที่แล้ว",
 	"dateTimeFormat-full": "{1} {0}",
 	"dateFormatItem-hm": "h:mm a",
 	"dateFormatItem-d": "d",
-	"field-weekday": "วันในสัปดาห์",
+	"field-weekday": "วันของสัปดาห์",
 	"field-day-short-relative+0": "วันนี้",
+	"field-quarter-narrow-relative+0": "ไตรมาสนี้",
 	"field-day-short-relative+1": "พรุ่งนี้",
 	"field-sat-relative+0": "เสาร์นี้",
+	"field-quarter-narrow-relative+1": "ไตรมาสหน้า",
 	"dateFormatItem-h": "h a",
 	"field-day-short-relative+2": "มะรืนนี้",
 	"field-sat-relative+1": "เสาร์หน้า",
 	"field-week-short-relative+0": "สัปดาห์นี้",
 	"field-week-short-relative+1": "สัปดาห์หน้า",
+	"field-dayOfYear-narrow": "วันของปี",
 	"field-month-short-relative+0": "เดือนนี้",
 	"field-month-short-relative+1": "เดือนหน้า",
+	"field-weekdayOfMonth-short": "วันของเดือน",
 	"dateFormatItem-MEd": "E, d/M",
+	"field-zone-narrow": "เขตเวลา",
 	"dateFormatItem-y": "G y",
 	"field-thu-narrow-relative+0": "พฤหัสนี้",
 	"field-sun-narrow-relative+-1": "วันอาทิตย์ที่แล้ว",
@@ -382,31 +398,38 @@ define(
 	"dateFormatItem-Ed": "E d",
 	"field-wed-narrow-relative+0": "พุธนี้",
 	"field-wed-narrow-relative+1": "พุธหน้า",
+	"field-quarter-narrow-relative+-1": "ไตรมาสที่แล้ว",
 	"field-year-short-relative+0": "ปีนี้",
 	"dateFormatItem-yyyyMMM": "MMM G y",
+	"field-dayperiod-short": "ช่วงวัน",
 	"field-year-short-relative+1": "ปีหน้า",
 	"field-fri-short-relative+0": "ศุกร์นี้",
 	"field-fri-short-relative+1": "ศุกร์หน้า",
 	"field-week-short-relative+-1": "สัปดาห์ที่แล้ว",
 	"dateFormatItem-yyyyQQQQ": "QQQQ G y",
 	"field-hour-short": "ชม.",
+	"field-zone-short": "โซน",
 	"field-month-narrow": "เดือน",
 	"field-hour-narrow": "ชม.",
-	"field-fri-narrow-relative+-1": "ศุกร์ที่ผ่านมา",
+	"field-fri-narrow-relative+-1": "ศุกร์ที่แล้ว",
 	"field-year-relative+0": "ปีนี้",
 	"field-year-relative+1": "ปีหน้า",
+	"field-era-narrow": "สมัย",
 	"field-fri-relative+-1": "ศุกร์ที่แล้ว",
 	"field-tue-short-relative+-1": "อังคารที่แล้ว",
-	"field-minute-narrow": "น.",
+	"field-minute-narrow": "นาที",
 	"field-mon-narrow-relative+0": "จันทร์นี้",
 	"field-mon-narrow-relative+1": "จันทร์หน้า",
 	"field-year-short-relative+-1": "ปีที่แล้ว",
 	"field-zone": "เขตเวลา",
 	"dateFormatItem-MMMEd": "E d MMM",
+	"field-weekOfMonth-narrow": "สัปดาห์ของเดือน",
+	"field-weekday-narrow": "วันของสัปดาห์",
 	"field-quarter-narrow": "ไตรมาส",
 	"field-sun-short-relative+-1": "วันอาทิตย์ที่แล้ว",
 	"field-day-relative+-1": "เมื่อวาน",
 	"field-day-relative+-2": "เมื่อวานซืน",
+	"field-weekday-short": "วันของสัปดาห์",
 	"field-sun-relative+0": "วันอาทิตย์นี้",
 	"field-sun-relative+1": "วันอาทิตย์หน้า",
 	"dateFormatItem-Gy": "G y",
