@@ -1,190 +1,11 @@
 define(
 //begin v1.x content
 {
-	"field-quarter-short-relative+0": "這一季",
-	"field-quarter-short-relative+1": "下一季",
-	"field-tue-relative+-1": "上週二",
-	"field-year": "年",
-	"dateFormatItem-yw": "y年的第w週",
-	"dayPeriods-format-abbr-afternoon1": "中午",
-	"dayPeriods-format-abbr-afternoon2": "下午",
-	"dateFormatItem-Hm": "HH:mm",
-	"field-wed-relative+0": "本週三",
-	"field-wed-relative+1": "下週三",
-	"dateFormatItem-ms": "mm:ss",
-	"timeFormat-short": "ah:mm",
-	"field-minute": "分鐘",
-	"field-tue-narrow-relative+0": "本週二",
-	"field-tue-narrow-relative+1": "下週二",
-	"field-thu-short-relative+0": "本週四",
-	"dateTimeFormat-short": "{1} {0}",
-	"field-day-relative+0": "今天",
-	"field-thu-short-relative+1": "下週四",
-	"field-day-relative+1": "明天",
-	"field-day-relative+2": "後天",
-	"field-wed-narrow-relative+-1": "上週三",
-	"field-year-narrow": "年",
-	"field-tue-relative+0": "本週二",
-	"field-tue-relative+1": "下週二",
-	"dayPeriods-format-narrow-am": "上午",
-	"field-second-short": "秒",
-	"dayPeriods-standAlone-abbr-morning1": "清晨",
-	"dayPeriods-standAlone-abbr-morning2": "上午",
-	"dateFormatItem-MMMd": "M月d日",
-	"dayPeriods-format-narrow-morning1": "清晨",
-	"dayPeriods-format-narrow-morning2": "上午",
-	"dayPeriods-format-abbr-am": "上午",
-	"field-month-relative+0": "本月",
-	"field-week-relative+0": "本週",
-	"timeFormat-medium": "ah:mm:ss",
-	"field-month-relative+1": "下個月",
-	"field-week-relative+1": "下週",
+	"dateFormatItem-yMMMM": "y年M月",
+	"field-thu-narrow-relative+0": "本週四",
+	"field-thu-narrow-relative+1": "下週四",
 	"field-sun-narrow-relative+0": "本週日",
-	"field-mon-short-relative+0": "本週一",
 	"field-sun-narrow-relative+1": "下週日",
-	"field-mon-short-relative+1": "下週一",
-	"field-second-relative+0": "現在",
-	"months-standAlone-narrow": [
-		"1",
-		"2",
-		"3",
-		"4",
-		"5",
-		"6",
-		"7",
-		"8",
-		"9",
-		"10",
-		"11",
-		"12"
-	],
-	"eraNames": [
-		"西元前",
-		"西元"
-	],
-	"dayPeriods-standAlone-abbr-pm": "下午",
-	"dateFormatItem-GyMMMEd": "Gy年M月d日 E",
-	"field-month-short": "月",
-	"field-day": "日",
-	"dayPeriods-standAlone-wide-night1": "凌晨",
-	"field-year-relative+-1": "去年",
-	"dayPeriods-format-wide-am": "上午",
-	"field-sat-short-relative+-1": "上週六",
-	"dayPeriods-format-narrow-afternoon1": "中午",
-	"dayPeriods-format-wide-afternoon1": "中午",
-	"dayPeriods-format-narrow-afternoon2": "下午",
-	"field-hour-relative+0": "這一小時",
-	"dayPeriods-format-wide-afternoon2": "下午",
-	"field-wed-relative+-1": "上週三",
-	"dateTimeFormat-medium": "{1} {0}",
-	"days-standAlone-narrow": [
-		"日",
-		"一",
-		"二",
-		"三",
-		"四",
-		"五",
-		"六"
-	],
-	"field-sat-narrow-relative+-1": "上週六",
-	"field-second": "秒",
-	"dayPeriods-standAlone-wide-pm": "下午",
-	"dateFormatItem-Ehms": "E ah:mm:ss",
-	"dateFormat-long": "y年M月d日",
-	"dateFormatItem-GyMMMd": "Gy年M月d日",
-	"dayPeriods-standAlone-abbr-midnight": "午夜",
-	"field-quarter": "季",
-	"field-week-short": "週",
-	"dayPeriods-format-narrow-midnight": "午夜",
-	"dateFormatItem-yMMMEd": "y年M月d日 E",
-	"quarters-standAlone-wide": [
-		"第1季",
-		"第2季",
-		"第3季",
-		"第4季"
-	],
-	"days-format-narrow": [
-		"日",
-		"一",
-		"二",
-		"三",
-		"四",
-		"五",
-		"六"
-	],
-	"dayPeriods-format-wide-evening1": "晚上",
-	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
-	"field-tue-short-relative+0": "本週二",
-	"field-tue-short-relative+1": "下週二",
-	"field-mon-relative+-1": "上週一",
-	"dateFormatItem-GyMMM": "Gy年M月",
-	"field-month": "月",
-	"dayPeriods-standAlone-abbr-night1": "凌晨",
-	"field-day-narrow": "日",
-	"dayPeriods-standAlone-narrow-afternoon1": "中午",
-	"dayPeriods-standAlone-narrow-afternoon2": "下午",
-	"dateFormatItem-MMM": "LLL",
-	"field-minute-short": "分鐘",
-	"field-dayperiod": "上午/下午",
-	"field-sat-short-relative+0": "本週六",
-	"field-sat-short-relative+1": "下週六",
-	"dayPeriods-format-narrow-pm": "下午",
-	"dateFormat-medium": "y年M月d日",
-	"eraAbbr": [
-		"西元前",
-		"西元"
-	],
-	"quarters-standAlone-abbr": [
-		"1季",
-		"2季",
-		"3季",
-		"4季"
-	],
-	"dayPeriods-format-abbr-pm": "下午",
-	"field-second-narrow": "秒",
-	"dayPeriods-standAlone-narrow-night1": "凌晨",
-	"field-mon-relative+0": "本週一",
-	"field-year-short": "年",
-	"field-mon-relative+1": "下週一",
-	"months-format-narrow": [
-		"1",
-		"2",
-		"3",
-		"4",
-		"5",
-		"6",
-		"7",
-		"8",
-		"9",
-		"10",
-		"11",
-		"12"
-	],
-	"dayPeriods-format-wide-morning1": "清晨",
-	"dayPeriods-format-wide-morning2": "上午",
-	"field-quarter-relative+-1": "上一季",
-	"dayPeriods-standAlone-narrow-am": "上午",
-	"days-format-short": [
-		"日",
-		"一",
-		"二",
-		"三",
-		"四",
-		"五",
-		"六"
-	],
-	"quarters-format-narrow": [
-		"1",
-		"2",
-		"3",
-		"4"
-	],
-	"dayPeriods-format-wide-pm": "下午",
-	"field-sat-relative+-1": "上週六",
-	"dateTimeFormat-long": "{1} {0}",
-	"dateFormatItem-Md": "M/d",
-	"field-hour": "小時",
-	"dateFormatItem-yQQQQ": "y年QQQQ",
 	"months-format-wide": [
 		"1月",
 		"2月",
@@ -199,46 +20,30 @@ define(
 		"11月",
 		"12月"
 	],
-	"dayPeriods-format-wide-night1": "凌晨",
-	"dateFormat-full": "y年M月d日 EEEE",
-	"field-month-relative+-1": "上個月",
+	"dayPeriods-standAlone-abbr-pm": "下午",
 	"dateFormatItem-Hms": "HH:mm:ss",
-	"field-quarter-short": "季",
-	"field-sat-narrow-relative+0": "本週六",
-	"dateFormatItem-Hmv": "HH:mm [v]",
-	"field-fri-relative+0": "本週五",
-	"field-sat-narrow-relative+1": "下週六",
-	"field-fri-relative+1": "下週五",
-	"field-sun-short-relative+0": "本週日",
-	"field-sun-short-relative+1": "下週日",
-	"field-week-relative+-1": "上週",
-	"field-quarter-short-relative+-1": "上一季",
-	"dateFormatItem-Ehm": "E ah:mm",
-	"months-format-abbr": [
-		"1月",
-		"2月",
-		"3月",
-		"4月",
-		"5月",
-		"6月",
-		"7月",
-		"8月",
-		"9月",
-		"10月",
-		"11月",
-		"12月"
+	"field-fri-narrow-relative+0": "本週五",
+	"field-fri-narrow-relative+1": "下週五",
+	"eraNarrow": [
+		"西元前",
+		"公元前",
+		"西元",
+		"公元"
 	],
-	"dayPeriods-format-wide-midnight": "午夜",
-	"field-quarter-relative+0": "這一季",
-	"timeFormat-long": "ah:mm:ss [z]",
-	"field-minute-relative+0": "這一分鐘",
-	"field-quarter-relative+1": "下一季",
-	"field-wed-short-relative+-1": "上週三",
-	"dateFormatItem-yMMM": "y年M月",
-	"dateFormat-short": "y/M/d",
+	"dateFormatItem-Hmv": "HH:mm [v]",
+	"dateFormatItem-hmsv": "ah:mm:ss [v]",
+	"dateFormatItem-yMMMd": "y年M月d日",
 	"dayPeriods-format-abbr-night1": "凌晨",
-	"dateFormatItem-MMMMW": "MMM的第W週",
-	"field-thu-short-relative+-1": "上週四",
+	"dayPeriods-format-narrow-evening1": "晚上",
+	"days-standAlone-narrow": [
+		"日",
+		"一",
+		"二",
+		"三",
+		"四",
+		"五",
+		"六"
+	],
 	"days-standAlone-wide": [
 		"星期日",
 		"星期一",
@@ -248,15 +53,72 @@ define(
 		"星期五",
 		"星期六"
 	],
-	"field-mon-narrow-relative+-1": "上週一",
-	"dateFormatItem-MMMMd": "M月d日",
+	"dayPeriods-format-abbr-afternoon1": "中午",
+	"dayPeriods-format-wide-evening1": "晚上",
+	"dayPeriods-format-abbr-afternoon2": "下午",
+	"dateFormatItem-Ehm": "E ah:mm",
+	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
+	"field-wed-narrow-relative+-1": "上週三",
+	"dayPeriods-standAlone-wide-evening1": "晚上",
+	"field-minute-narrow-relative+0": "這一分鐘",
+	"days-format-wide": [
+		"星期日",
+		"星期一",
+		"星期二",
+		"星期三",
+		"星期四",
+		"星期五",
+		"星期六"
+	],
+	"dateFormatItem-yMM": "y/MM",
+	"field-month-short-relative+0": "本月",
+	"field-month-short-relative+1": "下個月",
+	"dateFormatItem-Ehms": "E ah:mm:ss",
+	"dayPeriods-standAlone-narrow-evening1": "晚上",
+	"dayPeriods-standAlone-abbr-afternoon1": "中午",
+	"dayPeriods-standAlone-abbr-afternoon2": "下午",
+	"field-thu-relative+0": "本週四",
+	"dayPeriods-standAlone-abbr-night1": "凌晨",
+	"field-thu-relative+1": "下週四",
+	"dayPeriods-format-wide-am": "上午",
+	"field-fri-relative+0": "本週五",
+	"field-fri-relative+1": "下週五",
+	"dateFormatItem-yMd": "y/M/d",
 	"field-thu-narrow-relative+-1": "上週四",
-	"dateFormatItem-E": "ccc",
-	"dateFormatItem-H": "H時",
-	"field-tue-narrow-relative+-1": "上週二",
-	"dayPeriods-format-abbr-evening1": "晚上",
-	"dayPeriods-standAlone-narrow-pm": "下午",
-	"dateFormatItem-M": "M月",
+	"field-quarter-relative+0": "這一季",
+	"field-quarter-relative+1": "下一季",
+	"field-sun-short-relative+0": "本週日",
+	"timeFormat-short": "ah:mm",
+	"field-sun-short-relative+1": "下週日",
+	"dateFormatItem-hms": "ah:mm:ss",
+	"dayPeriods-format-narrow-afternoon1": "中午",
+	"dateFormatItem-Md": "M/d",
+	"dayPeriods-format-narrow-afternoon2": "下午",
+	"dateFormatItem-Hmsv": "HH:mm:ss [v]",
+	"dateFormatItem-hmv": "ah:mm [v]",
+	"field-week-narrow": "週",
+	"field-hour-relative+0": "這一小時",
+	"field-day-relative+-1": "昨天",
+	"field-day-relative+-2": "前天",
+	"field-mon-narrow-relative+-1": "上週一",
+	"field-minute-narrow": "分鐘",
+	"field-thu-short-relative+0": "本週四",
+	"field-mon-relative+0": "本週一",
+	"field-thu-short-relative+1": "下週四",
+	"field-mon-relative+1": "下週一",
+	"field-day-narrow-relative+0": "今天",
+	"field-era-short": "年代",
+	"field-day-narrow-relative+1": "明天",
+	"field-sat-narrow-relative+0": "本週六",
+	"field-day-narrow-relative+2": "後天",
+	"timeFormat-long": "ah:mm:ss [z]",
+	"field-sat-narrow-relative+1": "下週六",
+	"field-week-narrow-relative+0": "本週",
+	"field-week-narrow-relative+1": "下週",
+	"field-hour-short-relative+0": "這一小時",
+	"field-wed-narrow-relative+0": "本週三",
+	"field-wed-narrow-relative+1": "下週三",
+	"field-month": "月",
 	"months-standAlone-wide": [
 		"1月",
 		"2月",
@@ -271,10 +133,205 @@ define(
 		"11月",
 		"12月"
 	],
+	"field-weekday-narrow": "週天",
+	"dayPeriods-standAlone-narrow-afternoon1": "中午",
+	"dayPeriods-standAlone-narrow-afternoon2": "下午",
+	"field-year-relative+0": "今年",
+	"field-year-relative+1": "明年",
+	"dayPeriods-format-abbr-evening1": "晚上",
+	"dayPeriods-format-narrow-midnight": "午夜",
+	"dayPeriods-format-wide-midnight": "午夜",
+	"field-tue-relative+0": "本週二",
+	"field-tue-relative+1": "下週二",
+	"dayPeriods-standAlone-abbr-evening1": "晚上",
+	"field-minute-short-relative+0": "這一分鐘",
+	"dateFormatItem-hm": "ah:mm",
+	"dayPeriods-standAlone-wide-midnight": "午夜",
+	"field-year-narrow": "年",
+	"field-tue-short-relative+0": "本週二",
+	"dayPeriods-standAlone-narrow-midnight": "午夜",
+	"field-tue-short-relative+1": "下週二",
+	"field-tue-narrow-relative+0": "本週二",
+	"field-tue-narrow-relative+1": "下週二",
+	"dateTimeFormat-full": "{1} {0}",
+	"dateFormatItem-E": "ccc",
+	"dateFormatItem-EBhm": "E Bh:mm",
+	"dateFormatItem-H": "H時",
+	"field-wed-relative+0": "本週三",
+	"field-wed-relative+1": "下週三",
+	"dateFormatItem-M": "M月",
 	"field-wed-short-relative+0": "本週三",
+	"field-fri-short-relative+0": "本週五",
 	"field-wed-short-relative+1": "下週三",
-	"dateFormatItem-Hmsv": "HH:mm:ss [v]",
-	"field-sun-relative+-1": "上週日",
+	"field-fri-short-relative+1": "下週五",
+	"field-weekOfMonth-short": "週",
+	"field-quarter-short-relative+-1": "上一季",
+	"field-year-short-relative+-1": "去年",
+	"dateFormatItem-Bhm": "Bh:mm",
+	"dayPeriods-format-wide-night1": "凌晨",
+	"dateTimeFormat-medium": "{1} {0}",
+	"field-quarter-narrow-relative+-1": "上一季",
+	"dateFormatItem-d": "d日",
+	"dayPeriods-format-abbr-pm": "下午",
+	"dateFormatItem-h": "ah時",
+	"quarters-standAlone-wide": [
+		"第1季",
+		"第2季",
+		"第3季",
+		"第4季"
+	],
+	"field-weekOfMonth-narrow": "週",
+	"dateFormatItem-y": "y年",
+	"field-minute-relative+0": "這一分鐘",
+	"field-year-short-relative+0": "今年",
+	"dateFormatItem-EBhms": "E Bh:mm:ss",
+	"field-year-short-relative+1": "明年",
+	"field-weekday": "週天",
+	"dayPeriods-format-narrow-pm": "下午",
+	"field-tue-narrow-relative+-1": "上週二",
+	"dateFormatItem-yMEd": "y/M/d（E）",
+	"dayPeriods-standAlone-wide-night1": "凌晨",
+	"field-year-narrow-relative+-1": "去年",
+	"field-sat-relative+-1": "上週六",
+	"dayPeriods-format-abbr-midnight": "午夜",
+	"dayPeriods-format-narrow-morning1": "清晨",
+	"dayPeriods-format-narrow-morning2": "上午",
+	"dayPeriods-format-wide-morning1": "清晨",
+	"dayPeriods-format-wide-morning2": "上午",
+	"dayPeriods-standAlone-abbr-midnight": "午夜",
+	"dayPeriods-standAlone-narrow-pm": "下午",
+	"dayPeriods-standAlone-wide-morning1": "清晨",
+	"field-mon-narrow-relative+0": "本週一",
+	"dayPeriods-standAlone-wide-morning2": "上午",
+	"field-mon-narrow-relative+1": "下週一",
+	"field-second": "秒",
+	"dateFormatItem-yMMMEd": "y年M月d日 E",
+	"field-year-relative+-1": "去年",
+	"field-weekdayOfMonth-short": "每月平日",
+	"dateFormat-short": "y/M/d",
+	"eraNames": [
+		"西元前",
+		"西元"
+	],
+	"field-second-short": "秒",
+	"field-thu-short-relative+-1": "上週四",
+	"field-zone": "時區",
+	"field-dayperiod-narrow": "上午/下午",
+	"field-sun-short-relative+-1": "上週日",
+	"dayPeriods-standAlone-narrow-morning1": "清晨",
+	"dayPeriods-standAlone-narrow-morning2": "上午",
+	"eraAbbr": [
+		"西元前",
+		"西元"
+	],
+	"field-week-short": "週",
+	"dayPeriods-standAlone-abbr-am": "上午",
+	"dayPeriods-standAlone-wide-pm": "下午",
+	"dateFormatItem-ms": "mm:ss",
+	"field-day-relative+0": "今天",
+	"field-day-relative+1": "明天",
+	"field-day-relative+2": "後天",
+	"field-day-short-relative+0": "今天",
+	"field-dayOfYear-short": "年天",
+	"field-day-short-relative+1": "明天",
+	"dateFormat-long": "y年M月d日",
+	"field-day-short-relative+2": "後天",
+	"field-sun-narrow-relative+-1": "上週日",
+	"field-second-relative+0": "現在",
+	"field-quarter-relative+-1": "上一季",
+	"dayPeriods-format-narrow-night1": "凌晨",
+	"quarters-format-abbr": [
+		"第1季",
+		"第2季",
+		"第3季",
+		"第4季"
+	],
+	"dayPeriods-standAlone-narrow-night1": "凌晨",
+	"field-week-relative+-1": "上週",
+	"dayPeriods-format-abbr-morning1": "清晨",
+	"field-month-relative+-1": "上個月",
+	"dayPeriods-format-abbr-morning2": "上午",
+	"months-format-narrow": [
+		"1",
+		"2",
+		"3",
+		"4",
+		"5",
+		"6",
+		"7",
+		"8",
+		"9",
+		"10",
+		"11",
+		"12"
+	],
+	"field-year": "年",
+	"field-era": "年代",
+	"dayPeriods-standAlone-abbr-morning1": "清晨",
+	"dayPeriods-standAlone-abbr-morning2": "上午",
+	"days-standAlone-short": [
+		"日",
+		"一",
+		"二",
+		"三",
+		"四",
+		"五",
+		"六"
+	],
+	"quarters-format-narrow": [
+		"1",
+		"2",
+		"3",
+		"4"
+	],
+	"dateFormatItem-yQQQQ": "y年QQQQ",
+	"field-day-short-relative+-1": "昨天",
+	"field-day-short-relative+-2": "前天",
+	"dateFormatItem-GyMMM": "Gy年M月",
+	"timeFormat-full": "ah:mm:ss [zzzz]",
+	"dateFormatItem-Bhms": "Bh:mm:ss",
+	"field-hour": "小時",
+	"field-dayOfYear-narrow": "年天",
+	"field-second-narrow-relative+0": "現在",
+	"field-quarter": "季",
+	"field-month-narrow-relative+0": "本月",
+	"field-month-narrow-relative+1": "下個月",
+	"dateFormatItem-MMdd": "MM/dd",
+	"field-day": "日",
+	"field-mon-relative+-1": "上週一",
+	"field-dayOfYear": "年天",
+	"dateFormat-medium": "y年M月d日",
+	"dateTimeFormat-short": "{1} {0}",
+	"dateFormatItem-yMMM": "y年M月",
+	"dateFormatItem-GyMMMd": "Gy年M月d日",
+	"dateFormatItem-MEd": "M/d（E）",
+	"field-tue-short-relative+-1": "上週二",
+	"field-year-short": "年",
+	"field-month-short": "月",
+	"dateFormatItem-MMMEd": "M月d日 E",
+	"dayPeriods-format-wide-afternoon1": "中午",
+	"dateFormatItem-MMMd": "M月d日",
+	"dayPeriods-format-wide-afternoon2": "下午",
+	"dateFormatItem-Bh": "Bh時",
+	"months-format-abbr": [
+		"1月",
+		"2月",
+		"3月",
+		"4月",
+		"5月",
+		"6月",
+		"7月",
+		"8月",
+		"9月",
+		"10月",
+		"11月",
+		"12月"
+	],
+	"dayPeriods-format-abbr-am": "上午",
+	"field-sat-relative+0": "本週六",
+	"field-sat-relative+1": "下週六",
+	"dayPeriods-format-wide-pm": "下午",
+	"field-zone-short": "時區",
 	"days-standAlone-abbr": [
 		"週日",
 		"週一",
@@ -284,16 +341,96 @@ define(
 		"週五",
 		"週六"
 	],
-	"dateTimeFormat-full": "{1} {0}",
-	"dateFormatItem-hm": "ah:mm",
-	"dateFormatItem-d": "d日",
-	"field-weekday": "週天",
-	"dayPeriods-standAlone-wide-evening1": "晚上",
-	"field-quarter-narrow-relative+0": "這一季",
-	"field-sat-relative+0": "本週六",
-	"dateFormatItem-h": "ah時",
-	"field-quarter-narrow-relative+1": "下一季",
-	"field-sat-relative+1": "下週六",
+	"field-week-short-relative+0": "本週",
+	"field-week-short-relative+1": "下週",
+	"dayPeriods-standAlone-wide-afternoon1": "中午",
+	"dayPeriods-standAlone-wide-afternoon2": "下午",
+	"field-fri-short-relative+-1": "上週五",
+	"field-month-narrow": "月",
+	"dayPeriods-format-narrow-am": "上午",
+	"field-month-narrow-relative+-1": "上個月",
+	"days-format-abbr": [
+		"週日",
+		"週一",
+		"週二",
+		"週三",
+		"週四",
+		"週五",
+		"週六"
+	],
+	"field-weekday-short": "週天",
+	"field-day-narrow-relative+-1": "昨天",
+	"field-day-narrow-relative+-2": "前天",
+	"field-quarter-short": "季",
+	"days-format-short": [
+		"日",
+		"一",
+		"二",
+		"三",
+		"四",
+		"五",
+		"六"
+	],
+	"months-standAlone-narrow": [
+		"1",
+		"2",
+		"3",
+		"4",
+		"5",
+		"6",
+		"7",
+		"8",
+		"9",
+		"10",
+		"11",
+		"12"
+	],
+	"days-format-narrow": [
+		"日",
+		"一",
+		"二",
+		"三",
+		"四",
+		"五",
+		"六"
+	],
+	"dateFormatItem-EHm": "E HH:mm",
+	"field-quarter-narrow": "季",
+	"field-mon-short-relative+0": "本週一",
+	"field-mon-short-relative+1": "下週一",
+	"field-dayperiod-short": "上午/下午",
+	"dayPeriods-standAlone-narrow-am": "上午",
+	"field-week-narrow-relative+-1": "上週",
+	"field-thu-relative+-1": "上週四",
+	"field-fri-narrow-relative+-1": "上週五",
+	"field-mon-short-relative+-1": "上週一",
+	"timeFormat-medium": "ah:mm:ss",
+	"field-quarter-short-relative+0": "這一季",
+	"field-quarter-short-relative+1": "下一季",
+	"dateFormatItem-Ed": "d E",
+	"field-wed-relative+-1": "上週三",
+	"field-weekOfMonth": "週",
+	"field-weekdayOfMonth-narrow": "每月平日",
+	"dayPeriods-standAlone-wide-am": "上午",
+	"dateFormatItem-yQQQ": "y年QQQ",
+	"field-fri-relative+-1": "上週五",
+	"field-minute": "分鐘",
+	"quarters-standAlone-narrow": [
+		"1",
+		"2",
+		"3",
+		"4"
+	],
+	"field-second-short-relative+0": "現在",
+	"quarters-format-wide": [
+		"第1季",
+		"第2季",
+		"第3季",
+		"第4季"
+	],
+	"field-day-short": "日",
+	"field-dayperiod": "上午/下午",
+	"field-hour-short": "小時",
 	"months-standAlone-abbr": [
 		"1月",
 		"2月",
@@ -308,132 +445,51 @@ define(
 		"11月",
 		"12月"
 	],
-	"dateFormatItem-hmsv": "ah:mm:ss [v]",
-	"dayPeriods-format-abbr-morning1": "清晨",
-	"dayPeriods-standAlone-narrow-evening1": "晚上",
-	"dateFormatItem-yMM": "y/MM",
-	"dayPeriods-format-abbr-morning2": "上午",
-	"timeFormat-full": "ah:mm:ss [zzzz]",
-	"dateFormatItem-MEd": "M/d（E）",
-	"dateFormatItem-y": "y年",
-	"field-thu-narrow-relative+0": "本週四",
-	"field-sun-narrow-relative+-1": "上週日",
-	"field-mon-short-relative+-1": "上週一",
-	"field-thu-narrow-relative+1": "下週四",
-	"field-thu-relative+0": "本週四",
-	"dayPeriods-standAlone-abbr-afternoon1": "中午",
-	"field-thu-relative+1": "下週四",
-	"dayPeriods-standAlone-abbr-afternoon2": "下午",
-	"dateFormatItem-hms": "ah:mm:ss",
-	"field-fri-short-relative+-1": "上週五",
-	"dateFormatItem-hmv": "ah:mm [v]",
-	"field-thu-relative+-1": "上週四",
-	"dateFormatItem-yMd": "y/M/d",
-	"quarters-standAlone-narrow": [
-		"1",
-		"2",
-		"3",
-		"4"
-	],
-	"field-week": "週",
-	"quarters-format-wide": [
+	"field-second-narrow": "秒",
+	"field-month-relative+0": "本月",
+	"field-month-relative+1": "下個月",
+	"dateFormat-full": "y年M月d日 EEEE",
+	"field-era-narrow": "年代",
+	"field-sat-short-relative+-1": "上週六",
+	"field-week-short-relative+-1": "上週",
+	"dateTimeFormat-long": "{1} {0}",
+	"dateFormatItem-yM": "y/M",
+	"field-sun-relative+-1": "上週日",
+	"field-wed-short-relative+-1": "上週三",
+	"field-weekdayOfMonth": "每月平日",
+	"field-quarter-narrow-relative+0": "這一季",
+	"dateFormatItem-GyMMMEd": "Gy年M月d日 E",
+	"field-quarter-narrow-relative+1": "下一季",
+	"field-sat-short-relative+0": "本週六",
+	"field-hour-narrow": "小時",
+	"field-sat-short-relative+1": "下週六",
+	"field-year-narrow-relative+0": "今年",
+	"field-year-narrow-relative+1": "明年",
+	"dateFormatItem-Gy": "Gy年",
+	"field-zone-narrow": "時區",
+	"field-tue-relative+-1": "上週二",
+	"field-minute-short": "分鐘",
+	"dateFormatItem-yw": "Y年的第w週",
+	"dateFormatItem-Hm": "HH:mm",
+	"field-week-relative+0": "本週",
+	"field-week-relative+1": "下週",
+	"dateFormatItem-MMM": "LLL",
+	"field-sun-relative+0": "本週日",
+	"field-sun-relative+1": "下週日",
+	"field-sat-narrow-relative+-1": "上週六",
+	"quarters-standAlone-abbr": [
 		"第1季",
 		"第2季",
 		"第3季",
 		"第4季"
 	],
-	"dateFormatItem-Ed": "d E",
-	"field-wed-narrow-relative+0": "本週三",
-	"field-wed-narrow-relative+1": "下週三",
-	"dayPeriods-standAlone-wide-morning1": "清晨",
-	"dayPeriods-standAlone-wide-morning2": "上午",
-	"field-quarter-narrow-relative+-1": "上一季",
-	"field-fri-short-relative+0": "本週五",
-	"field-fri-short-relative+1": "下週五",
-	"days-standAlone-short": [
-		"日",
-		"一",
-		"二",
-		"三",
-		"四",
-		"五",
-		"六"
-	],
-	"dayPeriods-standAlone-narrow-morning1": "清晨",
-	"dayPeriods-standAlone-narrow-morning2": "上午",
-	"dayPeriods-format-abbr-midnight": "午夜",
-	"field-hour-short": "小時",
-	"quarters-format-abbr": [
-		"1季",
-		"2季",
-		"3季",
-		"4季"
-	],
-	"field-month-narrow": "月",
-	"field-hour-narrow": "小時",
-	"field-fri-narrow-relative+-1": "上週五",
-	"field-year-relative+0": "今年",
-	"field-year-relative+1": "明年",
-	"field-fri-relative+-1": "上週五",
-	"eraNarrow": [
-		"西元前",
-		"公元前",
-		"西元",
-		"公元"
-	],
-	"field-tue-short-relative+-1": "上週二",
-	"field-minute-narrow": "分鐘",
-	"dayPeriods-standAlone-wide-afternoon1": "中午",
-	"dateFormatItem-yQQQ": "y年QQQ",
-	"days-format-wide": [
-		"星期日",
-		"星期一",
-		"星期二",
-		"星期三",
-		"星期四",
-		"星期五",
-		"星期六"
-	],
-	"dayPeriods-standAlone-wide-afternoon2": "下午",
-	"field-mon-narrow-relative+0": "本週一",
-	"dateFormatItem-EHm": "E HH:mm",
-	"field-mon-narrow-relative+1": "下週一",
-	"dayPeriods-standAlone-wide-midnight": "午夜",
-	"dateFormatItem-yM": "y/M",
-	"field-zone": "時區",
-	"dateFormatItem-yMMMM": "y年M月",
-	"dateFormatItem-MMMEd": "M月d日 E",
+	"dateFormatItem-MMMMW": "MMMM的第W週",
+	"field-month-short-relative+-1": "上個月",
 	"dateFormatItem-EHms": "E HH:mm:ss",
-	"dateFormatItem-yMEd": "y/M/d（E）",
-	"dayPeriods-standAlone-narrow-midnight": "午夜",
-	"field-quarter-narrow": "季",
-	"dayPeriods-standAlone-abbr-am": "上午",
-	"field-day-relative+-1": "昨天",
-	"field-sun-short-relative+-1": "上週日",
-	"field-day-relative+-2": "前天",
-	"dayPeriods-format-narrow-night1": "凌晨",
-	"days-format-abbr": [
-		"週日",
-		"週一",
-		"週二",
-		"週三",
-		"週四",
-		"週五",
-		"週六"
-	],
-	"dateFormatItem-MMdd": "MM/dd",
-	"field-sun-relative+0": "本週日",
-	"field-sun-relative+1": "下週日",
-	"dateFormatItem-yMMMd": "y年M月d日",
-	"dateFormatItem-Gy": "Gy年",
-	"field-era": "年代",
-	"field-week-narrow": "週",
-	"field-day-short": "日",
-	"dayPeriods-standAlone-abbr-evening1": "晚上",
-	"field-fri-narrow-relative+0": "本週五",
-	"dayPeriods-format-narrow-evening1": "晚上",
-	"field-fri-narrow-relative+1": "下週五",
-	"dayPeriods-standAlone-wide-am": "上午"
+	"dateFormatItem-MMMMd": "M月d日",
+	"field-week": "週",
+	"field-day-narrow": "日",
+	"field-hour-narrow-relative+0": "這一小時"
 }
 //end v1.x content
 );
\ No newline at end of file
