@@ -10,20 +10,32 @@ define(
 	"field-wed-relative+1": "下週三",
 	"timeFormat-short": "ah:mm",
 	"field-minute": "分鐘",
+	"field-month-narrow-relative+-1": "上個月",
 	"field-tue-narrow-relative+0": "本週二",
 	"field-tue-narrow-relative+1": "下週二",
 	"field-thu-short-relative+0": "本週四",
+	"field-day-short-relative+-1": "昨天",
+	"dateTimeFormat-short": "{1} {0}",
 	"field-thu-short-relative+1": "下週四",
 	"field-day-relative+0": "今天",
+	"field-day-short-relative+-2": "前天",
 	"field-day-relative+1": "明天",
+	"field-week-narrow-relative+0": "本週",
 	"field-day-relative+2": "後天",
+	"field-week-narrow-relative+1": "下週",
 	"field-wed-narrow-relative+-1": "上週三",
+	"dateFormatItem-EBhms": "E Bh:mm:ss",
 	"field-year-narrow": "年",
+	"field-era-short": "年代",
+	"field-year-narrow-relative+0": "今年",
 	"field-tue-relative+0": "本週二",
+	"field-year-narrow-relative+1": "明年",
 	"field-tue-relative+1": "下週二",
+	"field-weekdayOfMonth": "每月平日",
 	"field-second-short": "秒",
 	"dayPeriods-format-narrow-am": "上午",
 	"dateFormatItem-MMMd": "M月d日",
+	"field-weekdayOfMonth-narrow": "每月平日",
 	"dayPeriods-format-abbr-am": "上午",
 	"field-week-relative+0": "本週",
 	"field-month-relative+0": "本月",
@@ -53,17 +65,21 @@ define(
 	"eraNames": [
 		"波斯曆"
 	],
+	"field-weekOfMonth": "週",
 	"dayPeriods-standAlone-abbr-pm": "下午",
 	"field-month-short": "月",
 	"dateFormatItem-GyMMMEd": "G y年M月d日 E",
 	"dateFormatItem-yyyyMd": "G y/M/d",
 	"field-day": "日",
+	"field-dayOfYear-short": "年天",
 	"field-year-relative+-1": "去年",
 	"dayPeriods-format-wide-am": "上午",
 	"field-sat-short-relative+-1": "上週六",
 	"field-hour-relative+0": "這一小時",
 	"dateFormatItem-yyyyMEd": "G y/M/d（E）",
+	"field-second-short-relative+0": "現在",
 	"field-wed-relative+-1": "上週三",
+	"dateTimeFormat-medium": "{1} {0}",
 	"field-sat-narrow-relative+-1": "上週六",
 	"field-second": "秒",
 	"days-standAlone-narrow": [
@@ -76,10 +92,15 @@ define(
 		"六"
 	],
 	"dayPeriods-standAlone-wide-pm": "下午",
+	"dateFormatItem-Ehms": "E ah:mm:ss",
 	"dateFormat-long": "G y年M月d日",
 	"dateFormatItem-GyMMMd": "G y年M月d日",
+	"field-hour-short-relative+0": "這一小時",
 	"field-quarter": "季",
 	"field-week-short": "週",
+	"field-day-narrow-relative+0": "今天",
+	"field-day-narrow-relative+1": "明天",
+	"field-day-narrow-relative+2": "後天",
 	"quarters-standAlone-wide": [
 		"第1季",
 		"第2季",
@@ -97,10 +118,12 @@ define(
 	],
 	"field-tue-short-relative+0": "本週二",
 	"field-tue-short-relative+1": "下週二",
+	"field-month-short-relative+-1": "上個月",
 	"field-mon-relative+-1": "上週一",
 	"dateFormatItem-GyMMM": "G y年M月",
 	"field-month": "月",
 	"field-day-narrow": "日",
+	"dateFormatItem-MMM": "LLL",
 	"field-minute-short": "分鐘",
 	"field-dayperiod": "上午/下午",
 	"field-sat-short-relative+0": "本週六",
@@ -112,17 +135,19 @@ define(
 		"波斯曆"
 	],
 	"quarters-standAlone-abbr": [
-		"1季",
-		"2季",
-		"3季",
-		"4季"
+		"第1季",
+		"第2季",
+		"第3季",
+		"第4季"
 	],
 	"dayPeriods-format-abbr-pm": "下午",
 	"dateFormatItem-yyyyM": "G y/M",
 	"field-second-narrow": "秒",
 	"field-mon-relative+0": "本週一",
 	"field-mon-relative+1": "下週一",
+	"field-day-narrow-relative+-1": "昨天",
 	"field-year-short": "年",
+	"field-day-narrow-relative+-2": "前天",
 	"months-format-narrow": [
 		"1",
 		"2",
@@ -139,7 +164,9 @@ define(
 	],
 	"field-quarter-relative+-1": "上一季",
 	"dateFormatItem-yyyyMMMd": "G y年M月d日",
+	"field-dayperiod-narrow": "上午/下午",
 	"dayPeriods-standAlone-narrow-am": "上午",
+	"field-week-narrow-relative+-1": "上週",
 	"days-format-short": [
 		"日",
 		"一",
@@ -150,8 +177,11 @@ define(
 		"六"
 	],
 	"dayPeriods-format-wide-pm": "下午",
+	"field-dayOfYear": "年天",
 	"field-sat-relative+-1": "上週六",
+	"dateTimeFormat-long": "{1} {0}",
 	"dateFormatItem-Md": "M/d",
+	"field-minute-narrow-relative+0": "這一分鐘",
 	"field-hour": "小時",
 	"months-format-wide": [
 		"1月",
@@ -175,10 +205,15 @@ define(
 	"field-fri-relative+0": "本週五",
 	"field-sat-narrow-relative+1": "下週六",
 	"field-fri-relative+1": "下週五",
+	"dateFormatItem-EBhm": "E Bh:mm",
+	"field-month-narrow-relative+0": "本月",
+	"field-month-narrow-relative+1": "下個月",
 	"field-sun-short-relative+0": "本週日",
 	"field-sun-short-relative+1": "下週日",
 	"field-week-relative+-1": "上週",
 	"field-quarter-short-relative+-1": "上一季",
+	"field-minute-short-relative+0": "這一分鐘",
+	"dateFormatItem-Ehm": "E ah:mm",
 	"months-format-abbr": [
 		"1月",
 		"2月",
@@ -199,7 +234,10 @@ define(
 	"field-quarter-relative+1": "下一季",
 	"field-wed-short-relative+-1": "上週三",
 	"dateFormat-short": "G y/M/d",
+	"dateFormatItem-Bh": "Bh時",
+	"field-year-narrow-relative+-1": "去年",
 	"field-thu-short-relative+-1": "上週四",
+	"dateFormatItem-yyyyMMMEd": "G y年M月d日 E",
 	"days-standAlone-wide": [
 		"星期日",
 		"星期一",
@@ -209,15 +247,15 @@ define(
 		"星期五",
 		"星期六"
 	],
-	"dateFormatItem-yyyyMMMEd": "G y年M月d日 E",
 	"field-mon-narrow-relative+-1": "上週一",
 	"dateFormatItem-MMMMd": "M月d日",
 	"field-thu-narrow-relative+-1": "上週四",
+	"dateFormatItem-E": "ccc",
+	"field-weekOfMonth-short": "週",
 	"field-tue-narrow-relative+-1": "上週二",
 	"dateFormatItem-H": "H時",
 	"dateFormatItem-yyyy": "G y年",
 	"dayPeriods-standAlone-narrow-pm": "下午",
-	"field-wed-short-relative+0": "本週三",
 	"dateFormatItem-M": "M月",
 	"months-standAlone-wide": [
 		"1月",
@@ -233,6 +271,7 @@ define(
 		"11月",
 		"12月"
 	],
+	"field-wed-short-relative+0": "本週三",
 	"field-wed-short-relative+1": "下週三",
 	"field-sun-relative+-1": "上週日",
 	"days-standAlone-abbr": [
@@ -245,14 +284,20 @@ define(
 		"週六"
 	],
 	"dateTimeFormat-full": "{1}{0}",
+	"field-second-narrow-relative+0": "現在",
 	"dateFormatItem-hm": "ah:mm",
 	"dateFormatItem-d": "d日",
 	"field-weekday": "週天",
+	"field-day-short-relative+0": "今天",
 	"field-quarter-narrow-relative+0": "這一季",
+	"field-day-short-relative+1": "明天",
 	"field-sat-relative+0": "本週六",
 	"field-quarter-narrow-relative+1": "下一季",
-	"dateFormatItem-h": "ah時",
+	"field-day-short-relative+2": "後天",
 	"field-sat-relative+1": "下週六",
+	"dateFormatItem-h": "ah時",
+	"field-week-short-relative+0": "本週",
+	"field-week-short-relative+1": "下週",
 	"months-standAlone-abbr": [
 		"1月",
 		"2月",
@@ -267,13 +312,18 @@ define(
 		"11月",
 		"12月"
 	],
+	"field-dayOfYear-narrow": "年天",
+	"field-month-short-relative+0": "本月",
+	"field-month-short-relative+1": "下個月",
+	"field-weekdayOfMonth-short": "每月平日",
 	"timeFormat-full": "ah:mm:ss [zzzz]",
 	"dateFormatItem-MEd": "M/d（E）",
+	"field-zone-narrow": "時區",
 	"dateFormatItem-y": "G y年",
 	"field-thu-narrow-relative+0": "本週四",
-	"field-thu-narrow-relative+1": "下週四",
 	"field-sun-narrow-relative+-1": "上週日",
 	"field-mon-short-relative+-1": "上週一",
+	"field-thu-narrow-relative+1": "下週四",
 	"field-thu-relative+0": "本週四",
 	"field-thu-relative+1": "下週四",
 	"field-fri-short-relative+-1": "上週五",
@@ -290,7 +340,10 @@ define(
 	"field-wed-narrow-relative+0": "本週三",
 	"field-wed-narrow-relative+1": "下週三",
 	"field-quarter-narrow-relative+-1": "上一季",
+	"field-year-short-relative+0": "今年",
 	"dateFormatItem-yyyyMMM": "G y年M月",
+	"field-dayperiod-short": "上午/下午",
+	"field-year-short-relative+1": "明年",
 	"field-fri-short-relative+0": "本週五",
 	"field-fri-short-relative+1": "下週五",
 	"days-standAlone-short": [
@@ -302,23 +355,26 @@ define(
 		"五",
 		"六"
 	],
+	"field-week-short-relative+-1": "上週",
+	"field-hour-narrow-relative+0": "這一小時",
 	"dateFormatItem-yyyyQQQQ": "G y年QQQQ",
 	"field-hour-short": "小時",
+	"field-zone-short": "時區",
 	"quarters-format-abbr": [
-		"1季",
-		"2季",
-		"3季",
-		"4季"
+		"第1季",
+		"第2季",
+		"第3季",
+		"第4季"
 	],
 	"field-month-narrow": "月",
 	"field-hour-narrow": "小時",
 	"field-fri-narrow-relative+-1": "上週五",
 	"field-year-relative+0": "今年",
 	"field-year-relative+1": "明年",
+	"field-era-narrow": "年代",
 	"field-fri-relative+-1": "上週五",
-	"eraNarrow": [
-		"波斯曆"
-	],
+	"eraNarrow": "波斯曆",
+	"dateFormatItem-Bhms": "Bh:mm:ss",
 	"field-tue-short-relative+-1": "上週二",
 	"field-minute-narrow": "分鐘",
 	"days-format-wide": [
@@ -332,13 +388,17 @@ define(
 	],
 	"field-mon-narrow-relative+0": "本週一",
 	"field-mon-narrow-relative+1": "下週一",
+	"field-year-short-relative+-1": "去年",
 	"field-zone": "時區",
 	"dateFormatItem-MMMEd": "M月d日 E",
+	"field-weekOfMonth-narrow": "週",
+	"field-weekday-narrow": "週天",
 	"field-quarter-narrow": "季",
 	"field-sun-short-relative+-1": "上週日",
 	"field-day-relative+-1": "昨天",
 	"dayPeriods-standAlone-abbr-am": "上午",
 	"field-day-relative+-2": "前天",
+	"field-weekday-short": "週天",
 	"days-format-abbr": [
 		"週日",
 		"週一",
@@ -348,6 +408,7 @@ define(
 		"週五",
 		"週六"
 	],
+	"dateFormatItem-Bhm": "Bh:mm",
 	"field-sun-relative+0": "本週日",
 	"field-sun-relative+1": "下週日",
 	"dateFormatItem-Gy": "G y年",
