@@ -1,146 +1,44 @@
 define(
 //begin v1.x content
 {
-	"months-format-narrow": [
-		"1",
-		"2",
-		"3",
-		"4",
-		"5",
-		"6",
-		"7",
-		"8",
-		"9",
-		"10",
-		"11",
-		"12",
-		"13"
-	],
-	"field-second-relative+0": "现在",
-	"field-quarter-relative+-1": "上季度",
-	"field-weekday": "工作日",
-	"field-mon-narrow-relative+0": "本周一",
-	"field-mon-narrow-relative+1": "下周一",
+	"field-quarter-short-relative+0": "本季度",
+	"field-quarter-short-relative+1": "下季度",
+	"field-tue-relative+-1": "上周二",
+	"field-year": "年",
 	"field-wed-relative+0": "本周三",
 	"field-wed-relative+1": "下周三",
-	"field-week-short": "周",
-	"field-tue-relative+-1": "上周二",
-	"field-year-short": "年",
-	"field-thu-narrow-relative+-1": "上周四",
-	"field-hour-relative+0": "这一时间 / 此时",
-	"field-quarter-narrow": "季",
-	"field-fri-relative+-1": "上周五",
-	"field-hour-short": "小时",
-	"field-wed-relative+-1": "上周三",
-	"months-format-wide": [
-		"一月",
-		"二月",
-		"三月",
-		"四月",
-		"五月",
-		"六月",
-		"七月",
-		"八月",
-		"九月",
-		"十月",
-		"十一月",
-		"十二月",
-		"十三月"
-	],
-	"field-mon-short-relative+-1": "上周一",
-	"field-thu-relative+-1": "上周四",
-	"field-era": "纪元",
-	"months-standAlone-wide": [
-		"一月",
-		"二月",
-		"三月",
-		"四月",
-		"五月",
-		"六月",
-		"七月",
-		"八月",
-		"九月",
-		"十月",
-		"十一月",
-		"十二月",
-		"十三月"
-	],
-	"field-sat-narrow-relative+0": "本周六",
-	"field-sat-narrow-relative+1": "下周六",
-	"field-year": "年",
-	"field-hour": "小时",
-	"months-format-abbr": [
-		"1月",
-		"2月",
-		"3月",
-		"4月",
-		"5月",
-		"6月",
-		"7月",
-		"8月",
-		"9月",
-		"10月",
-		"11月",
-		"12月",
-		"13月"
-	],
-	"field-sat-relative+0": "本周六",
-	"field-sat-relative+1": "下周六",
-	"field-sat-short-relative+-1": "上周六",
-	"field-minute-narrow": "分",
-	"field-day-relative+0": "今天",
-	"field-day-relative+1": "明天",
-	"field-thu-relative+0": "本周四",
-	"field-mon-narrow-relative+-1": "上周一",
-	"field-day-relative+2": "后天",
-	"field-wed-narrow-relative+0": "本周三",
-	"field-thu-relative+1": "下周四",
-	"months-standAlone-abbr": [
-		"1月",
-		"2月",
-		"3月",
-		"4月",
-		"5月",
-		"6月",
-		"7月",
-		"8月",
-		"9月",
-		"10月",
-		"11月",
-		"12月",
-		"13月"
-	],
-	"field-wed-narrow-relative+1": "下周三",
-	"field-mon-short-relative+0": "本周一",
-	"field-mon-short-relative+1": "下周一",
-	"field-wed-short-relative+-1": "上周三",
-	"field-fri-narrow-relative+-1": "上周五",
-	"field-hour-narrow": "小时",
-	"field-tue-short-relative+0": "本周二",
-	"field-year-narrow": "年",
-	"field-tue-short-relative+1": "下周二",
-	"field-minute-short": "分",
-	"field-day-narrow": "日",
-	"field-wed-short-relative+0": "本周三",
-	"field-wed-short-relative+1": "下周三",
-	"field-sun-relative+0": "本周日",
-	"field-sun-relative+1": "下周日",
 	"field-minute": "分钟",
-	"field-month-short": "月",
-	"field-dayperiod": "上午/下午",
-	"field-day-relative+-1": "昨天",
-	"field-day-relative+-2": "前天",
-	"field-minute-relative+0": "此刻",
-	"field-week-narrow": "周",
+	"field-month-narrow-relative+-1": "上个月",
+	"field-tue-narrow-relative+0": "本周二",
+	"field-tue-narrow-relative+1": "下周二",
+	"field-thu-short-relative+0": "本周四",
+	"field-day-short-relative+-1": "昨天",
+	"field-thu-short-relative+1": "下周四",
+	"field-day-relative+0": "今天",
+	"field-day-short-relative+-2": "前天",
+	"field-day-relative+1": "明天",
+	"field-week-narrow-relative+0": "本周",
+	"field-day-relative+2": "后天",
+	"field-week-narrow-relative+1": "下周",
 	"field-wed-narrow-relative+-1": "上周三",
-	"field-day-short": "日",
-	"field-quarter-relative+0": "本季度",
-	"field-quarter-relative+1": "下季度",
-	"field-fri-relative+0": "本周五",
-	"field-fri-relative+1": "下周五",
-	"field-day": "日",
-	"field-second-narrow": "秒",
-	"field-zone": "时区",
+	"field-year-narrow": "年",
+	"field-era-short": "纪元",
+	"field-year-narrow-relative+0": "今年",
+	"field-tue-relative+0": "本周二",
+	"field-year-narrow-relative+1": "明年",
+	"field-tue-relative+1": "下周二",
+	"field-weekdayOfMonth": "月中日",
+	"field-second-short": "秒",
+	"field-weekdayOfMonth-narrow": "月中日",
+	"field-week-relative+0": "本周",
+	"field-month-relative+0": "本月",
+	"field-week-relative+1": "下周",
+	"field-month-relative+1": "下个月",
+	"field-sun-narrow-relative+0": "本周日",
+	"field-mon-short-relative+0": "本周一",
+	"field-sun-narrow-relative+1": "下周日",
+	"field-mon-short-relative+1": "下周一",
+	"field-second-relative+0": "现在",
 	"months-standAlone-narrow": [
 		"1",
 		"2",
@@ -156,56 +54,224 @@ define(
 		"12",
 		"13"
 	],
-	"field-year-relative+-1": "去年",
-	"field-month-relative+-1": "上个月",
-	"field-thu-short-relative+0": "本周四",
-	"field-thu-short-relative+1": "下周四",
 	"eraNames": [
 		"埃塞俄比亚历前",
 		"埃塞俄比亚历"
 	],
-	"field-quarter": "季度",
-	"field-month": "月",
-	"field-tue-relative+0": "本周二",
-	"field-tue-relative+1": "下周二",
-	"field-fri-narrow-relative+0": "本周五",
-	"field-fri-narrow-relative+1": "下周五",
-	"field-fri-short-relative+-1": "上周五",
-	"field-sun-narrow-relative+-1": "上周日",
-	"field-sun-narrow-relative+0": "本周日",
-	"field-thu-narrow-relative+0": "本周四",
-	"field-sun-narrow-relative+1": "下周日",
-	"field-thu-narrow-relative+1": "下周四",
-	"field-tue-narrow-relative+0": "本周二",
-	"field-mon-relative+0": "本周一",
-	"field-tue-narrow-relative+1": "下周二",
-	"field-mon-relative+1": "下周一",
-	"field-tue-narrow-relative+-1": "上周二",
-	"field-second-short": "秒",
+	"field-weekOfMonth": "月中周",
+	"field-month-short": "月",
+	"field-day": "日",
+	"field-dayOfYear-short": "年中日",
+	"field-year-relative+-1": "去年",
+	"field-sat-short-relative+-1": "上周六",
+	"field-hour-relative+0": "这一时间 / 此时",
+	"field-second-short-relative+0": "现在",
+	"field-wed-relative+-1": "上周三",
+	"field-sat-narrow-relative+-1": "上周六",
 	"field-second": "秒",
-	"field-fri-short-relative+0": "本周五",
-	"field-sat-relative+-1": "上周六",
-	"field-fri-short-relative+1": "下周五",
-	"field-sun-relative+-1": "上周日",
-	"field-month-relative+0": "本月",
-	"field-month-relative+1": "下个月",
-	"field-week": "周",
+	"field-hour-short-relative+0": "这一时间 / 此时",
+	"field-quarter": "季度",
+	"field-week-short": "周",
+	"field-day-narrow-relative+0": "今天",
+	"field-day-narrow-relative+1": "明天",
+	"field-day-narrow-relative+2": "后天",
+	"field-tue-short-relative+0": "本周二",
+	"field-tue-short-relative+1": "下周二",
+	"field-month-short-relative+-1": "上个月",
+	"field-mon-relative+-1": "上周一",
+	"field-month": "月",
+	"field-day-narrow": "日",
+	"field-minute-short": "分",
+	"field-dayperiod": "上午/下午",
 	"field-sat-short-relative+0": "本周六",
 	"field-sat-short-relative+1": "下周六",
-	"field-year-relative+0": "今年",
-	"field-week-relative+-1": "上周",
-	"field-year-relative+1": "明年",
+	"eraAbbr": [
+		"埃历前",
+		"埃历"
+	],
+	"field-second-narrow": "秒",
+	"field-mon-relative+0": "本周一",
+	"field-mon-relative+1": "下周一",
+	"field-day-narrow-relative+-1": "昨天",
+	"field-year-short": "年",
+	"field-day-narrow-relative+-2": "前天",
+	"months-format-narrow": [
+		"1",
+		"2",
+		"3",
+		"4",
+		"5",
+		"6",
+		"7",
+		"8",
+		"9",
+		"10",
+		"11",
+		"12",
+		"13"
+	],
+	"field-quarter-relative+-1": "上季度",
+	"field-dayperiod-narrow": "上午/下午",
+	"field-week-narrow-relative+-1": "上周",
+	"field-dayOfYear": "年中日",
+	"field-sat-relative+-1": "上周六",
+	"field-hour": "小时",
+	"field-minute-narrow-relative+0": "此刻",
+	"months-format-wide": [
+		"一月",
+		"二月",
+		"三月",
+		"四月",
+		"五月",
+		"六月",
+		"七月",
+		"八月",
+		"九月",
+		"十月",
+		"十一月",
+		"十二月",
+		"十三月"
+	],
+	"dateFormat-full": "Gy年MM月d日EEEE",
+	"field-month-relative+-1": "上个月",
 	"field-quarter-short": "季",
-	"field-sun-short-relative+-1": "上周日",
-	"field-thu-short-relative+-1": "上周四",
-	"field-tue-short-relative+-1": "上周二",
-	"field-mon-relative+-1": "上周一",
-	"field-sat-narrow-relative+-1": "上周六",
-	"field-month-narrow": "月",
-	"field-week-relative+0": "本周",
+	"field-sat-narrow-relative+0": "本周六",
+	"field-fri-relative+0": "本周五",
+	"field-sat-narrow-relative+1": "下周六",
+	"field-fri-relative+1": "下周五",
+	"field-month-narrow-relative+0": "本月",
+	"field-month-narrow-relative+1": "下个月",
 	"field-sun-short-relative+0": "本周日",
-	"field-week-relative+1": "下周",
-	"field-sun-short-relative+1": "下周日"
+	"field-sun-short-relative+1": "下周日",
+	"field-week-relative+-1": "上周",
+	"field-quarter-short-relative+-1": "上季度",
+	"field-minute-short-relative+0": "此刻",
+	"months-format-abbr": [
+		"1月",
+		"2月",
+		"3月",
+		"4月",
+		"5月",
+		"6月",
+		"7月",
+		"8月",
+		"9月",
+		"10月",
+		"11月",
+		"12月",
+		"13月"
+	],
+	"field-quarter-relative+0": "本季度",
+	"field-minute-relative+0": "此刻",
+	"field-quarter-relative+1": "下季度",
+	"field-wed-short-relative+-1": "上周三",
+	"field-thu-short-relative+-1": "上周四",
+	"field-year-narrow-relative+-1": "去年",
+	"field-mon-narrow-relative+-1": "上周一",
+	"field-thu-narrow-relative+-1": "上周四",
+	"field-tue-narrow-relative+-1": "上周二",
+	"field-weekOfMonth-short": "月中周",
+	"field-wed-short-relative+0": "本周三",
+	"months-standAlone-wide": [
+		"一月",
+		"二月",
+		"三月",
+		"四月",
+		"五月",
+		"六月",
+		"七月",
+		"八月",
+		"九月",
+		"十月",
+		"十一月",
+		"十二月",
+		"十三月"
+	],
+	"field-wed-short-relative+1": "下周三",
+	"field-sun-relative+-1": "上周日",
+	"field-second-narrow-relative+0": "现在",
+	"field-weekday": "工作日",
+	"field-day-short-relative+0": "今天",
+	"field-quarter-narrow-relative+0": "本季度",
+	"field-day-short-relative+1": "明天",
+	"field-sat-relative+0": "本周六",
+	"field-quarter-narrow-relative+1": "下季度",
+	"field-day-short-relative+2": "后天",
+	"field-sat-relative+1": "下周六",
+	"field-week-short-relative+0": "本周",
+	"field-week-short-relative+1": "下周",
+	"months-standAlone-abbr": [
+		"1月",
+		"2月",
+		"3月",
+		"4月",
+		"5月",
+		"6月",
+		"7月",
+		"8月",
+		"9月",
+		"10月",
+		"11月",
+		"12月",
+		"13月"
+	],
+	"field-dayOfYear-narrow": "年中日",
+	"field-month-short-relative+0": "本月",
+	"field-month-short-relative+1": "下个月",
+	"field-weekdayOfMonth-short": "月中日",
+	"field-zone-narrow": "时区",
+	"field-thu-narrow-relative+0": "本周四",
+	"field-thu-narrow-relative+1": "下周四",
+	"field-sun-narrow-relative+-1": "上周日",
+	"field-mon-short-relative+-1": "上周一",
+	"field-thu-relative+0": "本周四",
+	"field-thu-relative+1": "下周四",
+	"field-fri-short-relative+-1": "上周五",
+	"field-thu-relative+-1": "上周四",
+	"field-week": "周",
+	"field-wed-narrow-relative+0": "本周三",
+	"field-wed-narrow-relative+1": "下周三",
+	"field-quarter-narrow-relative+-1": "上季度",
+	"field-year-short-relative+0": "今年",
+	"field-dayperiod-short": "上午/下午",
+	"field-year-short-relative+1": "明年",
+	"field-fri-short-relative+0": "本周五",
+	"field-fri-short-relative+1": "下周五",
+	"field-week-short-relative+-1": "上周",
+	"field-hour-narrow-relative+0": "这一时间 / 此时",
+	"field-hour-short": "小时",
+	"field-zone-short": "时区",
+	"field-month-narrow": "月",
+	"field-hour-narrow": "小时",
+	"field-fri-narrow-relative+-1": "上周五",
+	"field-year-relative+0": "今年",
+	"field-year-relative+1": "明年",
+	"field-era-narrow": "纪元",
+	"field-fri-relative+-1": "上周五",
+	"eraNarrow": [
+		"埃历前",
+		"埃历"
+	],
+	"field-tue-short-relative+-1": "上周二",
+	"field-minute-narrow": "分",
+	"field-mon-narrow-relative+0": "本周一",
+	"field-mon-narrow-relative+1": "下周一",
+	"field-year-short-relative+-1": "去年",
+	"field-zone": "时区",
+	"field-weekOfMonth-narrow": "月中周",
+	"field-weekday-narrow": "工作日",
+	"field-quarter-narrow": "季",
+	"field-sun-short-relative+-1": "上周日",
+	"field-day-relative+-1": "昨天",
+	"field-day-relative+-2": "前天",
+	"field-weekday-short": "工作日",
+	"field-sun-relative+0": "本周日",
+	"field-sun-relative+1": "下周日",
+	"field-day-short": "日",
+	"field-week-narrow": "周",
+	"field-era": "纪元",
+	"field-fri-narrow-relative+0": "本周五",
+	"field-fri-narrow-relative+1": "下周五"
 }
 //end v1.x content
 );
\ No newline at end of file
